//
// org.osid.sequencing.ChainForm
//
//     The OSID Java specification for org.osid.sequencing.ChainForm.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.sequencing;


/**
 *  <p>This is the form for creating and updating chains. <code> </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> ChainAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface ChainForm
    extends org.osid.OsidObjectForm {


    /**
     *  Gets the metadata for the fifo flag. 
     *
     *  @return metadata for the fifo flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getFifoMetadata();


    /**
     *  Sets the fifo flag. 
     *
     *  @param  fifo <code> true </code> to append elements to the end of the 
     *          chain,, <code> false </code> to place new elements at the top 
     *          of the chain 
     *  @throws org.osid.InvalidArgumentException <code> affirmative </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setFifo(boolean fifo);


    /**
     *  Removes the fifo flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFifo();


    /**
     *  Gets the <code> ChainFormRecord </code> corresponding to the given 
     *  chain record <code> Type. </code> 
     *
     *  @param  chainRecordType a chain record type 
     *  @return the chain form record 
     *  @throws org.osid.NullArgumentException <code> chainRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(chainRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.records.ChainFormRecord getChainFormRecord(org.osid.type.Type chainRecordType)
        throws org.osid.OperationFailedException;
}
