//
// org.osid.sequencing.ChainLookupSession
//
//     The OSID Java specification for org.osid.sequencing.ChainLookupSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.sequencing;


/**
 *  <p>This session defines methods for retrieving chains. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated antimatroid view: All chain methods in this session 
 *      operate, retrieve and pertain to chains defined explicitly in the 
 *      current antimatroid. Using an isolated view is useful for managing 
 *      <code> Chains </code> with the <code> ChainAdminSession. </code> </li> 
 *      <li> federated antimatroid view: All chain lookup methods in this 
 *      session operate, retrieve and pertain to all chains defined in this 
 *      antimatroid and any other chains implicitly available in this 
 *      antimatroid through antimatroid inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedAntimatroidView() </code> and <code> 
 *  useIsolatedAntimatroidView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Chains may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the chains. 
 *  </p>
 */

public interface ChainLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Antimatroid </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Antimatroid Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAntimatroidId();


    /**
     *  Gets the <code> Antimatroid </code> associated with this session. 
     *
     *  @return the antimatroid 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.Antimatroid getAntimatroid()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Chain </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupChains();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeChainView();


    /**
     *  A complete view of the <code> Chain </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryChainView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include chains in antimatroids which are children of this antimatroid 
     *  in the antimatroid hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAntimatroidView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this antimatroid only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAntimatroidView();


    /**
     *  Gets the <code> Chain </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Chain </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Chain </code> and retained for compatibility. 
     *
     *  @param  chainId the <code> Id </code> of the <code> Chain </code> to 
     *          retrieve 
     *  @return the returned <code> Chain </code> 
     *  @throws org.osid.NotFoundException no <code> Chain </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> chainId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.Chain getChain(org.osid.id.Id chainId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ChainList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  chains specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Chains </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  chainIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Chain </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> chainIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.ChainList getChainsByIds(org.osid.id.IdList chainIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ChainList </code> corresponding to the given chain genus 
     *  <code> Type </code> which does not include chains of types derived 
     *  from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  chains or an error results. Otherwise, the returned list may contain 
     *  only those chains that are accessible through this session. 
     *
     *  @param  chainGenusType a chain genus type 
     *  @return the returned <code> Chain </code> list 
     *  @throws org.osid.NullArgumentException <code> chainGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.ChainList getChainsByGenusType(org.osid.type.Type chainGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ChainList </code> corresponding to the given chain genus 
     *  <code> Type </code> and include any additional chains with genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  chains or an error results. Otherwise, the returned list may contain 
     *  only those chains that are accessible through this session. 
     *
     *  @param  chainGenusType a chain genus type 
     *  @return the returned <code> Chain </code> list 
     *  @throws org.osid.NullArgumentException <code> chainGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.ChainList getChainsByParentGenusType(org.osid.type.Type chainGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ChainList </code> containing the given chain record 
     *  <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known chains or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  chains that are accessible through this session. 
     *
     *  @param  chainRecordType a chain record type 
     *  @return the returned <code> Chain </code> list 
     *  @throws org.osid.NullArgumentException <code> chainRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.ChainList getChainsByRecordType(org.osid.type.Type chainRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all chains. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  chains including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Chains </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @return the returned <code> Chain </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.ChainList getChains()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
