//
// org.osid.sequencing.ChainNotificationSession
//
//     The OSID Java specification for org.osid.sequencing.ChainNotificationSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.sequencing;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Chain </code> objects in this <code> dDstributor. </code> This 
 *  session is intended for consumers needing to synchronize their state with 
 *  this service without the use of polling. Notifications are cancelled when 
 *  this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> ChainLookupSession. </code> </p>
 */

public interface ChainNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Antimatroid </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Antimatroid Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAntimatroidId();


    /**
     *  Gets the <code> Antimatroid </code> associated with this session. 
     *
     *  @return the antimatroid 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.Antimatroid getAntimatroid()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Chain </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForChainNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include chains in antimatroids which are children of this antimatroid 
     *  in the antimatroid hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAntimatroidView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this antimatroid only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAntimatroidView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> acknowledgeChainNotification() 
     *  </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableChainNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableChainNotifications();


    /**
     *  Acknowledge a chain notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeChainNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new chains. <code> 
     *  ChainReceiver.newChains() </code> is invoked when a new <code> Chain 
     *  </code> appears in this antimatroid. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewChains()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated chains. <code> 
     *  ChainReceiver.changedChains() </code> is invoked when a chain in this 
     *  antimatroid is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedChains()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated chain. <code> 
     *  ChainReceiver.changedChains() </code> is invoked when the specified 
     *  chain in this antimatroid is changed. 
     *
     *  @param  chainId the <code> Id </code> of the <code> Chain </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> chainId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedChain(org.osid.id.Id chainId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted chains. <code> 
     *  ChainReceiver.deletedChains() </code> is invoked when a chain is 
     *  deleted or removed from this antimatroid. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedChains()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted chain. <code> 
     *  ChainReceiver.deletedChains() </code> is invoked when the specified 
     *  chain is deleted or removed from this antimatroid. 
     *
     *  @param  chainId the <code> Id </code> of the <code> Chain </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> chainId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedChain(org.osid.id.Id chainId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
