//
// org.osid.sequencing.ChainQuerySession
//
//     The OSID Java specification for org.osid.sequencing.ChainQuerySession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.sequencing;


/**
 *  <p>This session provides methods for searching among <code> Chain </code> 
 *  objects. The search query is constructed using the <code> ChainQuery. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated antimatroid view: searches include chains in 
 *      antimatroids of which this antimatroid is an ancestor in the 
 *      antimatroid hierarchy </li> 
 *      <li> isolated antimatroid view: searches are restricted to chains in 
 *      this antimatroid </li> 
 *  </ul>
 *  
 *  
 *  <p> chains may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> ChainQuery. </code> 
 *  </p>
 */

public interface ChainQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Antimatroid </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Antimatroid Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAntimatroidId();


    /**
     *  Gets the <code> Antimatroid </code> associated with this session. 
     *
     *  @return the antimatroid 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.Antimatroid getAntimatroid()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Chain </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchChains();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include chains in antimatroids which are children of this antimatroid 
     *  in the antimatroid hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAntimatroidView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this antimatroid only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAntimatroidView();


    /**
     *  Gets a chain query. 
     *
     *  @return the chain query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.ChainQuery getChainQuery();


    /**
     *  Gets a list of <code> Chains </code> matching the given chain query. 
     *
     *  @param  chainQuery the chain query 
     *  @return the returned <code> ChainList </code> 
     *  @throws org.osid.NullArgumentException <code> chainQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> chainQuery </code> is not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.ChainList getChainsByQuery(org.osid.sequencing.ChainQuery chainQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
