//
// org.osid.sequencing.ChainSearchSession
//
//     The OSID Java specification for org.osid.sequencing.ChainSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.sequencing;


/**
 *  <p>This session provides methods for searching among <code> Chain </code> 
 *  objects. The search query is constructed using the <code> ChainQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getChainsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Chains. </code> A more advanced search may be 
 *  performed with <code> getChainsBySearch(). </code> It accepts an <code> 
 *  ChainSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getChainsBySearch() </code> returns an <code> ChainSearchResults </code> 
 *  that can be used to access the resulting <code> ChainList </code> or be 
 *  used to perform a search within the result set through <code> ChainSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated antimatroid view: searches include chains in 
 *      antimatroids of which this antimatroid is an ancestor in the 
 *      antimatroid hierarchy </li> 
 *      <li> isolated antimatroid view: searches are restricted to chains in 
 *      this antimatroid </li> 
 *  </ul>
 *  
 *  
 *  <p> Chains may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> ChainQuery. </code> 
 *  </p>
 */

public interface ChainSearchSession
    extends org.osid.sequencing.ChainQuerySession {


    /**
     *  Gets a chain search. 
     *
     *  @return the chain search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.ChainSearch getChainSearch();


    /**
     *  Gets a chain search order. The <code> ChainSearchOrder </code> is 
     *  supplied to a <code> ChainSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the chain search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.ChainSearchOrder getChainSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  chainQuery the chain query 
     *  @param  chainSearch the chain search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> chainQuery </code> or 
     *          <code> chainSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> chainQuery </code> or 
     *          <code> chainSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.ChainSearchResults getChainsBySearch(org.osid.sequencing.ChainQuery chainQuery, 
                                                                    org.osid.sequencing.ChainSearch chainSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a chain query from an inspector. The inspector is available from 
     *  a <code> ChainSearchResults. </code> 
     *
     *  @param  chainQueryInspector a chain query inspector 
     *  @return the chain query 
     *  @throws org.osid.NullArgumentException <code> chainQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> chainQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.ChainQuery getChainQueryFromInspector(org.osid.sequencing.ChainQueryInspector chainQueryInspector);
}
