//
// org.osid.sequencing.ChainSmartAntimatroidSession
//
//     The OSID Java specification for org.osid.sequencing.ChainSmartAntimatroidSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.sequencing;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> ChainQuery </code> can be retrieved from this session 
 *  and antimatroidped to this <code> Antimatroid </code> to create a virtual 
 *  collection of <code> Chains. </code> The chains may be sequenced using the 
 *  <code> ChainSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Antimatroid </code> has a default query that matches any 
 *  chain and a default search order that specifies no sequencing. The queries 
 *  may be examined using a <code> ChainQueryInspector. </code> The query may 
 *  be modified by converting the inspector back to a <code> ChainQuery. 
 *  </code> </p>
 */

public interface ChainSmartAntimatroidSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Antimatroid </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Antimatroid Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAntimatroidId();


    /**
     *  Gets the <code> Antimatroid </code> associated with this session. 
     *
     *  @return the antimatroid 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.Antimatroid getAntimatroid()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart antimatroids. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known methods in this session will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart antimatroid management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartAntimatroids();


    /**
     *  Gets a chain query. 
     *
     *  @return the chain query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.ChainQuery getChainQuery();


    /**
     *  Gets a chain search order. 
     *
     *  @return the chain search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.ChainSearchOrder getChainSearchOrder();


    /**
     *  Applies a chain query to this antimatroid. 
     *
     *  @param  chainQuery the chain query 
     *  @throws org.osid.NullArgumentException <code> chainQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> chainQuery </code> not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyChainQuery(org.osid.sequencing.ChainQuery chainQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a chain query inspector for this antimatroid. 
     *
     *  @return the chain query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.ChainQueryInspector inspectChainQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a chain search order to this antimatroid. 
     *
     *  @param  chainSearchOrder the chain search order 
     *  @throws org.osid.NullArgumentException <code> chainSearchOrder </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> chainSearchOrder </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyChainSequencing(org.osid.sequencing.ChainSearchOrder chainSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a chain query from an inspector. 
     *
     *  @param  chainQueryInspector a chain query inspector 
     *  @return the chain query 
     *  @throws org.osid.NullArgumentException <code> chainQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> chainQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.ChainQuery getChainQueryFromInspector(org.osid.sequencing.ChainQueryInspector chainQueryInspector);
}
