//
// org.osid.subscription.DispatchQueryInspector
//
//     The OSID Java specification for org.osid.subscription.DispatchQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription;


/**
 *  <p>This is the query inspector for examining for dispatch queries. </p>
 */

public interface DispatchQueryInspector
    extends org.osid.OsidGovernatorQueryInspector {


    /**
     *  Gets the address genus <code> Type </code> terms. 
     *
     *  @return the address genus <code> Type </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.TypeTerm[] getAddressGenusTypeTerms();


    /**
     *  Gets the subscription <code> Id </code> terms. 
     *
     *  @return the subscription <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getSubscriptionIdTerms();


    /**
     *  Gets the subscription terms. 
     *
     *  @return the subscription terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionQueryInspector[] getSubscriptionTerms();


    /**
     *  Gets the publisher <code> Id </code> terms. 
     *
     *  @return the publisher <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getPublisherIdTerms();


    /**
     *  Gets the publisher terms. 
     *
     *  @return the publisher terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.PublisherQueryInspector[] getPublisherTerms();


    /**
     *  Gets the dispatch query inspector record corresponding to the given 
     *  <code> Dispatch </code> record <code> Type. </code> 
     *
     *  @param  dispatchRecordType a dispatch record type 
     *  @return the dispatch query inspector record 
     *  @throws org.osid.NullArgumentException <code> dispatchRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(dispatchRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.records.DispatchQueryInspectorRecord getDispatchQueryInspectorRecord(org.osid.type.Type dispatchRecordType)
        throws org.osid.OperationFailedException;
}
