//
// org.osid.subscription.SubscriptionProfile
//
//     The OSID Java specification for org.osid.subscription.SubscriptionProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription;


/**
 *  <p>The subscription profile describes the interoperability among 
 *  subscription services. </p>
 */

public interface SubscriptionProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any dispatch federation is exposed. Federation is exposed 
     *  when a specific dispatch may be identified, selected and used to 
     *  create a lookup or admin session. Federation is not exposed when a set 
     *  of dispatches appears as a single dispatch. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of a my subscription lookup service. 
     *
     *  @return <code> true </code> if my subscription lookup is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMySubscription();


    /**
     *  Tests for the availability of a my subscription administrative 
     *  service. 
     *
     *  @return <code> true </code> if my subscription admin is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMySubscriptionAdmin();


    /**
     *  Tests for the availability of a subscription lookup service. 
     *
     *  @return <code> true </code> if subscription lookup is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionLookup();


    /**
     *  Tests if querying subscriptions is available. 
     *
     *  @return <code> true </code> if subscription query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionQuery();


    /**
     *  Tests if searching for subscriptions is available. 
     *
     *  @return <code> true </code> if subscription search is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionSearch();


    /**
     *  Tests if searching for subscriptions is available. 
     *
     *  @return <code> true </code> if subscription search is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionAdmin();


    /**
     *  Tests if subscription notification is available. 
     *
     *  @return <code> true </code> if subscription notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionNotification();


    /**
     *  Tests if a subscription to publisher lookup session is available. 
     *
     *  @return <code> true </code> if subscription publisher lookup session 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionPublisher();


    /**
     *  Tests if a subscription to publisher assignment session is available. 
     *
     *  @return <code> true </code> if subscription publisher assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionPublisherAssignment();


    /**
     *  Tests if a subscription smart publisher session is available. 
     *
     *  @return <code> true </code> if subscription smart publisher is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionSmartPublisher();


    /**
     *  Tests for the availability of an dispatch lookup service. 
     *
     *  @return <code> true </code> if dispatch lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDispatchLookup();


    /**
     *  Tests if querying dispatches is available. 
     *
     *  @return <code> true </code> if dispatch query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDispatchQuery();


    /**
     *  Tests if searching for dispatches is available. 
     *
     *  @return <code> true </code> if dispatch search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDispatchSearch();


    /**
     *  Tests for the availability of a dispatch administrative service for 
     *  creating and deleting dispatches. 
     *
     *  @return <code> true </code> if dispatch administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDispatchAdmin();


    /**
     *  Tests for the availability of a dispatch notification service. 
     *
     *  @return <code> true </code> if dispatch notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsDispatchNotification();


    /**
     *  Tests if a dispatch to publisher lookup session is available. 
     *
     *  @return <code> true </code> if dispatch publisher lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDispatchPublisher();


    /**
     *  Tests if a dispatch to publisher assignment session is available. 
     *
     *  @return <code> true </code> if dispatch publisher assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDispatchPublisherAssignment();


    /**
     *  Tests if a dispatch smart publisher session is available. 
     *
     *  @return <code> true </code> if dispatch smart publisher is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDispatchSmartPublisher();


    /**
     *  Tests for the availability of an publisher lookup service. 
     *
     *  @return <code> true </code> if publisher lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPublisherLookup();


    /**
     *  Tests if querying publishers is available. 
     *
     *  @return <code> true </code> if publisher query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPublisherQuery();


    /**
     *  Tests if searching for publishers is available. 
     *
     *  @return <code> true </code> if publisher search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPublisherSearch();


    /**
     *  Tests for the availability of a publisher administrative service for 
     *  creating and deleting publishers. 
     *
     *  @return <code> true </code> if publisher administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPublisherAdmin();


    /**
     *  Tests for the availability of a publisher notification service. 
     *
     *  @return <code> true </code> if publisher notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsPublisherNotification();


    /**
     *  Tests for the availability of a publisher hierarchy traversal service. 
     *
     *  @return <code> true </code> if publisher hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPublisherHierarchy();


    /**
     *  Tests for the availability of a publisher hierarchy design service. 
     *
     *  @return <code> true </code> if publisher hierarchy design is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsPublisherHierarchyDesign();


    /**
     *  Tests for the availability of a subscription batch service. 
     *
     *  @return <code> true </code> if a subscription batch service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsSubscriptionBatch();


    /**
     *  Tests for the availability of a subscription rules service. 
     *
     *  @return <code> true </code> if a subscription rules service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsSubscriptionRules();


    /**
     *  Gets the supported <code> Subscription </code> record types. 
     *
     *  @return a list containing the supported subscription record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSubscriptionRecordTypes();


    /**
     *  Tests if the given <code> Subscription </code> record type is 
     *  supported. 
     *
     *  @param  subscriptionRecordType a <code> Type </code> indicating a 
     *          <code> Subscription </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> subscriptionRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionRecordType(org.osid.type.Type subscriptionRecordType);


    /**
     *  Gets the supported subscription search record types. 
     *
     *  @return a list containing the supported subscription search record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSubscriptionSearchRecordTypes();


    /**
     *  Tests if the given subscription search record type is supported. 
     *
     *  @param  subscriptionSearchRecordType a <code> Type </code> indicating 
     *          a subscription record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          subscriptionSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionSearchRecordType(org.osid.type.Type subscriptionSearchRecordType);


    /**
     *  Gets the supported <code> Dispatch </code> record types. 
     *
     *  @return a list containing the supported dispatch record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDispatchRecordTypes();


    /**
     *  Tests if the given <code> Dispatch </code> record type is supported. 
     *
     *  @param  dispatchRecordType a <code> Type </code> indicating a <code> 
     *          Dispatch </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> dispatchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDispatchRecordType(org.osid.type.Type dispatchRecordType);


    /**
     *  Gets the supported dispatch search record types. 
     *
     *  @return a list containing the supported dispatch search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDispatchSearchRecordTypes();


    /**
     *  Tests if the given dispatch search record type is supported. 
     *
     *  @param  dispatchSearchRecordType a <code> Type </code> indicating a 
     *          dispatch record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> dispatchSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDispatchSearchRecordType(org.osid.type.Type dispatchSearchRecordType);


    /**
     *  Gets the supported <code> Publisher </code> record types. 
     *
     *  @return a list containing the supported publisher record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPublisherRecordTypes();


    /**
     *  Tests if the given <code> Publisher </code> record type is supported. 
     *
     *  @param  publisherRecordType a <code> Type </code> indicating a <code> 
     *          Publisher </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> publisherRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPublisherRecordType(org.osid.type.Type publisherRecordType);


    /**
     *  Gets the supported publisher search record types. 
     *
     *  @return a list containing the supported publisher search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPublisherSearchRecordTypes();


    /**
     *  Tests if the given publisher search record type is supported. 
     *
     *  @param  publisherSearchRecordType a <code> Type </code> indicating a 
     *          publisher record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          publisherSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPublisherSearchRecordType(org.osid.type.Type publisherSearchRecordType);
}
