//
// org.osid.subscription.batch.DispatchBatchAdminSession
//
//     The OSID Java specification for org.osid.subscription.batch.DispatchBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Dispatches </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Dispatch, </code> a <code> DispatchForm </code> is requested using <code> 
 *  getDispatchFormsForCreate() </code> specifying the desired record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. Each 
 *  of the returned <code> DispatchForms </code> will indicate that it is to 
 *  be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once a <code> DispatchForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  DispatchForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> DispatchForms </code> returned from <code> 
 *  getDispatchFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> DispatchForm. 
 *  </code> In the case where there may be duplicates, any <code> DispatchForm 
 *  </code> of the same peer <code> Ids </code> may be used for a create 
 *  operation. </p> 
 *  
 *  <p> Once a batch of <code> DispatchForms </code> are submitted for create, 
 *  a <code> CreateResponse </code> is returned for each <code> DispatchForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createDispatches(), 
 *  </code> errors specific to an individual <code> DispatchForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> 
 *  DispatchForm </code> through the <code> DispatchForm </code> <code> Id 
 *  </code> . </p> 
 *  
 *  <p> For updates, <code> DispatchForms </code> are requested to the <code> 
 *  Dispatch </code> <code> Id </code> that is to be updated using <code> 
 *  getDispatchFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> DispatchForm </code> may be used to link the request. 
 *  Similarly, the <code> DispatchForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> DispatchForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> DispatchForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> DispatchForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateDispatches(), 
 *  </code> errors specific to an individual <code> DispatchForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> 
 *  DispatchForm </code> through the <code> DispatchForm </code> <code> Id. 
 *  </code> </p> 
 *  
 *  <p> The delete operations delete <code> Dispatches </code> in bulk. To 
 *  unmap a <code> Dispatch </code> from the current <code> Publisher, </code> 
 *  the <code> DispatchPublisherAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> Dispatch </code> 
 *  itself thus removing it from all known <code> Publisher </code> catalogs. 
 *  Bulk delete operations return the results in <code> DeleteResponses. 
 *  </code> </p>
 */

public interface DispatchBatchAdminSession
    extends org.osid.subscription.DispatchAdminSession {


    /**
     *  Gets the dispatch forms for creating a bunch of new dispatches. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  dispatchRecordTypes array of dispatch record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the dispatch forms 
     *  @throws org.osid.NullArgumentException <code> dispatchRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.batch.DispatchBatchFormList getDispatchFormsForCreate(long number, 
                                                                                       org.osid.type.Type[] dispatchRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Dispatches. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  dispatchForms the dispatch forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> dispatchForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createDispatches(org.osid.subscription.batch.DispatchBatchFormList dispatchForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the dispatch forms for updating an existing set of dispatches. A 
     *  new dispatch form should be requested for each update transaction. 
     *
     *  @param  dispatchIds the <code> Ids </code> of the <code> Dispatch 
     *          </code> 
     *  @return the dispatch form 
     *  @throws org.osid.NotFoundException a <code> dispatchId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> dispatchIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.batch.DispatchBatchFormList getDispatchFormsForUpdate(org.osid.id.IdList dispatchIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing dispatches. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  dispatchForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> dispatchForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateDispatches(org.osid.subscription.batch.DispatchBatchFormList dispatchForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Dispatches </code> in this <code> Publisher </code> 
     *  . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllDispatches()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes dispatches for the given <code> Ids. </code> 
     *
     *  @param  dispatchIds the <code> Ids </code> of the dispatches to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> dispatchIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteDispatches(org.osid.id.IdList dispatchIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Dispatch </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Dispatch </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another dispatch, it is reassigned to the given dispatch 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasDispatches(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
