//
// org.osid.subscription.batch.PublisherBatchAdminSession
//
//     The OSID Java specification for org.osid.subscription.batch.PublisherBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Publishers </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Publisher, </code> a <code> PublisherForm </code> is requested using 
 *  <code> getPublisherFormsForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  Each of the returned <code> PublisherForms </code> will indicate that it 
 *  is to be used with a create operation and can be used to examine metdata 
 *  or validate data prior to creation. Once a <code> PublisherForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  PublisherForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> PublisherForms </code> returned from <code> 
 *  getPublisherFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> PublisherForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  PublisherForm </code> of the same peer <code> Ids </code> may be used for 
 *  a create operation. </p> 
 *  
 *  <p> Once a batch of <code> PublisherForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  PublisherForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createPublishers(), </code> errors specific to an individual <code> 
 *  PublisherForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> PublisherForm </code> through the <code> 
 *  PublisherForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> PublisherForms </code> are requested to the <code> 
 *  Publisher </code> <code> Id </code> that is to be updated using <code> 
 *  getPublisherFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> PublisherForm </code> may be used to link the request. 
 *  Similarly, the <code> PublisherForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> PublisherForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> PublisherForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  PublisherForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updatePublishers(), </code> errors specific to an individual <code> 
 *  PublisherForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> PublisherForm </code> through the <code> 
 *  PublisherForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Publishers </code> in bulk. Bulk 
 *  delete operations return the results in <code> DeleteResponses. </code> 
 *  </p>
 */

public interface PublisherBatchAdminSession
    extends org.osid.subscription.PublisherAdminSession {


    /**
     *  Gets the publisher forms for creating a bunch of new publishers. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  publisherRecordTypes array of publisher record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the publisher forms 
     *  @throws org.osid.NullArgumentException <code> publisherRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.batch.PublisherBatchFormList getPublisherFormsForCreate(long number, 
                                                                                         org.osid.type.Type[] publisherRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Publishers. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  publisherForms the publisher forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> publisherForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createPublishers(org.osid.subscription.batch.PublisherBatchFormList publisherForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the publisher forms for updating an existing set of publishers. A 
     *  new publisher form should be requested for each update transaction. 
     *
     *  @param  publisherIds the <code> Ids </code> of the <code> Publisher 
     *          </code> 
     *  @return the publisher form 
     *  @throws org.osid.NotFoundException a <code> publisherId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> publisherIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.batch.PublisherBatchFormList getPublisherFormsForUpdate(org.osid.id.IdList publisherIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing publishers. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  publisherForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> publisherForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updatePublishers(org.osid.subscription.batch.PublisherBatchFormList publisherForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Publishers. </code> 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllPublishers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes publishers for the given <code> Ids. </code> 
     *
     *  @param  publisherIds the <code> Ids </code> of the publishers to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> publisherIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deletePublishers(org.osid.id.IdList publisherIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Publisher </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Publisher </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another publisher, it is reassigned to the given 
     *  publisher <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasPublishers(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
