//
// org.osid.subscription.rules.SubscriptionEnablerNotificationSession
//
//     The OSID Java specification for org.osid.subscription.rules.SubscriptionEnablerNotificationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription.rules;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> SubscriptionEnabler </code> objects in this <code> Subscription. 
 *  </code> This also includes existing <code> SubscriptionEnablers </code> 
 *  that may appear or disappear due to changes in the <code> Subscription 
 *  </code> hierarchy, This session is intended for consumers needing to 
 *  synchronize their state with this service without the use of polling. 
 *  Notifications are cancelled when this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> SubscriptionEnablerLookupSession. </code> </p>
 */

public interface SubscriptionEnablerNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Publisher </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Publisher Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPublisherId();


    /**
     *  Gets the <code> Publisher </code> associated with this session. 
     *
     *  @return the publisher 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.Publisher getPublisher()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> SubscriptionEnabler </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForSubscriptionEnablerNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include subscription enablers in publishers which are children of this 
     *  publisher in the publisher hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedPublisherView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this publisher only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedPublisherView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> 
     *  acknowledgeSubscriptionEnablerNotification() </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableSubscriptionEnablerNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableSubscriptionEnablerNotifications();


    /**
     *  Acknowledge a subscription enabler notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeSubscriptionEnablerNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new subscription enablers. <code> 
     *  SubscriptionEnablerReceiver.newSubscriptionEnablers() </code> is 
     *  invoked when a new <code> SubscriptionEnabler </code> appears in this 
     *  publisher. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewSubscriptionEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated subscription enabelrs. <code> 
     *  SubscriptionEnablerReceiver.changedSubscriptionEnablers() </code> is 
     *  invoked when a subscription enabler in this publisher is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedSubscriptionEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated subscription enabler. <code> 
     *  ProvisionableReceiver.changedSubscriptionEnablers() </code> is invoked 
     *  when the specified subscription enabler in this publisher is changed. 
     *
     *  @param  subscriptionEnablerId the <code> Id </code> of the <code> 
     *          SubscriptionEnabler </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> subscriptionEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedSubscriptionEnabler(org.osid.id.Id subscriptionEnablerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted subscription enablers. <code> 
     *  SubscriptionEnablerReceiver.deletedSubscriptionEnablers() </code> is 
     *  invoked when a subscription enabler is deleted or removed from this 
     *  publisher. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedSubscriptionEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted subscription enabler. <code> 
     *  SubscriptionEnablerReceiver.deletedSubscriptionEnablers() </code> is 
     *  invoked when the specified subscription enabler is deleted or removed 
     *  from this publisher. 
     *
     *  @param  subscriptionEnablerId the <code> Id </code> of the <code> 
     *          SubscriptionEnabler </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> subscriptionEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedSubscriptionEnabler(org.osid.id.Id subscriptionEnablerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
