//
// org.osid.subscription.rules.SubscriptionEnablerQuery
//
//     The OSID Java specification for org.osid.subscription.rules.SubscriptionEnablerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription.rules;


/**
 *  <p>This is the query for searching subscription enablers. Each method 
 *  match specifies an <code> AND </code> term while multiple invocations of 
 *  the same method produce a nested <code> OR. </code> </p>
 */

public interface SubscriptionEnablerQuery
    extends org.osid.OsidEnablerQuery {


    /**
     *  Matches enablers mapped to the subscription. 
     *
     *  @param  subscriptionId the subscription <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> subscriptionId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledSubscriptionId(org.osid.id.Id subscriptionId, 
                                         boolean match);


    /**
     *  Clears the subscription <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledSubscriptionIdTerms();


    /**
     *  Tests if a <code> SubscriptionQuery </code> is available. 
     *
     *  @return <code> true </code> if a subscription query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledSubscriptionQuery();


    /**
     *  Gets the query for a subscription. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the subscription query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledSubscriptionQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledSubscriptionQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.SubscriptionQuery getRuledSubscriptionQuery();


    /**
     *  Matches enablers mapped to any subscription. 
     *
     *  @param  match <code> true </code> for enablers mapped to any 
     *          subscription, <code> false </code> to match enablers mapped to 
     *          no subscription 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledSubscription(boolean match);


    /**
     *  Clears the subscription query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledSubscriptionTerms();


    /**
     *  Matches enablers mapped to the publisher. 
     *
     *  @param  publisherId the publisher <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPublisherId(org.osid.id.Id publisherId, boolean match);


    /**
     *  Clears the publisher <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPublisherIdTerms();


    /**
     *  Tests if a <code> PublisherQuery </code> is available. 
     *
     *  @return <code> true </code> if a publisher query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPublisherQuery();


    /**
     *  Gets the query for a publisher. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the publisher query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPublisherQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPublisherQuery() </code> is <code> true. </code> 
     */

    public org.osid.subscription.PublisherQuery getPublisherQuery();


    /**
     *  Clears the publisher query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPublisherTerms();


    /**
     *  Gets the subscription enabler query record corresponding to the given 
     *  <code> SubscriptionEnabler </code> record <code> Type. </code> 
     *  Multiple record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  subscriptionEnablerRecordType a subscription enabler record 
     *          type 
     *  @return the subscription enabler query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          subscriptionEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(subscriptionEnablerRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.rules.records.SubscriptionEnablerQueryRecord getSubscriptionEnablerQueryRecord(org.osid.type.Type subscriptionEnablerRecordType)
        throws org.osid.OperationFailedException;
}
