//
// org.osid.topology.EdgeAdminSession
//
//     The OSID Java specification for org.osid.topology.EdgeAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology;


/**
 *  <p>This session creates, updates, and deletes <code> Edges. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Edge, </code> an <code> EdgeForm </code> is requested using <code> 
 *  geEdgeFormForCreate() </code> specifying the <code> nodes </code> and 
 *  desired record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. The returned <code> EdgeForm </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once the <code> EdgeForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> EdgeForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> EdgeForms </code> are requested to the <code> Edge 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getEdgeFormForUpdate(). </code> Similarly, the <code> EdgeForm </code> has 
 *  metadata about the data that can be updated and it can perform validation 
 *  before submitting the update. The <code> EdgeForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Edges. </code> To unmap an <code> 
 *  Edge </code> from the current <code> Graph, </code> the <code> 
 *  EdgeGraphAssignmentSession </code> should be used. These delete operations 
 *  attempt to remove the <code> Edge </code> itself thus removing it from all 
 *  known <code> Graph </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface EdgeAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Graph </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Graph Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGraphId();


    /**
     *  Gets the <code> Graph </code> associated with this session. 
     *
     *  @return the graph 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.Graph getGraph()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Edges. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> Edge </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Edge </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateEdges();


    /**
     *  Tests if this user can create a single <code> Edge </code> using the 
     *  desired record types. While <code> 
     *  TopologyManager.getEdgeRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Edge. </code> Providing an 
     *  empty array tests if an <code> Edge </code> can be created with no 
     *  records. 
     *
     *  @param  edgeRecordTypes array of edge record types 
     *  @return <code> true </code> if <code> Edge </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> edgeRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateEdgeWithRecordTypes(org.osid.type.Type[] edgeRecordTypes);


    /**
     *  Gets the edge form for creating new edges. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  sourceNodeId the <code> Id </code> of the starting node. 
     *  @param  destinationNodeId the <code> Id </code> of the ending node. 
     *  @param  edgeRecordTypes array of edge record types 
     *  @return the edge form 
     *  @throws org.osid.NotFoundException <code> sourceNodeId </code> or 
     *          <code> destinationNodeId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> sourceNodeId, 
     *          destinationNodeId, </code> or <code> edgeRecordTypes </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.EdgeForm getEdgeFormForCreate(org.osid.id.Id sourceNodeId, 
                                                           org.osid.id.Id destinationNodeId, 
                                                           org.osid.type.Type[] edgeRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Edge. </code> 
     *
     *  @param  edgeForm the form for this <code> Edge </code> 
     *  @return the new <code> Edge </code> 
     *  @throws org.osid.IllegalStateException <code> edgeForm </code> already 
     *          used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> edgeForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> edgeForm </code> did not 
     *          originate from <code> getEdgeFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.Edge createEdge(org.osid.topology.EdgeForm edgeForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Edges. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> Edge </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Edge </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateEdges();


    /**
     *  Gets the edge form for updating an existing edge. A new edge form 
     *  should be requested for each update transaction. 
     *
     *  @param  edgeId the <code> Id </code> of the <code> Edge </code> 
     *  @return the edge form 
     *  @throws org.osid.NotFoundException <code> edgeId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> edgeId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.EdgeForm getEdgeFormForUpdate(org.osid.id.Id edgeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing edge. 
     *
     *  @param  edgeForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> edgeForm </code> already 
     *          used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> edgeForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> edgeForm </code> did not 
     *          originate from <code> getEdgeFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateEdge(org.osid.topology.EdgeForm edgeForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Edges. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> Edge </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Edge </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteEdges();


    /**
     *  Deletes an <code> Edge. </code> 
     *
     *  @param  edgeId the <code> Id </code> of the <code> Edge </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> edgeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> edgeId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteEdge(org.osid.id.Id edgeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for edges. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known changing an alias will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer alias operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Edge </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageEdgeAliases();


    /**
     *  Adds an <code> Id </code> to an <code> Edge </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Edge </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another edge, it is reassigned to the given edge <code> 
     *  Id. </code> 
     *
     *  @param  edgeId the <code> Id </code> of an <code> Edge </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> edgeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> edgeId </code> or <code> 
     *          aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasEdge(org.osid.id.Id edgeId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
