//
// org.osid.topology.EdgeSearchSession
//
//     The OSID Java specification for org.osid.topology.EdgeSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology;


/**
 *  <p>This session provides methods for searching among <code> Edge </code> 
 *  objects. The search query is constructed using the <code> EdgeQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getEdgesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Edges. </code> A more advanced search may be 
 *  performed with <code> getEdgesBySearch(). </code> It accepts an <code> 
 *  EdgeSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getEdgesBySearch() </code> returns an <code> EdgesSearchResults </code> 
 *  that can be used to access the resulting <code> EdgeList </code> or be 
 *  used to perform a search within the result set through <code> EdgeSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated graph view: searches include edges in graphs of which 
 *      this graph is an ancestor in the graph hierarchy </li> 
 *      <li> isolated graph view: searches are restricted to edges in this 
 *      graph </li> 
 *  </ul>
 *  
 *  
 *  <p> Edges may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> EdgeQuery. </code> </p>
 */

public interface EdgeSearchSession
    extends org.osid.topology.EdgeQuerySession {


    /**
     *  Gets an edge search. 
     *
     *  @return the edge search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.EdgeSearch getEdgeSearch();


    /**
     *  Gets an edge search order. The <code> EdgeSearchOrder </code> is 
     *  supplied to an <code> EdgeSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the edge search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.EdgeSearchOrder getEdgeSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  edgeQuery the edge query 
     *  @param  edgeSearch the edge search 
     *  @return the edge search results 
     *  @throws org.osid.NullArgumentException <code> edgeQuery </code> or 
     *          <code> edgeSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> edgeQuery </code> or 
     *          <code> edgeSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.EdgeSearchResults getEdgesBySearch(org.osid.topology.EdgeQuery edgeQuery, 
                                                                org.osid.topology.EdgeSearch edgeSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an edge query from an inspector. The inspector is available from 
     *  an <code> EdgeSearchResults. </code> 
     *
     *  @param  edgeQueryInspector an edge query inspector 
     *  @return the edge query 
     *  @throws org.osid.NullArgumentException <code> edgeQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> edgeQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.EdgeQuery getEdgeQueryFromInspector(org.osid.topology.EdgeQueryInspector edgeQueryInspector);
}
