//
// org.osid.topology.EdgeSmartGraphSession
//
//     The OSID Java specification for org.osid.topology.EdgeSmartGraphSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. An <code> EdgeQuery </code> can be retrieved from this session 
 *  and mapped to this <code> Graph </code> to create a virtual collection of 
 *  <code> Edges. </code> The entries may be sequenced using the <code> 
 *  EdgeSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Graph </code> has a default query that matches any edge 
 *  and a default search order that specifies no sequencing. The queries may 
 *  be examined using an <code> EdgeQueryInspector. </code> The query may be 
 *  modified by converting the inspector back to an <code> EdgeQuery. </code> 
 *  </p>
 */

public interface EdgeSmartGraphSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Graph </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Graph Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGraphId();


    /**
     *  Gets the <code> Graph </code> associated with this session. 
     *
     *  @return the graph 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.Graph getGraph()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart graphs. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer smart operations. 
     *
     *  @return <code> false </code> if smart graph methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartGraphs();


    /**
     *  Gets an edge query. 
     *
     *  @return the edge query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.EdgeQuery getEdgeQuery();


    /**
     *  Gets an edge search order. 
     *
     *  @return the edge search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.EdgeSearchOrder getEdgeSearchOrder();


    /**
     *  Applies an edge query to this graph. 
     *
     *  @param  edgeQuery the edge query 
     *  @throws org.osid.NullArgumentException <code> edgeQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> edgeQuery </code> not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyEdgeQuery(org.osid.topology.EdgeQuery edgeQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an edge query inspector for this graph. 
     *
     *  @return the edge query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.EdgeQueryInspector inspectEdgeQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an edge search order to this graph. 
     *
     *  @param  edgeSearchOrder the edge search order 
     *  @throws org.osid.NullArgumentException <code> edgeSearchOrder </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> edgeSearchOrder </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyEdgeSequencing(org.osid.topology.EdgeSearchOrder edgeSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an edge query from an inspector. 
     *
     *  @param  edgeQueryInspector an edge query inspector 
     *  @return the edge query 
     *  @throws org.osid.NullArgumentException <code> 
     *          relatinshipQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> edgeQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.EdgeQuery getEdgeQueryFromInspector(org.osid.topology.EdgeQueryInspector edgeQueryInspector);
}
