//
// org.osid.topology.GraphQuery
//
//     The OSID Java specification for org.osid.topology.GraphQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology;


/**
 *  <p>This is the query for searching graphs. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface GraphQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the node <code> Id </code> for this query to match graphs that 
     *  have a related node. 
     *
     *  @param  nodeId a node <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> nodeId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchNodeId(org.osid.id.Id nodeId, boolean match);


    /**
     *  Clears the node <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNodeIdTerms();


    /**
     *  Tests if a <code> NodeQuery </code> is available. 
     *
     *  @return <code> true </code> if a node query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNodeQuery();


    /**
     *  Gets the query for a node. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the node query 
     *  @throws org.osid.UnimplementedException <code> supportsNodeQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNodeQuery() </code> is <code> true. </code> 
     */

    public org.osid.topology.NodeQuery getNodeQuery();


    /**
     *  Matches graphs that have any node. 
     *
     *  @param  match <code> true </code> to match graphs with any node, 
     *          <code> false </code> to match graphs with no node 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyNode(boolean match);


    /**
     *  Clears the node terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNodeTerms();


    /**
     *  Sets the edge <code> Id </code> for this query to match graphs 
     *  containing edges. 
     *
     *  @param  edgeId the edge <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> edgeId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEdgeId(org.osid.id.Id edgeId, boolean match);


    /**
     *  Clears the edge <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEdgeIdTerms();


    /**
     *  Tests if an <code> EdgeQuery </code> is available. 
     *
     *  @return <code> true </code> if an edge query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEdgeQuery();


    /**
     *  Gets the query for an edge. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the edge query 
     *  @throws org.osid.UnimplementedException <code> supportsEdgeQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeQuery() </code> is <code> true. </code> 
     */

    public org.osid.topology.EdgeQuery getEdgeQuery();


    /**
     *  Matches graphs that have any edge. 
     *
     *  @param  match <code> true </code> to match graphs with any edge, 
     *          <code> false </code> to match graphs with no edge 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEdge(boolean match);


    /**
     *  Clears the edge terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEdgeTerms();


    /**
     *  Sets the graph <code> Id </code> for this query to match graphs that 
     *  have the specified graph as an ancestor. 
     *
     *  @param  graphId a graph <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorGraphId(org.osid.id.Id graphId, boolean match);


    /**
     *  Clears the ancestor graph <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorGraphIdTerms();


    /**
     *  Tests if a <code> GraphQuery </code> is available. 
     *
     *  @return <code> true </code> if a graph query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorGraphQuery();


    /**
     *  Gets the query for a graph. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the graph query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorGraphQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorGraphQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.GraphQuery getAncestorGraphQuery();


    /**
     *  Matches graphs with any ancestor. 
     *
     *  @param  match <code> true </code> to match graphs with any ancestor, 
     *          <code> false </code> to match root graphs 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorGraph(boolean match);


    /**
     *  Clears the ancestor graph terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorGraphTerms();


    /**
     *  Sets the graph <code> Id </code> for this query to match graphs that 
     *  have the specified graph as a descendant. 
     *
     *  @param  graphId a graph <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantGraphId(org.osid.id.Id graphId, boolean match);


    /**
     *  Clears the descendant graph <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantGraphIdTerms();


    /**
     *  Tests if a <code> GraphQuery </code> is available. 
     *
     *  @return <code> true </code> if a graph query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantGraphQuery();


    /**
     *  Gets the query for a graph. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the graph query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantGraphQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantGraphQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.GraphQuery getDescendantGraphQuery();


    /**
     *  Matches graphs with any descendant. 
     *
     *  @param  match <code> true </code> to match graphs with any descendant, 
     *          <code> false </code> to match leaf graphs 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantGraph(boolean match);


    /**
     *  Clears the descendant graph terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantGraphTerms();


    /**
     *  Gets the graph query record corresponding to the given <code> Graph 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  graphRecordType a graph record type 
     *  @return the graph query record 
     *  @throws org.osid.NullArgumentException <code> graphRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(graphRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.records.GraphQueryRecord getGraphQueryRecord(org.osid.type.Type graphRecordType)
        throws org.osid.OperationFailedException;
}
