//
// org.osid.topology.GraphQueryInspector
//
//     The OSID Java specification for org.osid.topology.GraphQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology;


/**
 *  <p>This is the query inspector for examining graph queries. </p>
 */

public interface GraphQueryInspector
    extends org.osid.OsidCatalogQueryInspector {


    /**
     *  Gets the node <code> Id </code> terms. 
     *
     *  @return the node <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getNodeIdTerms();


    /**
     *  Gets the node terms. 
     *
     *  @return the node terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.NodeQueryInspector[] getNodeTerms();


    /**
     *  Gets the edge <code> Id </code> terms. 
     *
     *  @return the edge <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getEdgeIdTerms();


    /**
     *  Gets the edge terms. 
     *
     *  @return the edge terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.EdgeQueryInspector[] getEdgeTerms();


    /**
     *  Gets the ancestor graph <code> Id </code> terms. 
     *
     *  @return the ancestor graph <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorGraphIdTerms();


    /**
     *  Gets the ancestor graph terms. 
     *
     *  @return the ancestor graph terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.GraphQueryInspector[] getAncestorGraphTerms();


    /**
     *  Gets the descendant graph <code> Id </code> terms. 
     *
     *  @return the descendant graph <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantGraphIdTerms();


    /**
     *  Gets the descendant graph terms. 
     *
     *  @return the descendant graph terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.GraphQueryInspector[] getDescendantGraphTerms();


    /**
     *  Gets thegraph query inspector record corresponding to the given <code> 
     *  Graph </code> record <code> Type. </code> 
     *
     *  @param  graphRecordType a graph record type 
     *  @return the graph query inspector record 
     *  @throws org.osid.NullArgumentException <code> graphRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(graphRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.records.GraphQueryInspectorRecord getGraphQueryInspectorRecord(org.osid.type.Type graphRecordType)
        throws org.osid.OperationFailedException;
}
