//
// org.osid.topology.NodeSmartGraphSession
//
//     The OSID Java specification for org.osid.topology.NodeSmartGraphSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> NodeQuery </code> can be retrieved from this session 
 *  and mapped to this <code> Graph </code> to create a virtual collection of 
 *  <code> Nodes. </code> The entries may be sequenced using the <code> 
 *  NodeSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Graph </code> has a default query that matches any node 
 *  and a default search order that specifies no sequencing. The queries may 
 *  be examined using a <code> NodeQueryInspector. </code> The query may be 
 *  modified by converting the inspector back to a <code> NodeQuery. </code> 
 *  </p>
 */

public interface NodeSmartGraphSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Familt </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Graph Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGraphId();


    /**
     *  Gets the <code> Graph </code> associated with this session. 
     *
     *  @return the graph 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.Graph getGraph()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart graphs. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer smart operations. 
     *
     *  @return <code> false </code> if smart graph methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartGraphs();


    /**
     *  Gets a node query. 
     *
     *  @return the node query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.NodeQuery getNodeQuery();


    /**
     *  Gets a node search order. 
     *
     *  @return the node search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.NodeSearchOrder getNodeSearchOrder();


    /**
     *  Applies a node query to this graph. 
     *
     *  @param  nodeQuery the node query 
     *  @throws org.osid.NullArgumentException <code> nodeQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> nodeQuery </code> not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyNodeQuery(org.osid.topology.NodeQuery nodeQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a node query inspector for this graph. 
     *
     *  @return the node query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.NodeQueryInspector inspectNodeQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a node search order to this graph. 
     *
     *  @param  nodeSearchOrder the node search order 
     *  @throws org.osid.NullArgumentException <code> nodeSearchOrder </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> nodeSearchOrder </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyNodeSequencing(org.osid.topology.NodeSearchOrder nodeSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a node query from an inspector. 
     *
     *  @param  nodeQueryInspector a node query inspector 
     *  @return the node query 
     *  @throws org.osid.NullArgumentException <code> 
     *          relatinshipQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> nodeQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.NodeQuery getNodeQueryFromInspector(org.osid.topology.NodeQueryInspector nodeQueryInspector);
}
