//
// org.osid.topology.TopologyRoutingSession
//
//     The OSID Java specification for org.osid.topology.TopologyRoutingSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology;


/**
 *  <p>This session defines methods to route between nodes. </p>
 */

public interface TopologyRoutingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Graph </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Graph Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGraphId();


    /**
     *  Gets the <code> Graph </code> associated with this session. 
     *
     *  @return the graph 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.Graph getGraph()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can traverse the topology. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if topology methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canTraverseTopology();


    /**
     *  The returns from the traversal methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeNodeView();


    /**
     *  A complete view of the method returns is desired. Methods will return 
     *  what is requested or result in an error. This view is used when 
     *  greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryNodeView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include edges in graphs which are children of this graph in the graph 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedGraphView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this graph only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedGraphView();


    /**
     *  Gets all the edges forming shortest path by number of node hops 
     *  between two nodes. 
     *
     *  @param  startNodeId the starting node <code> Id </code> 
     *  @param  endNodeId the ending node <code> Id </code> 
     *  @return a list of edges 
     *  @throws org.osid.NotFoundException <code> startNodeId </code> or 
     *          <code> endNodeId </code> is not found or not connected 
     *  @throws org.osid.NullArgumentException <code> startNodeId </code> or 
     *          <code> endNodeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.EdgeList findShortestPathByHops(org.osid.id.Id startNodeId, 
                                                             org.osid.id.Id endNodeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all the edges forming shortest path by total distance between two 
     *  nodes. 
     *
     *  @param  startNodeId the starting node <code> Id </code> 
     *  @param  endNodeId the ending node <code> Id </code> 
     *  @return a list of edges 
     *  @throws org.osid.NotFoundException <code> startNodeId </code> or 
     *          <code> endNodeId </code> is not found or not connected 
     *  @throws org.osid.NullArgumentException <code> startNodeId </code> or 
     *          <code> endNodeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.EdgeList findShortestPathByDistance(org.osid.id.Id startNodeId, 
                                                                 org.osid.id.Id endNodeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all the edges forming lowest cost path between two nodes. 
     *
     *  @param  startNodeId the starting node <code> Id </code> 
     *  @param  endNodeId the ending node <code> Id </code> 
     *  @return a list of edges 
     *  @throws org.osid.NotFoundException <code> startNodeId </code> or 
     *          <code> endNodeId </code> is not found or not connected 
     *  @throws org.osid.NullArgumentException <code> startNodeId </code> or 
     *          <code> endNodeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.EdgeList findCheapestPath(org.osid.id.Id startNodeId, 
                                                       org.osid.id.Id endNodeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if there is an active path between the two given nodes. 
     *
     *  @param  startNodeId the starting node <code> Id </code> 
     *  @param  endNodeId the ending node <code> Id </code> 
     *  @return <code> true </code> if a path exists, <code> false </code> 
     *          otherwise 
     *  @throws org.osid.NullArgumentException <code> startNodeId </code> or 
     *          <code> endNodeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean areNodesConnected(org.osid.id.Id startNodeId, 
                                     org.osid.id.Id endNodeId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
