//
// org.osid.topology.batch.EdgeBatchAdminSession
//
//     The OSID Java specification for org.osid.topology.batch.EdgeBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Edges </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Edge, </code> an <code> EdgeForm </code> is requested using <code> 
 *  getEdgeFormsForCreate() </code> specifying the desired record <code> Types 
 *  </code> or none if no record <code> Types </code> are needed. Each of the 
 *  returned <code> EdgeForms </code> will indicate that it is to be used with 
 *  a create operation and can be used to examine metdata or validate data 
 *  prior to creation. Once an <code> EdgeForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> EdgeForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> EdgeForms </code> returned from <code> 
 *  getEdgeFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> EdgeForm. </code> In the 
 *  case where there may be duplicates, any <code> EdgeForm </code> of the 
 *  same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> EdgeForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> EdgeForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createEdges(), 
 *  </code> errors specific to an individual <code> EdgeForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> EdgeForm 
 *  </code> through the <code> EdgeForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> EdgeForms </code> are requested to the <code> Edge 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getEdgeFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> EdgeForm </code> may be used to link the request. Similarly, 
 *  the <code> EdgeForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> EdgeForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> EdgeForms </code> are submitted for update, an 
 *  <code> UpdateResponse </code> is returned for each <code> EdgeForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateEdges(), 
 *  </code> errors specific to an individual <code> EdgeForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> EdgeForm 
 *  </code> through the <code> EdgeForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Edges </code> in bulk. To unmap an 
 *  <code> Edge </code> from the current <code> Graph, </code> the <code> 
 *  EdgeGraphAssignmentSession </code> should be used. These delete operations 
 *  attempt to remove the <code> Edge </code> itself thus removing it from all 
 *  known <code> Graph </code> catalogs. Bulk delete operations return the 
 *  results in <code> DeleteResponses. </code> </p>
 */

public interface EdgeBatchAdminSession
    extends org.osid.topology.EdgeAdminSession {


    /**
     *  Gets the edge forms for creating a bunch of new edges. A form is 
     *  returned for each set of edge peers. 
     *
     *  @param  peers a list of edge peers 
     *  @param  edgeRecordTypes array of edge record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the edge forms 
     *  @throws org.osid.NotFoundException a node is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          edgeRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.batch.EdgeBatchFormList getEdgeFormsForCreate(org.osid.topology.batch.EdgePeerList peers, 
                                                                           org.osid.type.Type[] edgeRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Edges. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  edgeForms the edge forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> edgeForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createEdges(org.osid.topology.batch.EdgeBatchFormList edgeForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the edge forms for updating an existing set of edges. A new edge 
     *  form should be requested for each update transaction. 
     *
     *  @param  edgeIds the <code> Ids </code> of the <code> Edge </code> 
     *  @return the edge form 
     *  @throws org.osid.NotFoundException an <code> edgeId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> edgeIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.batch.EdgeBatchFormList getEdgeFormsForUpdate(org.osid.id.IdList edgeIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing edges. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  edgeForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> edgeForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateEdges(org.osid.topology.batch.EdgeBatchFormList edgeForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Edges </code> in this <code> Graph </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllEdges()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes edges for the given <code> Ids. </code> 
     *
     *  @param  edgeIds the <code> Ids </code> of the edges to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> edgeIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteEdges(org.osid.id.IdList edgeIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes edges for the given source node. 
     *
     *  @param  sourceNodeId the <code> Id </code> of a node 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> sourceNodeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteEdgesForSourceNode(org.osid.id.Id sourceNodeId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes edges for the given destination node. 
     *
     *  @param  destinationNodeId the <code> Id </code> of a node 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> destinationNodeId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteEdgesForDestinationNode(org.osid.id.Id destinationNodeId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes edges ineffective before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveEdgesByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> Edge </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Edge </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another edge, it is reassigned to the given edge <code> Id. 
     *  </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasEdges(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
