//
// org.osid.topology.path.PathGraphAssignmentSession
//
//     The OSID Java specification for org.osid.topology.path.PathGraphAssignmentSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology.path;


/**
 *  <p>This session provides methods to re-assign <code> Paths </code> to 
 *  <code> Graph </code> objects. A <code> Path </code> may appear in multiple 
 *  <code> Graph </code> objects and removing the last reference to a <code> 
 *  Path </code> is the equivalent of deleting it. Each <code> Graph </code> 
 *  may have its own authorizations governing who is allowed to operate on it. 
 *  </p> 
 *  
 *  <p> Adding a reference of a <code> Path </code> to another <code> Graph 
 *  </code> is not a copy operation (eg: does not change its <code> Id </code> 
 *  ). </p>
 */

public interface PathGraphAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter path/graph mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known location methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer assignment operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignPaths();


    /**
     *  Tests if this user can alter path/graph mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignPathsToGraph(org.osid.id.Id graphId);


    /**
     *  Gets a list of graphs including and under the given graph node in 
     *  which any path can be assigned. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return list of assignable graph <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableGraphIds(org.osid.id.Id graphId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of graphs including and under the given graph node in 
     *  which a specific path can be assigned. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @param  pathId the <code> Id </code> of the <code> Path </code> 
     *  @return list of assignable graph <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> or 
     *          <code> pathId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableGraphIdsForPath(org.osid.id.Id graphId, 
                                                           org.osid.id.Id pathId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Path </code> to a <code> Graph. </code> 
     *
     *  @param  pathId the <code> Id </code> of the <code> Path </code> 
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @throws org.osid.AlreadyExistsException <code> pathId </code> is 
     *          already assigned to <code> graphId </code> 
     *  @throws org.osid.NotFoundException <code> pathId </code> or <code> 
     *          graphId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pathId </code> or <code> 
     *          graphId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignPathToGraph(org.osid.id.Id pathId, 
                                  org.osid.id.Id graphId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Path </code> from a <code> Graph. </code> 
     *
     *  @param  pathId the <code> Id </code> of the <code> Path </code> 
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @throws org.osid.NotFoundException <code> pathId </code> or <code> 
     *          graphId </code> not found or <code> pathId </code> not 
     *          assigned to <code> graphId </code> 
     *  @throws org.osid.NullArgumentException <code> pathId </code> or <code> 
     *          graphId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignPathFromGraph(org.osid.id.Id pathId, 
                                      org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> Path </code> from one <code> Graph </code> to another. 
     *  Mappings to other <code> Graphs </code> are unaffected. 
     *
     *  @param  pathId the <code> Id </code> of the <code> Credit </code> 
     *  @param  fromGraphId the <code> Id </code> of the current <code> Graph 
     *          </code> 
     *  @param  toGraphId the <code> Id </code> of the destination <code> 
     *          Graph </code> 
     *  @throws org.osid.NotFoundException <code> pathId, fromGraphId, </code> 
     *          or <code> toGraphId </code> not found or <code> pathId </code> 
     *          not mapped to <code> fromGraphId </code> 
     *  @throws org.osid.NullArgumentException <code> pathId, fromGraphId, 
     *          </code> or <code> toGraphId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignPathToGraph(org.osid.id.Id pathId, 
                                    org.osid.id.Id fromGraphId, 
                                    org.osid.id.Id toGraphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
