//
// org.osid.topology.path.PathQuery
//
//     The OSID Java specification for org.osid.topology.path.PathQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology.path;


/**
 *  <p>This is the query for searching paths. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface PathQuery
    extends org.osid.OsidRelationshipQuery,
            org.osid.OsidAggregateableQuery {


    /**
     *  Matches paths that are complete. 
     *
     *  @param  match <code> true </code> to match complete paths, <code> 
     *          false </code> to match inactive paths 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchComplete(boolean match);


    /**
     *  Clears the path complete query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompleteTerms();


    /**
     *  Matches paths that are closed. 
     *
     *  @param  match <code> true </code> to match closed paths, <code> false 
     *          </code> to match inactive paths 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchClosed(boolean match);


    /**
     *  Clears the path closed query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearClosedTerms();


    /**
     *  Sets the node <code> Id </code> for this query to match paths with a 
     *  starting node. 
     *
     *  @param  nodeId the node <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> nodeId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStartingNodeId(org.osid.id.Id nodeId, boolean match);


    /**
     *  Clears the starting node <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartingNodeIdTerms();


    /**
     *  Tests if a <code> NodeQuery </code> is available for a starting node. 
     *
     *  @return <code> true </code> if a node query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStartingNodeQuery();


    /**
     *  Gets the query for a starting node. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the node query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStartingNodeQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStartingNodeQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.NodeQuery getStartingNodeQuery();


    /**
     *  Clears the starting node query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartingNodeTerms();


    /**
     *  Sets the node <code> Id </code> for this query to match paths with an 
     *  ending node. 
     *
     *  @param  nodeId the node <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> nodeId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEndingNodeId(org.osid.id.Id nodeId, boolean match);


    /**
     *  Clears the ending node <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEndingNodeIdTerms();


    /**
     *  Tests if a <code> NodeQuery </code> is available for an ending node. 
     *
     *  @return <code> true </code> if a node query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEndingNodeQuery();


    /**
     *  Gets the query for an ending node. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the node query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEndingNodeQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEndingNodeQuery() </code> is <code> true. </code> 
     */

    public org.osid.topology.NodeQuery getEndingNodeQuery();


    /**
     *  Clears the ending node query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEndingNodeTerms();


    /**
     *  Sets the node <code> Ids </code> for this query to match paths along 
     *  the given nodes. 
     *
     *  @param  nodeIds the node <code> Ids </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> nodeIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAlongNodeIds(org.osid.id.Id[] nodeIds, boolean match);


    /**
     *  Clears the along node <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAlongNodeIdsTerms();


    /**
     *  Sets the path <code> Id </code> for this query to match paths 
     *  intersecting with another path. 
     *
     *  @param  pathId the path <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchIntersectingPathId(org.osid.id.Id pathId, boolean match);


    /**
     *  Clears the intersecting path <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIntersectingPathIdTerms();


    /**
     *  Tests if a <code> PathQuery </code> is available for intersecting 
     *  paths, 
     *
     *  @return <code> true </code> if a path query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIntersectingPathQuery();


    /**
     *  Gets the query for an intersecting path, Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the path query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsIntersectingPathQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsIntersectingPathQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.path.PathQuery getIntersectingPathQuery();


    /**
     *  Matches paths with any intersecting path, 
     *
     *  @param  match <code> true </code> to match paths with any intersecting 
     *          path, <code> false </code> to match paths with no intersecting 
     *          path 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyIntersectingPath(boolean match);


    /**
     *  Clears the intersecting path query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIntersectingPathTerms();


    /**
     *  Matches paths that have a number of hops within the given range 
     *  inclusive. 
     *
     *  @param  from starting range 
     *  @param  to ending range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchHops(long from, long to, boolean match);


    /**
     *  Clears the number of hops query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearHopsTerms();


    /**
     *  Matches paths that have a distance with the given range inclusive. 
     *
     *  @param  from starting range 
     *  @param  to ending range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDistance(java.math.BigDecimal from, 
                              java.math.BigDecimal to, boolean match);


    /**
     *  Matches paths that has any distance assigned. 
     *
     *  @param  match <code> true </code> to match paths with any distance, 
     *          <code> false </code> to match paths with no distance assigned 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDistance(boolean match);


    /**
     *  Clears the distance query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistanceTerms();


    /**
     *  Matches paths that have a cost with the given range inclusive. 
     *
     *  @param  from starting range 
     *  @param  to ending range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCost(java.math.BigDecimal from, java.math.BigDecimal to, 
                          boolean match);


    /**
     *  Clears the cost query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCostTerms();


    /**
     *  Sets the node <code> Id </code> for this query to match paths that 
     *  pass through nodes. 
     *
     *  @param  nodeId the node <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> nodeId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchNodeId(org.osid.id.Id nodeId, boolean match);


    /**
     *  Clears the node <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNodeIdTerms();


    /**
     *  Tests if a <code> NodeQuery </code> is available. 
     *
     *  @return <code> true </code> if a node query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNodeQuery();


    /**
     *  Gets the query for a node. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the node query 
     *  @throws org.osid.UnimplementedException <code> supportsNodeQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNodeQuery() </code> is <code> true. </code> 
     */

    public org.osid.topology.NodeQuery getNodeQuery();


    /**
     *  Clears the node query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNodeTerms();


    /**
     *  Sets the edge <code> Id </code> for this query to match paths contain 
     *  the edge. 
     *
     *  @param  edgeId the edge <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> edgeId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEdgeId(org.osid.id.Id edgeId, boolean match);


    /**
     *  Clears the edge <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEdgeIdTerms();


    /**
     *  Tests if an <code> EdgeQuery </code> is available. 
     *
     *  @return <code> true </code> if an edge query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEdgeQuery();


    /**
     *  Gets the query for an edge. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the edge query 
     *  @throws org.osid.UnimplementedException <code> supportsEdgeQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeQuery() </code> is <code> true. </code> 
     */

    public org.osid.topology.EdgeQuery getEdgeQuery();


    /**
     *  Clears the edge query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEdgeTerms();


    /**
     *  Sets the graph <code> Id </code> for this query to match edges 
     *  assigned to graphs. 
     *
     *  @param  graphId the graph <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGraphId(org.osid.id.Id graphId, boolean match);


    /**
     *  Clears the graph <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGraphIdTerms();


    /**
     *  Tests if a <code> GraphQuery </code> is available. 
     *
     *  @return <code> true </code> if a graph query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGraphQuery();


    /**
     *  Gets the query for a graph. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the graph query 
     *  @throws org.osid.UnimplementedException <code> supportsGraphQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGraphQuery() </code> is <code> true. </code> 
     */

    public org.osid.topology.GraphQuery getGraphQuery();


    /**
     *  Clears the graph terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGraphTerms();


    /**
     *  Gets the path query record corresponding to the given <code> Path 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  pathRecordType a path record type 
     *  @return the path query record 
     *  @throws org.osid.NullArgumentException <code> pathRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(pathRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.records.PathQueryRecord getPathQueryRecord(org.osid.type.Type pathRecordType)
        throws org.osid.OperationFailedException;
}
