//
// org.osid.topology.path.PathSearchSession
//
//     The OSID Java specification for org.osid.topology.path.PathSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology.path;


/**
 *  <p>This session provides methods for searching among <code> Path </code> 
 *  objects. The search query is constructed using the <code> PathQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getPathsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Paths. </code> A more advanced search may be 
 *  performed with <code> getPathsBySearch(). </code> It accepts a <code> 
 *  PathSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getPathsBySearch() </code> returns a <code> PathSearchResults </code> that 
 *  can be used to access the resulting <code> PathList </code> or be used to 
 *  perform a search within the result set through <code> PathSearch. </code> 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated graph view: searches include paths in graphs of which 
 *      this graph is an ancestor in the graph hierarchy </li> 
 *      <li> isolated graph view: searches are restricted to paths in this 
 *      graph </li> 
 *  </ul>
 *  
 *  
 *  <p> Paths may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> PathQuery. </code> </p>
 */

public interface PathSearchSession
    extends org.osid.topology.path.PathQuerySession {


    /**
     *  Gets a path search. 
     *
     *  @return the path search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathSearch getPathSearch();


    /**
     *  Gets a path search order. The <code> PathSearchOrder </code> is 
     *  supplied to a <code> PathSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the path search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathSearchOrder getPathSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  pathQuery the path query 
     *  @param  pathSearch the path search 
     *  @return the path search results 
     *  @throws org.osid.NullArgumentException <code> pathQuery </code> or 
     *          <code> pathSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> pathQuery </code> or 
     *          <code> pathSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathSearchResults getPathsBySearch(org.osid.topology.path.PathQuery pathQuery, 
                                                                     org.osid.topology.path.PathSearch pathSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a path query from an inspector. The inspector is available from a 
     *  <code> PathSearchResults. </code> 
     *
     *  @param  pathQueryInspector a path query inspector 
     *  @return the path query 
     *  @throws org.osid.NullArgumentException <code> pathQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> pathQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathQuery getPathQueryFromInspector(org.osid.topology.path.PathQueryInspector pathQueryInspector);
}
