//
// org.osid.topology.rules.EdgeEnablerLookupSession
//
//     The OSID Java specification for org.osid.topology.rules.EdgeEnablerLookupSession.
//
// Copyright (C) 2011 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology.rules;


/**
 *  <p>This session provides methods for retrieving <code> EdgeEnablers. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated graph view: All edge enabler methods in this session 
 *      operate, retrieve and pertain to edge enablers defined explicitly in 
 *      the current graph. Using an isolated view is useful for managing 
 *      <code> EdgeEnablers </code> with the <code> EdgeEnablerAdminSession. 
 *      </code> </li> 
 *      <li> federated graph view: All edge enabler methods in this session 
 *      operate, retrieve and pertain to all edge enablers defined in this 
 *      graph and any other edge enablers implicitly available in this graph 
 *      through graph inheritence. </li> 
 *      <li> active edge enabler view: All edge enabler lookup methods return 
 *      active edge enablers. </li> 
 *      <li> any status edge enabler view: Edge enablers of any active or 
 *      inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface EdgeEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Graph </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Graph Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGraphId();


    /**
     *  Gets the <code> Graph </code> associated with this session. 
     *
     *  @return the graph 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.Graph getGraph()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> EdgeEnablers </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupEdgeEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeEdgeEnablerView();


    /**
     *  A complete view of the <code> EdgeEnabler </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryEdgeEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include edge enablers in ontologies which are children of this graph 
     *  in the graph hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedGraphView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this graph only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedGraphView();


    /**
     *  Only active edge enablers are current are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveEdgeEnablerView();


    /**
     *  All active and inactive edge enablers are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusEdgeEnablerView();


    /**
     *  Gets the <code> EdgeEnabler </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  EdgeEnabler </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> EdgeEnabler </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, edge enablers are returned that are currently active. 
     *  In any status mode, active and inactive edge enablers are returned. 
     *
     *  @param  edgeEnablerId <code> Id </code> of the <code> EdgeEnabler 
     *          </code> 
     *  @return the edge enabler 
     *  @throws org.osid.NotFoundException <code> edgeEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.topology.rules.EdgeEnabler getEdgeEnabler(org.osid.id.Id edgeEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EdgeEnablerList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  edge enablers specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> EdgeEnablers </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, edge enablers are returned that are currently active. 
     *  In any status mode, active and inactive edge enablers are returned. 
     *
     *  @param  edgeEnablerIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> EdgeEnabler </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.rules.EdgeEnablerList getEdgeEnablersByIds(org.osid.id.IdList edgeEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EdgeEnablerList </code> corresponding to the given edge 
     *  enabler genus <code> Type </code> which does not include edge enablers 
     *  of genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  edge enablers or an error results. Otherwise, the returned list may 
     *  contain only those edge enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, edge enablers are returned that are currently active. 
     *  In any status mode, active and inactive edge enablers are returned. 
     *
     *  @param  edgeEnablerGenusType an edge enabler genus type 
     *  @return the returned <code> EdgeEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.rules.EdgeEnablerList getEdgeEnablersByGenusType(org.osid.type.Type edgeEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EdgeEnablerList </code> corresponding to the given edge 
     *  enabler genus <code> Type </code> and include any additional edge 
     *  enablers with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  edge enablers or an error results. Otherwise, the returned list may 
     *  contain only those edge enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, edge enablers are returned that are currently active. 
     *  In any status mode, active and inactive edge enablers are returned. 
     *
     *  @param  edgeEnablerGenusType an edge enabler genus type 
     *  @return the returned <code> EdgeEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.rules.EdgeEnablerList getEdgeEnablersByParentGenusType(org.osid.type.Type edgeEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EdgeEnablerList </code> containing the given edge 
     *  enabler record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  edge enablers or an error results. Otherwise, the returned list may 
     *  contain only those edge enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, edge enablers are returned that are currently active. 
     *  In any status mode, active and inactive edge enablers are returned. 
     *
     *  @param  edgeEnablerRecordType an edge enabler record type 
     *  @return the returned <code> EdgeEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.rules.EdgeEnablerList getEdgeEnablersByRecordType(org.osid.type.Type edgeEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EdgeEnablerList </code> which are effective for the 
     *  entire given date range inclusive but not confined to the date range 
     *  for any agent. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  edge enablers or an error results. Otherwise, the returned list may 
     *  contain only those edge enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, edge enablers are returned that are currently active. 
     *  In any status mode, active and inactive edge enablers are returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> EdgeEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.rules.EdgeEnablerList getEdgeEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EdgeEnablerList </code> which are effective for the 
     *  entire given date range inclusive but not confined to the date range 
     *  and evaluated against the given agent. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  edge enablers or an error results. Otherwise, the returned list may 
     *  contain only those edge enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, edge enablers are returned that are currently active. 
     *  In any status mode, active and inactive edge enablers are returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> EdgeEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.rules.EdgeEnablerList getEdgeEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                  org.osid.calendaring.DateTime from, 
                                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> EdgeEnablers. </code> 
     *  
     *  In plenary mode, the returned list contains all known edge enablers or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  edge enablers that are accessible through this session. 
     *  
     *  In active mode, edge enablers are returned that are currently active. 
     *  In any status mode, active and inactive edge enablers are returned. 
     *
     *  @return the returned <code> EdgeEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.rules.EdgeEnablerList getEdgeEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
