//
// org.osid.topology.rules.EdgeEnablerSearchSession
//
//     The OSID Java specification for org.osid.topology.rules.EdgeEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology.rules;


/**
 *  <p>This session provides methods for searching among <code> EdgeEnabler 
 *  </code> objects. The search query is constructed using the <code> 
 *  EdgeEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getEdgeEnablersByQuery() </code> is the basic search method and 
 *  returns a list of <code> EdgeEnablers. </code> A more advanced search may 
 *  be performed with <code> getEdgeEnablersBySearch(). </code> It accepts an 
 *  <code> EdgeEnablerSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getEdgeEnablersBySearch() </code> returns an <code> 
 *  EdgeEnablerSearchResults </code> that can be used to access the resulting 
 *  <code> EdgeEnablerList </code> or be used to perform a search within the 
 *  result set through <code> EdgeEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated graph view: searches include edge enablers in 
 *      ontologies of which this graph is an ancestor in the graph hierarchy 
 *      </li> 
 *      <li> isolated graph view: searches are restricted to edge enablers in 
 *      this graph </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> EdgeEnablers </code> may have a query record indicated by their 
 *  respective record types. The query record is accessed via the <code> 
 *  EdgeEnablerQuery. </code> </p>
 */

public interface EdgeEnablerSearchSession
    extends org.osid.topology.rules.EdgeEnablerQuerySession {


    /**
     *  Gets an edge enabler search. 
     *
     *  @return the edge enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.rules.EdgeEnablerSearch getEdgeEnablerSearch();


    /**
     *  Gets an edge enabler search order. The <code> EdgeEnablerSearchOrder 
     *  </code> is supplied to an <code> EdgeEnablerSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the edge enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.rules.EdgeEnablerSearchOrder getEdgeEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  edgeEnablerQuery the edge enabler query 
     *  @param  edgeEnablerSearch the edge enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerQuery </code> 
     *          or <code> edgeEnablerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> edgeEnablerQuery </code> 
     *          or <code> edgeEnablerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.rules.EdgeEnablerSearchResults getEdgeEnablersBySearch(org.osid.topology.rules.EdgeEnablerQuery edgeEnablerQuery, 
                                                                                    org.osid.topology.rules.EdgeEnablerSearch edgeEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an edge enabler query from an inspector. The inspector is 
     *  available from an <code> EdgeEnablerSearchResults. </code> 
     *
     *  @param  edgeEnablerQueryInspector an edge enabler query inspector 
     *  @return the edge enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          edgeEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> edgeEnablerQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.rules.EdgeEnablerQuery getEdgeEnablerQueryFromInspector(org.osid.topology.rules.EdgeEnablerQueryInspector edgeEnablerQueryInspector);
}
