//
// org.osid.topology.rules.TopologyRulesManager
//
//     The OSID Java specification for org.osid.topology.rules.TopologyRulesManager.
//
// Copyright (C) 2011 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology.rules;


/**
 *  <p>The topology rules manager provides access to topology rules sessions 
 *  and provides interoperability tests for various aspects of this service. 
 *  The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> EdgeEnablerLookupSession: </code> a session to retrieve 
 *      edge enablers </li> 
 *      <li> <code> EdgeEnablerQuerySession: </code> a session to query for 
 *      edge enablers </li> 
 *      <li> <code> EdgeEnablerSearchSession: </code> a session to search for 
 *      edge enablers </li> 
 *      <li> <code> EdgeEnablerAdminSession: </code> a session to create and 
 *      delete edge enablers </li> 
 *      <li> <code> EdgeEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to edge enabler changes </li> 
 *      <li> <code> EdgeEnablerGraphSession: </code> a session to look up edge 
 *      enabler graph mappings </li> 
 *      <li> <code> EdgeEnablerGraphAssignmentSession: </code> a session to 
 *      manage edge enabler to graph mappings </li> 
 *      <li> <code> EdgeEnablerSmartGraphSession: </code> a session to manage 
 *      dynamic ontologies of edge enablers </li> 
 *      <li> <code> EdgeEnablerRuleLookupSession: </code> a session to look up 
 *      edge enabler to edge mappings </li> 
 *      <li> <code> EdgeEnablerRuleApplicationSession: </code> a session to 
 *      apply edge enablers to edges </li> 
 *  </ul>
 *  
 */

public interface TopologyRulesManager
    extends org.osid.OsidManager,
            org.osid.topology.rules.TopologyRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the edge enabler 
     *  lookup service. 
     *
     *  @return an <code> EdgeEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.rules.EdgeEnablerLookupSession getEdgeEnablerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge enabler 
     *  lookup service for the given graph. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return an <code> EdgeEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Graph </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.topology.rules.EdgeEnablerLookupSession getEdgeEnablerLookupSessionForGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge enabler 
     *  query service. 
     *
     *  @return an <code> EdgeEnablerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerQuery() </code> is <code> true. </code> 
     */

    public org.osid.topology.rules.EdgeEnablerQuerySession getEdgeEnablerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge enabler 
     *  query service for the given graph. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return an <code> EdgeEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Graph </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.topology.rules.EdgeEnablerQuerySession getEdgeEnablerQuerySessionForGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge enabler 
     *  search service. 
     *
     *  @return an <code> EdgeEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.rules.EdgeEnablerSearchSession getEdgeEnablerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge enablers 
     *  earch service for the given graph. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return an <code> EdgeEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Graph </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.topology.rules.EdgeEnablerSearchSession getEdgeEnablerSearchSessionForGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge enabler 
     *  administration service. 
     *
     *  @return an <code> EdgeEnablerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerAdmin() </code> is <code> true. </code> 
     */

    public org.osid.topology.rules.EdgeEnablerAdminSession getEdgeEnablerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge enabler 
     *  administration service for the given graph. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return an <code> EdgeEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Graph </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.topology.rules.EdgeEnablerAdminSession getEdgeEnablerAdminSessionForGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge enabler 
     *  notification service. 
     *
     *  @param  edgeEnablerReceiver the notification callback 
     *  @return an <code> EdgeEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.rules.EdgeEnablerNotificationSession getEdgeEnablerNotificationSession(org.osid.topology.rules.EdgeEnablerReceiver edgeEnablerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge enabler 
     *  notification service for the given graph. 
     *
     *  @param  edgeEnablerReceiver the notification callback 
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return an <code> EdgeEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no graph found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerReceiver 
     *          </code> or <code> graphId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.topology.rules.EdgeEnablerNotificationSession getEdgeEnablerNotificationSessionForGraph(org.osid.topology.rules.EdgeEnablerReceiver edgeEnablerReceiver, 
                                                                                                            org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup edge enabler/graph 
     *  mappings for edge enablers. 
     *
     *  @return an <code> EdgeEnablerGraphSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerGraph() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerGraph() </code> is <code> true. </code> 
     */

    public org.osid.topology.rules.EdgeEnablerGraphSession getEdgeEnablerGraphSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning edge 
     *  enablers to ontologies for edge. 
     *
     *  @return an <code> EdgeEnablerGraphAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerGraphAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerGraphAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.topology.rules.EdgeEnablerGraphAssignmentSession getEdgeEnablerGraphAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage edge enabler smart 
     *  ontologies. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return an <code> EdgeEnablerSmartGraphSession </code> 
     *  @throws org.osid.NotFoundException no <code> Graph </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerSmartGraph() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerSmartGraph() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.rules.EdgeEnablerSmartGraphSession getEdgeEnablerSmartGraphSession(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge enabler 
     *  mapping lookup service for looking up the rules applied to the graph. 
     *
     *  @return an <code> EdgeEnablerRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.rules.EdgeEnablerRuleLookupSession getEdgeEnablerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge enabler 
     *  mapping lookup service for the given graph for looking up rules 
     *  applied to a graph. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return an <code> EdgeEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Graph </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.topology.rules.EdgeEnablerRuleLookupSession getEdgeEnablerRuleLookupSessionForGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge enabler 
     *  assignment service to apply enablers to ontologies. 
     *
     *  @return an <code> EdgeEnablerRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerRuleApplication() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.topology.rules.EdgeEnablerRuleApplicationSession getEdgeEnablerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge enabler 
     *  assignment service for the given graph to apply enablers to 
     *  ontologies. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return an <code> EdgeEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Graph </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeEnablerRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.topology.rules.EdgeEnablerRuleApplicationSession getEdgeEnablerRuleApplicationSessionForGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
