//
// org.osid.tracking.FrontOfficeSearchSession
//
//     The OSID Java specification for org.osid.tracking.FrontOfficeSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>This session provides methods for searching among <code> FrontOffice 
 *  </code> objects. The search query is constructed using the <code> 
 *  FrontOfficeQuery. </code> </p> 
 *  
 *  <p> <code> getFrontOfficesByQuery() </code> is the basic search method and 
 *  returns a list of <code> FrontOffices. </code> A more advanced search may 
 *  be performed with <code> getFrontOfficesBySearch(). </code> It accepts a 
 *  <code> FrontOfficeSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getFrontOfficesBySearch() </code> returns a <code> 
 *  FrontOfficeSearchResults </code> that can be used to access the resulting 
 *  <code> FrontOfficeList </code> or be used to perform a search within the 
 *  result set through <code> FrontOfficeSearch. </code> </p> 
 *  
 *  <p> FrontOffices may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  FrontOfficeQuery. </code> </p>
 */

public interface FrontOfficeSearchSession
    extends org.osid.tracking.FrontOfficeQuerySession {


    /**
     *  Gets a front office search. 
     *
     *  @return the front office search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOfficeSearch getFrontOfficeSearch();


    /**
     *  Gets a front office search order. The <code> FrontOfficeSearchOrder 
     *  </code> is supplied to a <code> FrontOfficeSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the front office search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOfficeSearchOrder getFrontOfficeSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  frontOfficeQuery the front office query 
     *  @param  frontOfficeSearch the front office search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> frontOfficeQuery </code> 
     *          or <code> frontOfficeSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> frontOfficeQuery </code> 
     *          or <code> frontOfficeSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOfficeSearchResults getFrontOfficesBySearch(org.osid.tracking.FrontOfficeQuery frontOfficeQuery, 
                                                                              org.osid.tracking.FrontOfficeSearch frontOfficeSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a front office query from an inspector. The inspector is 
     *  available from a <code> FrontOfficeSearchResults. </code> 
     *
     *  @param  frontOfficeQueryInspector a front office query inspector 
     *  @return the front office query 
     *  @throws org.osid.NullArgumentException <code> 
     *          frontOfficeQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> frontOfficeQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOfficeQuery getFrontOfficeQueryFromInspector(org.osid.tracking.FrontOfficeQueryInspector frontOfficeQueryInspector);
}
