//
// org.osid.tracking.IssueForm
//
//     The OSID Java specification for org.osid.tracking.IssueForm.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>This is the form for creating and updating <code> Issues. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> IssueAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface IssueForm
    extends org.osid.OsidRelationshipForm {


    /**
     *  Gets the metadata for the priority type. 
     *
     *  @return metadata for the priority type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPriorityTypeMetadata();


    /**
     *  Sets the priority type. 
     *
     *  @param  priorityType the new priority type 
     *  @throws org.osid.InvalidArgumentException <code> priorityType </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> priorityType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPriorityType(org.osid.type.Type priorityType);


    /**
     *  Removes the priority type. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPriorityType();


    /**
     *  Gets the metadata for the customer. 
     *
     *  @return metadata for the customer 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCustomerMetadata();


    /**
     *  Sets the customer. 
     *
     *  @param  resourceId the new customer 
     *  @throws org.osid.InvalidArgumentException <code> resourceId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCustomer(org.osid.id.Id resourceId);


    /**
     *  Removes the customer. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCustomer();


    /**
     *  Gets the metadata for the topic. 
     *
     *  @return metadata for the topic 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTopicMetadata();


    /**
     *  Sets the topic. 
     *
     *  @param  topicId the new topic 
     *  @throws org.osid.InvalidArgumentException <code> topicId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> topicId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTopic(org.osid.id.Id topicId);


    /**
     *  Removes the topic. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTopic();


    /**
     *  Gets the metadata for the due date. 
     *
     *  @return metadata for the due date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDueDateMetadata();


    /**
     *  Sets the due date. 
     *
     *  @param  topicId the new due date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDueDate(org.osid.calendaring.DateTime topicId);


    /**
     *  Removes the due date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDueDate();


    /**
     *  Gets the <code> IssueFormRecord </code> corresponding to the given 
     *  issue record <code> Type. </code> 
     *
     *  @param  issueRecordType a issue record type 
     *  @return the issue form record 
     *  @throws org.osid.NullArgumentException <code> issueRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(issueRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.records.IssueFormRecord getIssueFormRecord(org.osid.type.Type issueRecordType)
        throws org.osid.OperationFailedException;
}
