//
// org.osid.tracking.IssueLookupSession
//
//     The OSID Java specification for org.osid.tracking.IssueLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>This session defines methods for retrieving issues. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated front office view: All issue methods in this session 
 *      operate, retrieve and pertain to issues defined explicitly in the 
 *      current front office. Using an isolated view is useful for managing 
 *      <code> Issues </code> with the <code> IssueAdminSession. </code> </li> 
 *      <li> federated front office view: All issue lookup methods in this 
 *      session operate, retrieve and pertain to all issues defined in this 
 *      front office and any other issues implicitly available in this front 
 *      office through front office inheritence. </li> 
 *      <li> effective issue view: All issue lookup methods return issues 
 *      where the current date falls in between the effective dates inclusive. 
 *      </li> 
 *      <li> any effective issue view: Issues of any effective date are 
 *      returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedFrontOfficeView() </code> and <code> 
 *  useIsolatedFrontOfficeView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Issues may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Issues. </code> </p>
 */

public interface IssueLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> FrontOffice </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> FrontOffice Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFrontOfficeId();


    /**
     *  Gets the <code> FrontOffice </code> associated with this session. 
     *
     *  @return the front office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOffice getFrontOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Issue </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupIssues();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeIssueView();


    /**
     *  A complete view of the <code> Issue </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryIssueView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include issues in front offices which are children of this front 
     *  office in the front office hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFrontOfficeView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this front office only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFrontOfficeView();


    /**
     *  Only issues whose effective dates are current are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveIssueView();


    /**
     *  All issues of any effective dates are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveIssueView();


    /**
     *  Gets the <code> Issue </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Issue </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to 
     *  an <code> Issue </code> and retained for compatibility. 
     *  
     *  In effective mode, issues are returned that are currently effective. 
     *  In any effective mode, effective issues and those currently expired 
     *  are returned. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> to 
     *          retrieve 
     *  @return the returned <code> Issue </code> 
     *  @throws org.osid.NotFoundException no <code> Issue </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.Issue getIssue(org.osid.id.Id issueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> IssueList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  issues specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Issues </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, issues are returned that are currently effective. 
     *  In any effective mode, effective issues and those currently expired 
     *  are returned. 
     *
     *  @param  issueIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Issue </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> issueIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getIssuesByIds(org.osid.id.IdList issueIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> IssueList </code> corresponding to the given issue 
     *  genus <code> Type </code> which does not include issues of types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  issues or an error results. Otherwise, the returned list may contain 
     *  only those issues that are accessible through this session. 
     *  
     *  In effective mode, issues are returned that are currently effective. 
     *  In any effective mode, effective issues and those currently expired 
     *  are returned. 
     *
     *  @param  issueGenusType an issue genus type 
     *  @return the returned <code> Issue </code> list 
     *  @throws org.osid.NullArgumentException <code> issueGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getIssuesByGenusType(org.osid.type.Type issueGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> IssueList </code> corresponding to the given issue 
     *  genus <code> Type </code> and include any additional issues with genus 
     *  types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  issues or an error results. Otherwise, the returned list may contain 
     *  only those issues that are accessible through this session. 
     *  
     *  In effective mode, issues are returned that are currently effective. 
     *  In any effective mode, effective issues and those currently expired 
     *  are returned. 
     *
     *  @param  issueGenusType an issue genus type 
     *  @return the returned <code> Issue </code> list 
     *  @throws org.osid.NullArgumentException <code> issueGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getIssuesByParentGenusType(org.osid.type.Type issueGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> IssueList </code> containing the given issue record 
     *  <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known issues or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  issues that are accessible through this session. 
     *  
     *  In effective mode, issues are returned that are currently effective. 
     *  In any effective mode, effective issues and those currently expired 
     *  are returned. 
     *
     *  @param  issueRecordType an issue record type 
     *  @return the returned <code> Issue </code> list 
     *  @throws org.osid.NullArgumentException <code> issueRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getIssuesByRecordType(org.osid.type.Type issueRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of issues effective beginning in the date range. Issues 
     *  are returned with a start effective date that falls between the 
     *  requested dates inclusive. 
     *  
     *  In plenary mode, the returned list contains all known issues or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  issues that are accessible through this session. 
     *  
     *  In effective mode, issues are returned that are currently effective in 
     *  addition to being effective in the given date range. In any effective 
     *  mode, effective issues and those currently expired are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Issue </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getIssuesOnDate(org.osid.calendaring.DateTime from, 
                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of issues by queue. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  issues or an error results. Otherwise, the returned list may contain 
     *  only those issues that are accessible through this session. 
     *  
     *  In effective mode, issues are returned that are currently effective. 
     *  In any effective mode, effective issues and those currently expired 
     *  are returned. 
     *
     *  @param  queueId a queue <code> Id </code> 
     *  @return the returned <code> Issue </code> list 
     *  @throws org.osid.NullArgumentException <code> queueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getIssuesForQueue(org.osid.id.Id queueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of issues for a queue effective beginning in the date 
     *  range. Issues are returned with a start effective date that falls 
     *  between the requested dates inclusive. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  issues or an error results. Otherwise, the returned list may contain 
     *  only those issues that are accessible through this session. 
     *  
     *  In effective mode, issues are returned that are currently effective in 
     *  addition to being effective in the given date range. In any effective 
     *  mode, effective issues and those currently expired are returned. 
     *
     *  @param  queueId a queue <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Issue </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> queueId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getIssuesForQueueOnDate(org.osid.id.Id queueId, 
                                                               org.osid.calendaring.DateTime from, 
                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of issues by customer. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  issues or an error results. Otherwise, the returned list may contain 
     *  only those issues that are accessible through this session. 
     *  
     *  In effective mode, issues are returned that are currently effective. 
     *  In any effective mode, effective issues and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Issue </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getIssuesForCustomer(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of issues for a customer effective beginning in the date 
     *  range. Issues are returned with a start effective date that falls 
     *  between the requested dates inclusive. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  issues or an error results. Otherwise, the returned list may contain 
     *  only those issues that are accessible through this session. 
     *  
     *  In effective mode, issues are returned that are currently effective in 
     *  addition to being effective in the given date range. In any effective 
     *  mode, effective issues and those currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Issue </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getIssuesForCustomerOnDate(org.osid.id.Id resourceId, 
                                                                  org.osid.calendaring.DateTime from, 
                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of issues by queue and customer. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  issues or an error results. Otherwise, the returned list may contain 
     *  only those issues that are accessible through this session. 
     *  
     *  In effective mode, issues are returned that are currently effective. 
     *  In any effective mode, effective issues and those currently expired 
     *  are returned. 
     *
     *  @param  queueId a queue <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Issue </code> list 
     *  @throws org.osid.NullArgumentException <code> queueId </code> or 
     *          <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getIssuesForQueueAndCustomer(org.osid.id.Id queueId, 
                                                                    org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of issues for a queue and customer effective beginning in 
     *  the date range. Issues are returned with a start effective date that 
     *  falls between the requested dates inclusive. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  issues or an error results. Otherwise, the returned list may contain 
     *  only those issues that are accessible through this session. 
     *  
     *  In effective mode, issues are returned that are currently effective in 
     *  addition to being effective in the given date range. In any effective 
     *  mode, effective issues and those currently expired are returned. 
     *
     *  @param  queueId a queue <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Issue </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> queueId, resourceId, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getIssuesForQueueAndCustomerOnDate(org.osid.id.Id queueId, 
                                                                          org.osid.id.Id resourceId, 
                                                                          org.osid.calendaring.DateTime from, 
                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all issues. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  issues, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Issues </code> may be omitted from the list. 
     *  
     *  In effective mode, issues are returned that are currently effective. 
     *  In any effective mode, effective issues and those currently expired 
     *  are returned. 
     *
     *  @return the returned <code> Issue </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getIssues()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
