//
// org.osid.tracking.IssueQuery
//
//     The OSID Java specification for org.osid.tracking.IssueQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>This is the query for searching issues. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface IssueQuery
    extends org.osid.OsidRelationshipQuery {


    /**
     *  Sets the queue <code> Id </code> for this query. 
     *
     *  @param  queueId the queue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> queueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchQueueId(org.osid.id.Id queueId, boolean match);


    /**
     *  Clears the queue <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQueueIdTerms();


    /**
     *  Tests if a <code> QueueQuery </code> is available. 
     *
     *  @return <code> true </code> if a queue query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueQuery();


    /**
     *  Gets the query for a queue. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the queue query 
     *  @throws org.osid.UnimplementedException <code> supportsQueueQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueQuery() </code> is <code> true. </code> 
     */

    public org.osid.tracking.QueueQuery getQueueQuery();


    /**
     *  Clears the queue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQueueTerms();


    /**
     *  Sets the customer <code> Id </code> for this query. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCustomerId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the customer <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCustomerIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a customer query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCustomerQuery();


    /**
     *  Gets the query for a customer. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> supportsCustomerQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCustomerQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getCustomerQuery();


    /**
     *  Clears the customer query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCustomerTerms();


    /**
     *  Sets the topic <code> Id </code> for this query. 
     *
     *  @param  topicId the topic <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> topicId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTopicId(org.osid.id.Id topicId, boolean match);


    /**
     *  Clears the topic <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTopicIdTerms();


    /**
     *  Tests if a <code> TopicQuery </code> is available. 
     *
     *  @return <code> true </code> if a topic query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTopicQuery();


    /**
     *  Gets the query for a topic. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the topic query 
     *  @throws org.osid.UnimplementedException <code> supportsTopicQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTopicQuery() </code> is <code> true. </code> 
     */

    public org.osid.ontology.SubjectQuery getTopicQuery();


    /**
     *  Matches issues that have any topic. 
     *
     *  @param  match <code> true </code> to match issues with any topic, 
     *          <code> false </code> to match issues with no topic 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTopic(boolean match);


    /**
     *  Clears the topic query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTopicTerms();


    /**
     *  Sets the subtask <code> Id </code> for this query. 
     *
     *  @param  issueId the issue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSubtaskId(org.osid.id.Id issueId, boolean match);


    /**
     *  Clears the subtask issue <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubtaskIdTerms();


    /**
     *  Tests if an <code> IssueQuery </code> is available. 
     *
     *  @return <code> true </code> if a subtask issue query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubtaskQuery();


    /**
     *  Gets the query for a subtask issue. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the subtask issue query 
     *  @throws org.osid.UnimplementedException <code> supportsSubtaskQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubtaskQuery() </code> is <code> true. </code> 
     */

    public org.osid.tracking.IssueQuery getSubtaskQuery();


    /**
     *  Matches issues that have any subtask. 
     *
     *  @param  match <code> true </code> to match issues with any subtasks, 
     *          <code> false </code> to match issues on no subtasks 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySubtask(boolean match);


    /**
     *  Clears the subtask query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubtaskTerms();


    /**
     *  Sets the master issue <code> Id </code> for this query. 
     *
     *  @param  issueId the issue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMasterIssueId(org.osid.id.Id issueId, boolean match);


    /**
     *  Clears the master issue issue <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMasterIssueIdTerms();


    /**
     *  Tests if an <code> IssueQuery </code> is available. 
     *
     *  @return <code> true </code> if a master issue query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMasterIssueQuery();


    /**
     *  Gets the query for a master issue. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the master issue query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMasterIssueQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMasterIssueQuery() </code> is <code> true. </code> 
     */

    public org.osid.tracking.IssueQuery getMasterIssueQuery();


    /**
     *  Matches issues that are subtasks. 
     *
     *  @param  match <code> true </code> to match issues with any master 
     *          issue, <code> false </code> to match issues on no master 
     *          issues 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyMasterIssue(boolean match);


    /**
     *  Clears the linked issue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMasterIssueTerms();


    /**
     *  Sets the linked issue <code> Id </code> for this query. 
     *
     *  @param  issueId the issue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDuplicateIssueId(org.osid.id.Id issueId, boolean match);


    /**
     *  Clears the duplicate issue issue <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDuplicateIssueIdTerms();


    /**
     *  Tests if an <code> IssueQuery </code> is available. 
     *
     *  @return <code> true </code> if a duplicate issue query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDuplicateIssueQuery();


    /**
     *  Gets the query for a duplicate issue. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the duplicate issue query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDuplicateIssueQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDuplicateIssueQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.tracking.IssueQuery getDuplicateIssueQuery();


    /**
     *  Matches issues that are duplicated by any other issue. 
     *
     *  @param  match <code> true </code> to match duplicate issues, <code> 
     *          false </code> to match unlinked issues 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDuplicateIssue(boolean match);


    /**
     *  Clears the duplicate issue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDuplicateIssueTerms();


    /**
     *  Sets the branched issue <code> Id </code> for this query. 
     *
     *  @param  issueId the issue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBranchedIssueId(org.osid.id.Id issueId, boolean match);


    /**
     *  Clears the branched issue issue <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBranchedIssueIdTerms();


    /**
     *  Tests if an <code> IssueQuery </code> is available. 
     *
     *  @return <code> true </code> if a branched issue query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBranchedIssueQuery();


    /**
     *  Gets the query for a branched issue. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the branched issue query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBranchedIssueQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBranchedIssueQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.tracking.IssueQuery getBranchedIssueQuery();


    /**
     *  Matches issues that branched to any other issue. 
     *
     *  @param  match <code> true </code> to match issues with branches, 
     *          <code> false </code> to match issues with no branches 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBranchedIssue(boolean match);


    /**
     *  Clears the branched issue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBranchedIssueTerms();


    /**
     *  Sets the root of the branch issue <code> Id </code> for this query. 
     *
     *  @param  issueId the issue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRootIssueId(org.osid.id.Id issueId, boolean match);


    /**
     *  Clears the root issue issue <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRootIssueIdTerms();


    /**
     *  Tests if an <code> IssueQuery </code> is available. 
     *
     *  @return <code> true </code> if a root issue query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRootIssueQuery();


    /**
     *  Gets the query for a root of the branch issue. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the root issue query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRootIssueQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRootIssueQuery() </code> is <code> true. </code> 
     */

    public org.osid.tracking.IssueQuery getRootIssueQuery();


    /**
     *  Matches issue branches with a root. 
     *
     *  @param  match <code> true </code> to match branches with a root, 
     *          <code> false </code> to match issues that are not a branch of 
     *          another issue 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRootIssue(boolean match);


    /**
     *  Clears the root issue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRootIssueTerms();


    /**
     *  Matches issues with the given priority type. 
     *
     *  @param  priorityType the priority <code> Type </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> priorityType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPriorityType(org.osid.type.Type priorityType, 
                                  boolean match);


    /**
     *  Clears the priority type query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPriorityTypeTerms();


    /**
     *  Sets the creator <code> Id </code> for this query. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCreatorId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the creator <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreatorIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreatorQuery();


    /**
     *  Gets the query for a creator. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> supportsCreatorQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreatorQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getCreatorQuery();


    /**
     *  Clears the creator query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreatorTerms();


    /**
     *  Sets the creating agent <code> Id </code> for this query. 
     *
     *  @param  agentId the agent <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCreatingAgentId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears the creator <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreatingAgentIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available. 
     *
     *  @return <code> true </code> if an agent query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreatingAgentQuery();


    /**
     *  Gets the query for a creator. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the agent query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCreatingAgentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreatingAgentQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentQuery getCreatingAgentQuery();


    /**
     *  Clears the creating agent query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreatingAgentTerms();


    /**
     *  Matches issues created within the given date range inclusive. 
     *
     *  @param  from the range start 
     *  @param  to the range end 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCreatedDate(org.osid.calendaring.DateTime from, 
                                 org.osid.calendaring.DateTime to, 
                                 boolean match);


    /**
     *  Clears the created date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreatedDateTerms();


    /**
     *  Sets the reopener <code> Id </code> for this query. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchReopenerId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the reopener <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearReopenerIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsReopenerQuery();


    /**
     *  Gets the query for the resource who reopened this issue. Multiple 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> supportsReopenerQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsReopenerQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getReopenerQuery();


    /**
     *  Clears the reopener query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearReopenerTerms();


    /**
     *  Sets the reopening agent <code> Id </code> for this query. 
     *
     *  @param  agentId the agent <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchReopeningAgentId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears the reopening agent <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearReopeningAgentIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available. 
     *
     *  @return <code> true </code> if an agent query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsReopeningAgentQuery();


    /**
     *  Gets the query for the agent who reopened this issue. Multiple 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @return the agent query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsReopeningAgentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsReopeningAgentQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentQuery getReopeningAgentQuery();


    /**
     *  Clears the reopner query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearReopeningAgentTerms();


    /**
     *  Matches issues reopened within the given date range inclusive. 
     *
     *  @param  from the range start 
     *  @param  to the range end 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchReopenedDate(org.osid.calendaring.DateTime from, 
                                  org.osid.calendaring.DateTime to, 
                                  boolean match);


    /**
     *  Matches issues that have any reopened date. 
     *
     *  @param  match <code> true </code> to match issues with any reopened 
     *          date, <code> false </code> to match issues with no reopened 
     *          date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyReopenedDate(boolean match);


    /**
     *  Clears the reopened date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearReopenedDateTerms();


    /**
     *  Matches issue due dates within the given date range inclusive. 
     *
     *  @param  from the range start 
     *  @param  to the range end 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDueDate(org.osid.calendaring.DateTime from, 
                             org.osid.calendaring.DateTime to, boolean match);


    /**
     *  Matches issues that have any due date. 
     *
     *  @param  match <code> true </code> to match issues with any due date, 
     *          <code> false </code> to match issues with no due date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDueDate(boolean match);


    /**
     *  Clears the due date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDueDateTerms();


    /**
     *  Matches issues that are pending a customer response. 
     *
     *  @param  match <code> true </code> to match pending issues, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPending(boolean match);


    /**
     *  Clears the pending query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPendingTerms();


    /**
     *  Sets the blocking issue <code> Id </code> for this query. 
     *
     *  @param  issueId the issue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBlockingIssueId(org.osid.id.Id issueId, boolean match);


    /**
     *  Clears the blocking issue issue <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBlockingIssueIdTerms();


    /**
     *  Tests if an <code> IssueQuery </code> is available. 
     *
     *  @return <code> true </code> if a blocking issue query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlockingIssueQuery();


    /**
     *  Gets the query for a blocking issue. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the blocking issue query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBlockingIssueQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBlockingIssueQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.tracking.IssueQuery getBlockingIssueQuery();


    /**
     *  Matches any blocking issue. 
     *
     *  @param  match <code> true </code> to match blocking issues, <code> 
     *          false </code> to match issues not blocking 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBlockingIssue(boolean match);


    /**
     *  Clears the blocking issue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBlockingIssueTerms();


    /**
     *  Sets the blocked issue <code> Id </code> for this query. 
     *
     *  @param  issueId the issue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBlockedIssueId(org.osid.id.Id issueId, boolean match);


    /**
     *  Clears the blocked issue issue <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBlockedIssueIdTerms();


    /**
     *  Tests if an <code> IssueQuery </code> is available. 
     *
     *  @return <code> true </code> if a blocked issue query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlockedIssueQuery();


    /**
     *  Gets the query for a blocked issue. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the blocking issue query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBlockedIssueQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBlockedIssueQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.tracking.IssueQuery getBlockedIssueQuery();


    /**
     *  Matches any issue blocked. 
     *
     *  @param  match <code> true </code> to match issues blocked, <code> 
     *          false </code> to match issues that are not blocked 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBlockedIssue(boolean match);


    /**
     *  Clears the blocked issue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBlockedIssueTerms();


    /**
     *  Sets the resolver <code> Id </code> for this query. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResolverId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the resolver <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResolverIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResolverQuery();


    /**
     *  Gets the query for the resource who resolved this issue. Multiple 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> supportsResolverQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResolverQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getResolverQuery();


    /**
     *  Clears the resolver query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResolverTerms();


    /**
     *  Sets the resolving agent <code> Id </code> for this query. 
     *
     *  @param  agentId the agent <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResolvingAgentId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears the resolving agent <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResolvingAgentIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available. 
     *
     *  @return <code> true </code> if an agent query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResolvingAgentQuery();


    /**
     *  Gets the query for the agent who resolved this issue. Multiple 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @return the agent query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResolvingAgentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResolvingAgentQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentQuery getResolvingAgentQuery();


    /**
     *  Clears the resolving query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResolvingAgentTerms();


    /**
     *  Matches issue resolved dates within the given date range inclusive. 
     *
     *  @param  from the range start 
     *  @param  to the range end 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResolvedDate(org.osid.calendaring.DateTime from, 
                                  org.osid.calendaring.DateTime to, 
                                  boolean match);


    /**
     *  Matches any issue that has been resolved. 
     *
     *  @param  match <code> true </code> to match resolved issues, <code> 
     *          false </code> to match unresolved issues 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyResolvedDate(boolean match);


    /**
     *  Clears the resolved date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResolvedDateTerms();


    /**
     *  Matches issues with the given resolution type. 
     *
     *  @param  resolutionType the resolution <code> Type </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resolutionType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResolutionType(org.osid.type.Type resolutionType, 
                                    boolean match);


    /**
     *  Clears the resolution type query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResolutionTypeTerms();


    /**
     *  Sets the closer resource <code> Id </code> for this query. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCloserId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the closer resource <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCloserIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCloserQuery();


    /**
     *  Gets the query for the agent who closed this issue. Multiple 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> supportsCloserQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCloserQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getCloserQuery();


    /**
     *  Clears the closer query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCloserTerms();


    /**
     *  Sets the closing agent <code> Id </code> for this query. 
     *
     *  @param  agentId the agent <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchClosingAgentId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears the closing agent <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearClosingAgentIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available. 
     *
     *  @return <code> true </code> if a closing agent query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsClosingAgentQuery();


    /**
     *  Gets the query for the agent who closed this issue. Multiple 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @return the agent query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsClosingAgentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsClosingAgentQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentQuery getClosingAgentQuery();


    /**
     *  Clears the closing agent query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearClosingAgentTerms();


    /**
     *  Matches issue closed dates within the given date range inclusive. 
     *
     *  @param  from the range start 
     *  @param  to the range end 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchClosedDate(org.osid.calendaring.DateTime from, 
                                org.osid.calendaring.DateTime to, 
                                boolean match);


    /**
     *  Matches any issue that has been closed. 
     *
     *  @param  match <code> true </code> to match closed issues, <code> false 
     *          </code> to match unclosed issues 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyClosedDate(boolean match);


    /**
     *  Clears the closed date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearClosedDateTerms();


    /**
     *  Sets the currently assigned resource <code> Id </code> for this query. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAssignedResourceId(org.osid.id.Id resourceId, 
                                        boolean match);


    /**
     *  Clears the currently assigned resource <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssignedResourceIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if an assigned resource query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssignedResourceQuery();


    /**
     *  Gets the query for the current assigned resource. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssignedResourceQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssignedResourceQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceQuery getAssignedResourceQuery();


    /**
     *  Matches any issue that has any current assigned resource. 
     *
     *  @param  match <code> true </code> to match issues with any currently 
     *          assigned resource, <code> false </code> to match issues with 
     *          no currently assigned resource 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAssignedResource(boolean match);


    /**
     *  Clears the current assigned resource query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssignedResourceTerms();


    /**
     *  Sets the resource <code> Id </code> for this query to match any 
     *  resource ever assigned to an issue. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResourceId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the assigned resource <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if an assigned resource query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceQuery();


    /**
     *  Gets the query for the assigned resource. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> supportsResourceQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getResourceQuery();


    /**
     *  Matches any issue that has any assigned resource. 
     *
     *  @param  match <code> true </code> to match issues with any resource 
     *          ever assigned, <code> false </code> to match issues that never 
     *          had an assigned resource 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyResource(boolean match);


    /**
     *  Clears the resource query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceTerms();


    /**
     *  Sets the log entry <code> Id </code> for this query to match issues 
     *  along the given log entry. 
     *
     *  @param  logEntryId the log entry <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> logEntryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLogEntryId(org.osid.id.Id logEntryId, boolean match);


    /**
     *  Clears the log entry <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLogEntryIdTerms();


    /**
     *  Tests if a <code> LogEntryQuery </code> is available. 
     *
     *  @return <code> true </code> if a log entry query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogEntryQuery();


    /**
     *  Gets the query for a log entry. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the log entry query 
     *  @throws org.osid.UnimplementedException <code> supportsLogEntryQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogEntryQuery() </code> is <code> true. </code> 
     */

    public org.osid.tracking.LogEntryQuery getLogEntryQuery();


    /**
     *  Matches issues that are used on any log entry. 
     *
     *  @param  match <code> true </code> to match issues with any log entry, 
     *          <code> false </code> to match issues with no log entries 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLogEntry(boolean match);


    /**
     *  Clears the log entry query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLogEntryTerms();


    /**
     *  Sets the front office <code> Id </code> for this query to match issues 
     *  assigned to front offices. 
     *
     *  @param  frontOfficeId the front office <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> frontOfficeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFrontOfficeId(org.osid.id.Id frontOfficeId, boolean match);


    /**
     *  Clears the front office <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFrontOfficeIdTerms();


    /**
     *  Tests if a <code> FrontOfficeQuery </code> is available. 
     *
     *  @return <code> true </code> if a front office query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFrontOfficeQuery();


    /**
     *  Gets the query for a front office. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the front office query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFrontOfficeQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFrontOfficeQuery() </code> is <code> true. </code> 
     */

    public org.osid.tracking.FrontOfficeQuery getFrontOfficeQuery();


    /**
     *  Clears the front office query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFrontOfficeTerms();


    /**
     *  Gets the issue query record corresponding to the given <code> Issue 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  issueRecordType a issue record type 
     *  @return the issue query record 
     *  @throws org.osid.NullArgumentException <code> issueRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(issueRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.records.IssueQueryRecord getIssueQueryRecord(org.osid.type.Type issueRecordType)
        throws org.osid.OperationFailedException;
}
