//
// org.osid.tracking.IssueResourcingSession
//
//     The OSID Java specification for org.osid.tracking.IssueResourcingSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>This session defines methods for resourcing issues. </p>
 */

public interface IssueResourcingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> FrontOffice </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> FrontOffice Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFrontOfficeId();


    /**
     *  Gets the <code> FrontOffice </code> associated with this session. 
     *
     *  @return the front office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOffice getFrontOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can assign resources to <code> Issues. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if resource assignment methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canResourceIssues();


    /**
     *  Gets a list of resource assignable in this queue. 
     *
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> 
     *  @return a list of resources 
     *  @throws org.osid.NotFoundException <code> queueId </code> not found 
     *  @throws org.osid.NullArgumentException <code> queueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getResourcesForQueue(org.osid.id.Id queueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of candidate resources from this queue available for an 
     *  issue sorted from best suited. 
     *
     *  @param  issueId the <code> Id </code> of an <code> Issue </code> 
     *  @return a list of resources 
     *  @throws org.osid.NotFoundException <code> issueId </code> not found 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getResourcesAvailableForIssue(org.osid.id.Id issueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of issues assigned to a resource. 
     *
     *  @param  resourceId the <code> Id </code> of a <code> Resource </code> 
     *  @return a list of issues 
     *  @throws org.osid.NotFoundException <code> resourceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getIssuesByResource(org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of issues assigned to a resource in a given queue. 
     *
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> 
     *  @param  resourceId the <code> Id </code> of a <code> Resource </code> 
     *  @return a list of issues 
     *  @throws org.osid.NotFoundException <code> queueId </code> or <code> 
     *          resourceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> queueId </code> or 
     *          <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getIssuesByResourceForQueue(org.osid.id.Id queueId, 
                                                                   org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Assigns an <code> Issue </code> to a <code> Resource </code> . The 
     *  resource must be a valid resource in the issue queue. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> issueId </code> already 
     *          assigned 
     *  @throws org.osid.NotFoundException <code> issueId </code> or <code> 
     *          resourceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> issueId </code> or 
     *          <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignIssueToResource(org.osid.id.Id issueId, 
                                      org.osid.id.Id resourceId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Unassigns an <code> Issue </code> from a <code> Resource. </code> 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @throws org.osid.NotFoundException <code> issueId </code> not found 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignIssueFromResource(org.osid.id.Id issueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
