//
// org.osid.tracking.IssueTrackingSession
//
//     The OSID Java specification for org.osid.tracking.IssueTrackingSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>This session defines methods for looking at issues in a queue. </p> 
 *  
 *  <p> Issues may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Issues. </code> </p>
 */

public interface IssueTrackingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> FrontOffice </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> FrontOffice Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFrontOfficeId();


    /**
     *  Gets the <code> FrontOffice </code> associated with this session. 
     *
     *  @return the front office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOffice getFrontOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Issue </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupIssues();


    /**
     *  Gets the <code> Issue </code> specified by its <code> Id. </code> 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> to 
     *          retrieve 
     *  @return the returned <code> Issue </code> 
     *  @throws org.osid.NotFoundException no <code> Issue </code> found in 
     *          this queue with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.Issue getIssue(org.osid.id.Id issueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all open issues in a queue. 
     *
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> to 
     *  @return the returned <code> Issue </code> list 
     *  @throws org.osid.NotFoundException <code> queueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> queueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getOpenIssues(org.osid.id.Id queueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all open unassigned issues in this queue. 
     *
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> to 
     *  @return the returned <code> Issue </code> list 
     *  @throws org.osid.NotFoundException <code> queueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> queueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getOpenUnassignedIssues(org.osid.id.Id queueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of open issues that have been idle since the given date. 
     *
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> to 
     *  @param  date a date 
     *  @return the returned <code> IssueList </code> 
     *  @throws org.osid.NotFoundException <code> queueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> queueId </code> or 
     *          <code> date </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getOpenIdleIssues(org.osid.id.Id queueId, 
                                                         org.osid.calendaring.DateTime date)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of open issues assigned to the given resource. 
     *
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> to 
     *  @param  resourceId a resource 
     *  @return the returned <code> IssueList </code> 
     *  @throws org.osid.NotFoundException <code> queueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> queueId </code> or 
     *          <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getOpenIssuesByAssignee(org.osid.id.Id queueId, 
                                                               org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of issues by topic which may include issues of any child 
     *  topic. 
     *
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> to 
     *  @param  subjectId a resource 
     *  @return the returned <code> IssueList </code> 
     *  @throws org.osid.NotFoundException <code> queueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> queueId </code> or 
     *          <code> subjectId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getOpenIssuesByTopic(org.osid.id.Id queueId, 
                                                            org.osid.id.Id subjectId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all closed issues in this queue. 
     *
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> to 
     *  @return the returned <code> Issue </code> list 
     *  @throws org.osid.NotFoundException <code> queueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> queueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getClosedIssues(org.osid.id.Id queueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of closed issues that were ever assigned to the given 
     *  resource. 
     *
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> to 
     *  @param  resourceId a resource 
     *  @return the returned <code> IssueList </code> 
     *  @throws org.osid.NotFoundException <code> queueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> queueId </code> or 
     *          <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getClosedIssuesByAssignee(org.osid.id.Id queueId, 
                                                                 org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of issues by topic which may include issues of any child 
     *  topic. 
     *
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> to 
     *  @param  topicId a resource 
     *  @return the returned <code> IssueList </code> 
     *  @throws org.osid.NotFoundException <code> queueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> queueId </code> or 
     *          <code> topicId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getClosedIssuesByTopic(org.osid.id.Id queueId, 
                                                              org.osid.id.Id topicId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of closed issues that were created between the given date 
     *  range inclusive. 
     *
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> to 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> IssueList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NotFoundException <code> queueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> queueId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getClosedIssuesByCreateDate(org.osid.id.Id queueId, 
                                                                   org.osid.calendaring.DateTime from, 
                                                                   org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all issues that were in an open status on the given 
     *  date. 
     *
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> to 
     *  @param  date a date 
     *  @return the returned <code> IssueList </code> 
     *  @throws org.osid.NotFoundException <code> queueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> queueId </code> or 
     *          <code> date </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getIssuesByActiveDate(org.osid.id.Id queueId, 
                                                             org.osid.calendaring.DateTime date)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all issues created since the given date. 
     *
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> to 
     *  @param  date a date 
     *  @return the returned <code> IssueList </code> 
     *  @throws org.osid.NotFoundException <code> queueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> queueId </code> or 
     *          <code> date </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getIssuesSinceDate(org.osid.id.Id queueId, 
                                                          org.osid.calendaring.DateTime date)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
