//
// org.osid.tracking.IssueTriagingSession
//
//     The OSID Java specification for org.osid.tracking.IssueTriagingSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>This session defines methods for routing issues. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> isolated front office view: All issue methods in this session 
 *      operate, retrieve and pertain to issues defined explicitly in the 
 *      current front office. Using an isolated view is useful for managing 
 *      <code> Issues </code> with the <code> IssueAdminSession. </code> </li> 
 *      <li> federated front office view: All issue lookup methods in this 
 *      session operate, retrieve and pertain to all issues defined in this 
 *      front office and any other issues implicitly available in this front 
 *      office through front office inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedFrontOfficeView() </code> and <code> 
 *  useIsolatedFrontOfficeView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p>
 */

public interface IssueTriagingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> FrontOffice </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> FrontOffice Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFrontOfficeId();


    /**
     *  Gets the <code> FrontOffice </code> associated with this session. 
     *
     *  @return the front office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOffice getFrontOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can route <code> Issue </code> lookups. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer routing operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if routing methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRouteIssues();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include issues in front offices which are children of this front 
     *  office in the front office hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFrontOfficeView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this front office only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFrontOfficeView();


    /**
     *  Moves an <code> Issue </code> to another <code> Queue. </code> If the 
     *  assigned resource is not valid in the destination queue, the issue may 
     *  automatically be unassigned. If the assigned topic is not valid in the 
     *  destination queue, it may default to another topic. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @param  queueId the <code> Id </code> of the <code> Queue </code> 
     *  @throws org.osid.AlreadyExistsException <code> issueId </code> already 
     *          in <code> queueId </code> 
     *  @throws org.osid.NotFoundException <code> issueId </code> or <code> 
     *          queueId </code> not found 
     *  @throws org.osid.NullArgumentException <code> issueId </code> or 
     *          <code> queueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveIssueToQueue(org.osid.id.Id issueId, 
                                 org.osid.id.Id queueId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of assignable topic <code> Ids </code> for a queue. 
     *
     *  @param  queueId the <code> Id </code> of the <code> Queue </code> 
     *  @return a list of subject <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> queueId </code> not found 
     *  @throws org.osid.NullArgumentException <code> queueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableTopicIds(org.osid.id.Id queueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of assignable topics for a queue. 
     *
     *  @param  queueId the <code> Id </code> of the <code> Queue </code> 
     *  @return a list of subjects 
     *  @throws org.osid.NotFoundException <code> queueId </code> not found 
     *  @throws org.osid.NullArgumentException <code> queueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.SubjectList getAssignableTopics(org.osid.id.Id queueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Assigns a <code> Topic </code> to an <code> Issue. </code> 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @param  subjectId the <code> Id </code> of the <code> Subject </code> 
     *  @throws org.osid.AlreadyExistsException <code> issueId </code> already 
     *          assigned to <code> subjectId </code> 
     *  @throws org.osid.NotFoundException <code> issueId </code> or <code> 
     *          subjectId </code> not found 
     *  @throws org.osid.NullArgumentException <code> issueId </code> or 
     *          <code> subjectId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignTopic(org.osid.id.Id issueId, org.osid.id.Id subjectId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Closes an issue. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @throws org.osid.NotFoundException <code> issueId </code> not found 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void closeIssue(org.osid.id.Id issueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
