//
// org.osid.tracking.LogEntry
//
//     The OSID Java specification for org.osid.tracking.LogEntry.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>A <code> LogEntry </code> is an entry of an issue. </p>
 */

public interface LogEntry
    extends org.osid.OsidObject {


    /**
     *  Gets the <code> Id </code> of the agent. 
     *
     *  @return the agent <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAgentId();


    /**
     *  Gets the agent. 
     *
     *  @return the agent 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the issue of this log entry. 
     *
     *  @return the issue <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getIssueId();


    /**
     *  Gets the issue of this log entry. 
     *
     *  @return the issue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.Issue getIssue()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the date of this log entry. 
     *
     *  @return the date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getDate();


    /**
     *  Gets the action of this log entry. 
     *
     *  @return the issue action 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueAction getAction();


    /**
     *  Gets a summary header for this entry. 
     *
     *  @return the summary 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getSummary();


    /**
     *  Gets the text of this entry. 
     *
     *  @return the entry text 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getMessage();


    /**
     *  Gets the log entry record corresponding to the given <code> LogEntry 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> 
     *  logEntryRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(logEntryRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  logEntryRecordType the type of log entry record to retrieve 
     *  @return the log entry record 
     *  @throws org.osid.NullArgumentException <code> logEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(logEntryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.records.LogEntryRecord getLogEntryRecord(org.osid.type.Type logEntryRecordType)
        throws org.osid.OperationFailedException;
}
