//
// org.osid.tracking.QueueLookupSession
//
//     The OSID Java specification for org.osid.tracking.QueueLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>This session provides methods for retrieving <code> Queue </code> 
 *  objects. The <code> Queue </code> represents a fixed connection between 
 *  two <code> Issues. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated front office view: All queue methods in this session 
 *      operate, retrieve and pertain to queues defined explicitly in the 
 *      current front office. Using an isolated view is useful for managing 
 *      <code> Queues </code> with the <code> QueueAdminSession. </code> </li> 
 *      <li> federated front office view: All queue methods in this session 
 *      operate, retrieve and pertain to all queues defined in this front 
 *      office and any other queues implicitly available in this front office 
 *      through front office inheritence. </li> 
 *      <li> active queue view: active queue are returned from methods in this 
 *      session </li> 
 *      <li> any status queue view: active and inactive queues are returned 
 *      from methods in this session </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedFrontOfficeView() </code> and <code> 
 *  useIsolatedFrontOfficeView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p>
 */

public interface QueueLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> FrontOffice </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> FrontOffice Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFrontOfficeId();


    /**
     *  Gets the <code> FrontOffice </code> associated with this session. 
     *
     *  @return the front office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOffice getFrontOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Queue </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupQueues();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeQueueView();


    /**
     *  A complete view of the <code> Queue </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryQueueView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include queues in front offices which are children of this front 
     *  office in the front office hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFrontOfficeView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this front office only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFrontOfficeView();


    /**
     *  Only active queues are returned from methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveQueueView();


    /**
     *  Borth active and inactive queues are returned from methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusQueueView();


    /**
     *  Gets the <code> Queue </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Queue </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Queue </code> and retained for compatibility. 
     *  
     *  In active mode, queues are returned that are currently active. In any 
     *  status mode, active and inactive queues are returned. 
     *
     *  @param  queueId <code> Id </code> of the <code> Queue </code> 
     *  @return the queue 
     *  @throws org.osid.NotFoundException <code> queueId </code> not found 
     *  @throws org.osid.NullArgumentException <code> queueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.tracking.Queue getQueue(org.osid.id.Id queueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QueueList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  queues specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Queues </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, queues are returned that are currently active. In any 
     *  status mode, active and inactive queues are returned. 
     *
     *  @param  queueIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Queue </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> queueIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.QueueList getQueuesByIds(org.osid.id.IdList queueIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QueueList </code> corresponding to the given queue genus 
     *  <code> Type </code> which does not include queues of genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  queues or an error results. Otherwise, the returned list may contain 
     *  only those queues that are accessible through this session. 
     *  
     *  In active mode, queues are returned that are currently active. In any 
     *  status mode, active and inactive queues are returned. 
     *
     *  @param  queueGenusType a queue genus type 
     *  @return the returned <code> Queue </code> list 
     *  @throws org.osid.NullArgumentException <code> queueGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.QueueList getQueuesByGenusType(org.osid.type.Type queueGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QueueList </code> corresponding to the given queue genus 
     *  <code> Type </code> and include any additional queues with genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  queues or an error results. Otherwise, the returned list may contain 
     *  only those queues that are accessible through this session. 
     *  
     *  In active mode, queues are returned that are currently active. In any 
     *  status mode, active and inactive queues are returned. 
     *
     *  @param  queueGenusType a queue genus type 
     *  @return the returned <code> Queue </code> list 
     *  @throws org.osid.NullArgumentException <code> queueGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.QueueList getQueuesByParentGenusType(org.osid.type.Type queueGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QueueList </code> containing the given queue record 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  queues or an error results. Otherwise, the returned list may contain 
     *  only those queues that are accessible through this session. 
     *  
     *  In active mode, queues are returned that are currently active. In any 
     *  status mode, active and inactive queues are returned. 
     *
     *  @param  queueRecordType a queue record type 
     *  @return the returned <code> Queue </code> list 
     *  @throws org.osid.NullArgumentException <code> queueRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.QueueList getQueuesByRecordType(org.osid.type.Type queueRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QueueList </code> for a provider. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  queues or an error results. Otherwise, the returned list may contain 
     *  only those queues that are accessible through this session. 
     *  
     *  In active mode, queues are returned that are currently active. In any 
     *  status mode, active and inactive queues are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Queue </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.QueueList getQueuesByProvider(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Queues. </code> 
     *  
     *  In plenary mode, the returned list contains all known queues or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  queues that are accessible through this session. 
     *  
     *  In active mode, queues are returned that are currently active. In any 
     *  status mode, active and inactive queues are returned. 
     *
     *  @return a list of <code> Queues </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.QueueList getQueues()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
