//
// org.osid.tracking.QueueSearch
//
//     The OSID Java specification for org.osid.tracking.QueueSearch.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>The search interface for governing queue searches. </p>
 */

public interface QueueSearch
    extends org.osid.OsidSearch {


    /**
     *  Execute this search among the given list of queues. 
     *
     *  @param  queueIds list of queues 
     *  @throws org.osid.NullArgumentException <code> queueIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void searchAmongQueues(org.osid.id.IdList queueIds);


    /**
     *  Specify an ordering to the search results. 
     *
     *  @param  queueSearchOrder queue search order 
     *  @throws org.osid.NullArgumentException <code> queueSearchOrder </code> 
     *          is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> queueSearchOrder </code> 
     *          is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderQueueResults(org.osid.tracking.QueueSearchOrder queueSearchOrder);


    /**
     *  Gets the queue search record corresponding to the given queue search 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. 
     *
     *  @param  queueSearchRecordType a queue search record type 
     *  @return the queue search record 
     *  @throws org.osid.NullArgumentException <code> queueSearchRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(queueSearchRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.records.QueueSearchRecord getQueueSearchRecord(org.osid.type.Type queueSearchRecordType)
        throws org.osid.OperationFailedException;
}
