//
// org.osid.tracking.SubtaskIssueAdminSession
//
//     The OSID Java specification for org.osid.tracking.SubtaskIssueAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>This session creates subtask <code> Issues. </code> Subtasks are issues 
 *  that are created in the contex of an existing issue. </p> 
 *  
 *  <p> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> To create a subtask, an <code> IssueForm </code> is requested using 
 *  <code> getSubtaskFormForCreate() </code> specifying the desired issue and 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. The returned <code> IssueForm </code> will indicate that it is to 
 *  be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> IssueForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  IssueForm </code> corresponds to an attempted transaction. </p>
 */

public interface SubtaskIssueAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> FrontOffice </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> FrontOffice Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFrontOfficeId();


    /**
     *  Gets the <code> FrontOffice </code> associated with this session. 
     *
     *  @return the front office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOffice getFrontOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create subtask <code> Issues. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a subtask will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if subtask <code> Issue </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateSubtasks();


    /**
     *  Tests if this user can create a single <code> Issue </code> using the 
     *  desired record types. While <code> 
     *  TrackingManager.getIssueRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Issue. </code> Providing an 
     *  empty array tests if an <code> Issue </code> can be created with no 
     *  records. 
     *
     *  @param  issueRecordTypes array of issue record types 
     *  @return <code> true </code> if <code> Issue </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> issueRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateSubtaskWithRecordTypes(org.osid.type.Type[] issueRecordTypes);


    /**
     *  Gets the issue form for creating subtasks. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @param  queueId the <code> Id </code> of the <code> Queue </code> in 
     *          which the subtask should be created 
     *  @param  issueRecordTypes array of issue record types 
     *  @return the issue form 
     *  @throws org.osid.NotFoundException <code> issueId </code> or <code> 
     *          queueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> issueId, queueId </code> 
     *          or <code> issueRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueForm getSubtaskFormForCreate(org.osid.id.Id issueId, 
                                                               org.osid.id.Id queueId, 
                                                               org.osid.type.Type[] issueRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a subtask <code> Issue. </code> A subtask is a nested <code> 
     *  Issue. </code> 
     *
     *  @param  issueForm the form for the subtask 
     *  @return the new <code> Issue </code> 
     *  @throws org.osid.IllegalStateException <code> issueForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> issueForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> issueForm </code> did not 
     *          originate from <code> getSubtaskFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.Issue createSubtask(org.osid.tracking.IssueForm issueForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
