//
// org.osid.tracking.TrackingProfile
//
//     The OSID Java specification for org.osid.tracking.TrackingProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>The tracking profile describes the interoperability among tracking 
 *  services. </p>
 */

public interface TrackingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any front office federation is exposed. Federation is exposed 
     *  when a specific front office may be identified, selected and used to 
     *  create a lookup or admin session. Federation is not exposed when a set 
     *  of front offices appears as a single front office. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if an issue service is supported for the current agent. 
     *
     *  @return <code> true </code> if my issue is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMyIssue();


    /**
     *  Tests if an issue tracking service is supported. 
     *
     *  @return <code> true </code> if issue tracking is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueTracking();


    /**
     *  Tests if an issue resourcing service is supported. 
     *
     *  @return <code> true </code> if issue resourcing is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueResourcing();


    /**
     *  Tests if an issue triaging service is supported. 
     *
     *  @return <code> true </code> if issue triaging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueTriaging();


    /**
     *  Tests if looking up issues is supported. 
     *
     *  @return <code> true </code> if issue lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueLookup();


    /**
     *  Tests if querying issues is supported. 
     *
     *  @return <code> true </code> if issue query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueQuery();


    /**
     *  Tests if searching issues is supported. 
     *
     *  @return <code> true </code> if issue search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueSearch();


    /**
     *  Tests if issue <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if issue administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueAdmin();


    /**
     *  Tests if an issue <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if issue notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueNotification();


    /**
     *  Tests if an issue front office lookup service is supported. 
     *
     *  @return <code> true </code> if an issue front office lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueFrontOffice();


    /**
     *  Tests if an issue front office assignment service is supported. 
     *
     *  @return <code> true </code> if an issue to front office assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueFrontOfficeAssignment();


    /**
     *  Tests if an issue smart front office service is supported. 
     *
     *  @return <code> true </code> if an issue smart front office service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueSmartFrontOffice();


    /**
     *  Tests if looking up subtasks is supported. 
     *
     *  @return <code> true </code> if subtask lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubtaskIssueLookup();


    /**
     *  Tests if managing subtasks is supported. 
     *
     *  @return <code> true </code> if subtask admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubtaskIssueAdmin();


    /**
     *  Tests if looking up duplicate issues is supported. 
     *
     *  @return <code> true </code> if duplicate issue lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDuplicateIssueLookup();


    /**
     *  Tests if managing duplicate issues is supported. 
     *
     *  @return <code> true </code> if duplicate issue admin is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDuplicateIssueAdmin();


    /**
     *  Tests if looking up issue branches is supported. 
     *
     *  @return <code> true </code> if branched issue lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBranchedIssueLookup();


    /**
     *  Tests if managing issue branches is supported. 
     *
     *  @return <code> true </code> if branched issue admin is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBranchedIssueAdmin();


    /**
     *  Tests if looking up blocking issues is supported. 
     *
     *  @return <code> true </code> if blocking issue lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlockingIssueLookup();


    /**
     *  Tests if managing issue blocks is supported. 
     *
     *  @return <code> true </code> if blocking issue admin is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlockingIssueAdmin();


    /**
     *  Tests if looking up log entries is supported. 
     *
     *  @return <code> true </code> if log entry lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogEntryLookup();


    /**
     *  Tests if issue commenting and customer messaging is supported. 
     *
     *  @return <code> true </code> if issue messaging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueMessaging();


    /**
     *  Tests if log entry notification is supported. 
     *
     *  @return <code> true </code> if log entry notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogEntryNotification();


    /**
     *  Tests if looking up queues is supported. 
     *
     *  @return <code> true </code> if queue lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueLookup();


    /**
     *  Tests if querying queues is supported. 
     *
     *  @return <code> true </code> if queue query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueQuery();


    /**
     *  Tests if searching queues is supported. 
     *
     *  @return <code> true </code> if queue search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueSearch();


    /**
     *  Tests if queue <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if queue administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueAdmin();


    /**
     *  Tests if a queue <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if queue notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueNotification();


    /**
     *  Tests if a queue front office lookup service is supported. 
     *
     *  @return <code> true </code> if a queue front office lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueFrontOffice();


    /**
     *  Tests if a queue front office service is supported. 
     *
     *  @return <code> true </code> if queue to front office assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueFrontOfficeAssignment();


    /**
     *  Tests if a queue smart front office lookup service is supported. 
     *
     *  @return <code> true </code> if a queue smart front office service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueSmartFrontOffice();


    /**
     *  Tests if a queue resourcing is supported. 
     *
     *  @return <code> true </code> if a queue resourcing service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueResourcing();


    /**
     *  Tests if looking up front offices is supported. 
     *
     *  @return <code> true </code> if front office lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFrontOfficeLookup();


    /**
     *  Tests if querying front offices is supported. 
     *
     *  @return <code> true </code> if a front office query service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFrontOfficeQuery();


    /**
     *  Tests if searching front offices is supported. 
     *
     *  @return <code> true </code> if front office search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFrontOfficeSearch();


    /**
     *  Tests if front office administrative service is supported. 
     *
     *  @return <code> true </code> if front office administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFrontOfficeAdmin();


    /**
     *  Tests if a front office <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if front office notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFrontOfficeNotification();


    /**
     *  Tests for the availability of a front office hierarchy traversal 
     *  service. 
     *
     *  @return <code> true </code> if front office hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsFrontOfficeHierarchy();


    /**
     *  Tests for the availability of a front office hierarchy design service. 
     *
     *  @return <code> true </code> if front office hierarchy design is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFrontOfficeHierarchyDesign();


    /**
     *  Tests for the availability of a tracking rules service. 
     *
     *  @return <code> true </code> if a tracking rules service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTrackingRules();


    /**
     *  Gets the supported <code> Issue </code> record types. 
     *
     *  @return a list containing the supported <code> Issue </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getIssueRecordTypes();


    /**
     *  Tests if the given <code> Issue </code> record type is supported. 
     *
     *  @param  issueRecordType a <code> Type </code> indicating an <code> 
     *          Issue </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> issueRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueRecordType(org.osid.type.Type issueRecordType);


    /**
     *  Gets the supported <code> Issue </code> search types. 
     *
     *  @return a list containing the supported <code> Issue </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getIssueSearchRecordTypes();


    /**
     *  Tests if the given <code> Issue </code> search type is supported. 
     *
     *  @param  issueSearchRecordType a <code> Type </code> indicating an 
     *          <code> Issue </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> issueSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueSearchRecordType(org.osid.type.Type issueSearchRecordType);


    /**
     *  Gets the supported <code> LogEntry </code> record types. 
     *
     *  @return a list containing the supported <code> LogEntry </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getLogEntryRecordTypes();


    /**
     *  Tests if the given <code> LogEntry </code> record type is supported. 
     *
     *  @param  logEntryRecordType a <code> Type </code> indicating a <code> 
     *          LogEntry </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> logEntryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogEntryRecordType(org.osid.type.Type logEntryRecordType);


    /**
     *  Gets the supported <code> Queue </code> record types. 
     *
     *  @return a list containing the supported <code> Queue </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueRecordTypes();


    /**
     *  Tests if the given <code> Queue </code> record type is supported. 
     *
     *  @param  queueRecordType a <code> Type </code> indicating a <code> 
     *          Queue </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> queueRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueRecordType(org.osid.type.Type queueRecordType);


    /**
     *  Gets the supported <code> Queue </code> search record types. 
     *
     *  @return a list containing the supported <code> Queue </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueSearchRecordTypes();


    /**
     *  Tests if the given <code> Queue </code> search record type is 
     *  supported. 
     *
     *  @param  queueSearchRecordType a <code> Type </code> indicating a 
     *          <code> Queue </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> queueSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueSearchRecordType(org.osid.type.Type queueSearchRecordType);


    /**
     *  Gets the supported <code> FrontOffice </code> record types. 
     *
     *  @return a list containing the supported <code> FrontOffice </code> 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getFrontOfficeRecordTypes();


    /**
     *  Tests if the given <code> FrontOffice </code> record type is 
     *  supported. 
     *
     *  @param  frontOfficeRecordType a <code> Type </code> indicating a 
     *          <code> FrontOffice </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> frontOfficeRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFrontOfficeRecordType(org.osid.type.Type frontOfficeRecordType);


    /**
     *  Gets the supported <code> FrontOffice </code> search record types. 
     *
     *  @return a list containing the supported <code> FrontOffice </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getFrontOfficeSearchRecordTypes();


    /**
     *  Tests if the given <code> FrontOffice </code> search record type is 
     *  supported. 
     *
     *  @param  frontOfficeSearchRecordType a <code> Type </code> indicating a 
     *          <code> FrontOffice </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          frontOfficeSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFrontOfficeSearchRecordType(org.osid.type.Type frontOfficeSearchRecordType);
}
