//
// org.osid.tracking.batch.SubtaskIssueBatchAdminSession
//
//     The OSID Java specification for org.osid.tracking.batch.SubtaskIssueBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking.batch;


/**
 *  <p>This session creates and deletes <code> Subtasks </code> in bulk. The 
 *  data for create is provided by the consumer via the form object. <code> 
 *  OsidForms </code> are requested for each create or update and may not be 
 *  reused. </p> 
 *  
 *  <p> To create a <code> Subtask, </code> a <code> SubtaskForm </code> is 
 *  requested using <code> getSubtaskFormsForCreate() </code> specifying the 
 *  desired issue, queue, and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. Each of the returned <code> SubtaskForms 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once a 
 *  <code> SubtaskForm </code> is submiited to a create operation, it cannot 
 *  be reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> SubtaskForm </code> corresponds to an attempted 
 *  transaction. </p> 
 *  
 *  <p> The <code> SubtaskForms </code> returned from <code> 
 *  getSubtaskFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> SubtaskForm. 
 *  </code> In the case where there may be duplicates, any <code> SubtaskForm 
 *  </code> of the same peer <code> Ids </code> may be used for a create 
 *  operation. </p> 
 *  
 *  <p> Once a batch of <code> SubtaskForms </code> are submitted for create, 
 *  a <code> CreateResponse </code> is returned for each <code> SubtaskForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createSubtasks(), 
 *  </code> errors specific to an individual <code> SubtaskForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> 
 *  SubtaskForm </code> through the <code> SubtaskForm </code> <code> Id 
 *  </code> . </p>
 */

public interface SubtaskIssueBatchAdminSession
    extends org.osid.tracking.SubtaskIssueAdminSession {


    /**
     *  Gets the subtask forms for creating a bunch of new subtasks. A 
     *  SubtaskForm is returned for each queue and issue. 
     *
     *  @param  peers an <code> Id </code> of a queue 
     *  @param  issueRecordTypes array of issue record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the issue forms 
     *  @throws org.osid.NotFoundException a <code> queueId </code> or <code> 
     *          issueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          issueRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.batch.IssueBatchFormList getSubtaskFormsForCreate(org.osid.tracking.batch.SubtaskIssuePeerList peers, 
                                                                               org.osid.type.Type[] issueRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Subtasks. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  issueForms the issue forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> issueForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createSubtasks(org.osid.tracking.batch.IssueBatchFormList issueForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Subtasks </code> in this <code> FrontOffice </code> 
     *  . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllSubtasks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all subtasks for the given queue. 
     *
     *  @param  queueId an <code> Id </code> of a queue 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> queueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteSubtasksForQueue(org.osid.id.Id queueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all subtasks for the given issue. 
     *
     *  @param  issueId an <code> Id </code> of an issue 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteSubtasksForIssue(org.osid.id.Id issueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
