//
// org.osid.tracking.rules.QueueConstrainerEnablerFrontOfficeSession
//
//     The OSID Java specification for org.osid.tracking.rules.QueueConstrainerEnablerFrontOfficeSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking.rules;


/**
 *  <p>This session provides methods to retrieve <code> 
 *  QueueConstrainerEnabler </code> to <code> FrontOffice </code> mappings. a 
 *  <code> QueueConstrainerEnabler </code> may appear in multiple <code> 
 *  FrontOffice </code> objects. Each front office may have its own 
 *  authorizations governing who is allowed to look at it. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface QueueConstrainerEnablerFrontOfficeSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform lookups of queue constrainer 
     *  enabler/office mappings. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  lookup methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupQueueConstrainerEnablerFrontOfficeMappings();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeQueueConstrainerEnablerFrontOfficeView();


    /**
     *  A complete view of the <code> QueueConstrainerEnabler </code> and 
     *  <code> FrontOffice </code> returns is desired. Methods will return 
     *  what is requested or result in an error. This view is used when 
     *  greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryQueueConstrainerEnablerFrontOfficeView();


    /**
     *  Gets the list of <code> QueueConstrainerEnablerIds </code> associated 
     *  with an <code> FrontFront Office. </code> 
     *
     *  @param  frontOfficeId <code> Id </code> of the <code> FrontOffice 
     *          </code> 
     *  @return list of related queue constrainer enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> frontOfficeId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> frontOfficeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getQueueConstrainerEnablerIdsByFrontOffice(org.osid.id.Id frontOfficeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of queue constrainer enablers associated with an <code> 
     *  FrontFront Office. </code> 
     *
     *  @param  frontOfficeId <code> Id </code> of the <code> FrontOffice 
     *          </code> 
     *  @return list of related queue constrainer enablers 
     *  @throws org.osid.NotFoundException <code> frontOfficeId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> frontOfficeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueConstrainerEnablerList getQueueConstrainerEnablersByFrontOffice(org.osid.id.Id frontOfficeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> QueueConstrainerEnabler Ids </code> 
     *  corresponding to a list of <code> FrontOffices. </code> 
     *
     *  @param  frontOfficeIds list of front office <code> Ids </code> 
     *  @return list of queue constrainer enabler <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> frontOfficeIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getQueueConstrainerEnablerIdsByFrontOffices(org.osid.id.IdList frontOfficeIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of queue constrainer enablers corresponding to a list of 
     *  <code> FrontOffices. </code> 
     *
     *  @param  frontOfficeIds list of front office <code> Ids </code> 
     *  @return list of queue constrainer enablers 
     *  @throws org.osid.NullArgumentException <code> frontOfficeIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueConstrainerEnablerList getQueueConstrainerEnablersByFrontOffices(org.osid.id.IdList frontOfficeIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> FrontOffice </code> <code> Ids </code> mapped to a 
     *  <code> QueueConstrainerEnabler. </code> 
     *
     *  @param  queueConstrainerEnablerId <code> Id </code> of a <code> 
     *          QueueConstrainerEnabler </code> 
     *  @return list of offices 
     *  @throws org.osid.NotFoundException <code> queueConstrainerEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getFrontOfficeIdsByQueueConstrainerEnabler(org.osid.id.Id queueConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> FrontOffices </code> mapped to a <code> 
     *  QueueConstrainerEnabler. </code> 
     *
     *  @param  queueConstrainerEnablerId <code> Id </code> of a <code> 
     *          QueueConstrainerEnabler </code> 
     *  @return list of offices 
     *  @throws org.osid.NotFoundException <code> queueConstrainerEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOfficeList getFrontOfficesByQueueConstrainerEnabler(org.osid.id.Id queueConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
