//
// org.osid.tracking.rules.QueueConstrainerNotificationSession
//
//     The OSID Java specification for org.osid.tracking.rules.QueueConstrainerNotificationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking.rules;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> QueueConstrainer </code> objects in this <code> FrontFront 
 *  Office. </code> This also includes existing <code> QueueConstrainers 
 *  </code> that may appear or disappear due to changes in the <code> 
 *  FrontOffice </code> hierarchy, This session is intended for consumers 
 *  needing to synchronize their state with this service without the use of 
 *  polling. Notifications are cancelled when this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> QueueConstrainerLookupSession. </code> </p>
 */

public interface QueueConstrainerNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> FrontOffice </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> FrontOffice Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFrontOfficeId();


    /**
     *  Gets the <code> FrontOffice </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOffice getFrontOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> QueueConstrainer </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForQueueConstrainerNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include in front offices which are children of this front office in 
     *  the front office hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFrontOfficeView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this front office only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFrontOfficeView();


    /**
     *  Register for notifications of new queue constrainers. <code> 
     *  QueueConstrainerReceiver.newQueueConstrainers() </code> is invoked 
     *  when a new <code> QueueConstrainer </code> appears in this front 
     *  office. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewQueueConstrainers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated front office. <code> 
     *  QueueConstrainerReceiver.changedQueueConstrainers() </code> is invoked 
     *  when a queue constrainer in this front office is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedQueueConstrainers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated queue constrainer. <code> 
     *  ProvisionableReceiver.changedQueueConstrainers() </code> is invoked 
     *  when the specified queue constrainer in this front office is changed. 
     *
     *  @param  queueConstrainerId the <code> Id </code> of the <code> 
     *          QueueConstrainer </code> to monitor 
     *  @throws org.osid.NotFoundException a queue constrainer was not found 
     *          in this queue matchmaker identified by the given <code> Id 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> queueConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedQueueConstrainer(org.osid.id.Id queueConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted queue constrainers. <code> 
     *  QueueConstrainerReceiver.deletedQueueConstrainers() </code> is invoked 
     *  when a queue constrainer is deleted or removed from this front office. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedQueueConstrainers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted queue constrainer. <code> 
     *  QueueConstrainerReceiver.deletedQueueConstrainers() </code> is invoked 
     *  when the specified queue constrainer is deleted or removed from this 
     *  front office. 
     *
     *  @param  queueConstrainerId the <code> Id </code> of the <code> 
     *          QueueConstrainer </code> to monitor 
     *  @throws org.osid.NotFoundException a queue constrainer was not found 
     *          in this queue matchmaker identified by the given <code> Id 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> queueConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedQueueConstrainer(org.osid.id.Id queueConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
