//
// org.osid.tracking.rules.QueueConstrainerQuery
//
//     The OSID Java specification for org.osid.tracking.rules.QueueConstrainerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking.rules;


/**
 *  <p>This is the query for searching queue constrainers. Each method match 
 *  specifies a <code> AND </code> term while multiple invocations of the same 
 *  method produce a nested <code> OR. </code> </p>
 */

public interface QueueConstrainerQuery
    extends org.osid.OsidConstrainerQuery {


    /**
     *  Matches mapped to a queue. 
     *
     *  @param  queueId the queue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> queueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledQueueId(org.osid.id.Id queueId, boolean match);


    /**
     *  Clears the queue <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledQueueIdTerms();


    /**
     *  Tests if a <code> QueueQuery </code> is available. 
     *
     *  @return <code> true </code> if a queue query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledQueueQuery();


    /**
     *  Gets the query for a queue. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the queue query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledQueueQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledQueueQuery() </code> is <code> true. </code> 
     */

    public org.osid.tracking.QueueQuery getRuledQueueQuery();


    /**
     *  Matches constrainers mapped to any queue. 
     *
     *  @param  match <code> true </code> for constrainers mapped to any 
     *          queue, <code> false </code> to match constrainers mapped to no 
     *          queues 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledQueue(boolean match);


    /**
     *  Clears the queue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledQueueTerms();


    /**
     *  Matches constrainers mapped to the front office. 
     *
     *  @param  frontOfficeId the front office <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> frontOfficeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFrontOfficeId(org.osid.id.Id frontOfficeId, boolean match);


    /**
     *  Clears the front office <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFrontOfficeIdTerms();


    /**
     *  Tests if an <code> FrontOfficeQuery </code> is available. 
     *
     *  @return <code> true </code> if a front office query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFrontOfficeQuery();


    /**
     *  Gets the query for a front office. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the front office query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFrontOfficeQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFrontOfficeQuery() </code> is <code> true. </code> 
     */

    public org.osid.tracking.FrontOfficeQuery getFrontOfficeQuery();


    /**
     *  Clears the front office query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFrontOfficeTerms();


    /**
     *  Gets the queue constrainer query record corresponding to the given 
     *  <code> QueueConstrainer </code> record <code> Type. </code> Multiple 
     *  record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  queueConstrainerRecordType a queue constrainer record type 
     *  @return the queue constrainer query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(queueConstrainerRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.records.QueueConstrainerQueryRecord getQueueConstrainerQueryRecord(org.osid.type.Type queueConstrainerRecordType)
        throws org.osid.OperationFailedException;
}
