//
// org.osid.tracking.rules.QueueProcessorEnablerSearchSession
//
//     The OSID Java specification for org.osid.tracking.rules.QueueProcessorEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  QueueProcessorEnabler </code> objects. The search query is constructed 
 *  using the <code> QueueProcessorEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getQueueProcessorEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> QueueProcessorEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getQueueProcessorEnablersBySearch(). </code> It accepts a <code> 
 *  QueueProcessorEnablerSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as tracking. <code> getQueueProcessorEnablersBySearch() </code> returns a 
 *  <code> QueueProcessorEnablerSearchResults </code> that can be used to 
 *  access the resulting <code> QueueProcessorEnablerList </code> or be used 
 *  to perform a search within the result set through <code> 
 *  QueueProcessorEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated front office view: searches include queue processor 
 *      enablers in front office of which this front office matchmaker is an 
 *      ancestor in the front office hierarchy </li> 
 *      <li> isolated front office view: searches are restricted to queue 
 *      processor enablers in this office </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> QueueProcessorEnablers </code> may have a query record 
 *  indicated by their respective query record types. The record is accessed 
 *  via the <code> QueueProcessorEnablerQuery. </code> </p>
 */

public interface QueueProcessorEnablerSearchSession
    extends org.osid.tracking.rules.QueueProcessorEnablerQuerySession {


    /**
     *  Gets a queue processor enabler search. 
     *
     *  @return the queue processor enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorEnablerSearch getQueueProcessorEnablerSearch();


    /**
     *  Gets a queue processor enabler search order. The <code> 
     *  QueueProcessorEnablerSearchOrder </code> is supplied to a <code> 
     *  QueueProcessorEnablerSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the queue processor enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorEnablerSearchOrder getQueueProcessorEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  queueProcessorEnablerQuery the queue processor enabler query 
     *  @param  queueProcessorEnablerSearch the queue processor enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerQuery </code> or <code> 
     *          queueProcessorEnablerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          queueProcessorEnablerQuery </code> or <code> 
     *          queueProcessorEnablerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorEnablerSearchResults getQueueProcessorEnablersBySearch(org.osid.tracking.rules.QueueProcessorEnablerQuery queueProcessorEnablerQuery, 
                                                                                                        org.osid.tracking.rules.QueueProcessorEnablerSearch queueProcessorEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a queue processor enabler query from an inspector. The inspector 
     *  is available from a <code> QueueProcessorEnablerSearchResults. </code> 
     *
     *  @param  queueProcessorEnablerQueryInspector a queue processor enabler 
     *          query inspector 
     *  @return the queue processor enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          queueProcessorEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorEnablerQuery getQueueProcessorEnablerQueryFromInspector(org.osid.tracking.rules.QueueProcessorEnablerQueryInspector queueProcessorEnablerQueryInspector);
}
