//
// org.osid.tracking.rules.QueueProcessorLookupSession
//
//     The OSID Java specification for org.osid.tracking.rules.QueueProcessorLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking.rules;


/**
 *  <p>This session provides methods for retrieving <code> QueueProcessors. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated front office view: All queue processor methods in this 
 *      session operate, retrieve and pertain to queue processor defined 
 *      explicitly in the current front office. Using an isolated view is 
 *      useful for managing <code> QueueProcessors </code> with the <code> 
 *      QueueProcessorAdminSession. </code> </li> 
 *      <li> federated front office view: All queue processor methods in this 
 *      session operate, retrieve and pertain to all queue processor defined 
 *      in this front office and any other queue processor implicitly 
 *      available in this front office through front office inheritence. </li> 
 *      <li> active queue processor view: All queue processor lookup methods 
 *      return active queue processors. </li> 
 *      <li> any status queue processor view: Queue processors of any active 
 *      or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedFrontOfficeView() </code> and <code> 
 *  useIsolatedFrontOfficeView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface QueueProcessorLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> FrontOffice </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> FrontOffice Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFrontOfficeId();


    /**
     *  Gets the <code> FrontOffice </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOffice getFrontOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> QueueProcessors </code> lookups. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupQueueProcessors();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeQueueProcessorView();


    /**
     *  A complete view of the <code> QueueProcessor </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryQueueProcessorView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include queue processor in front offices which are children of this 
     *  front office in the front office hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFrontOfficeView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this front office only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFrontOfficeView();


    /**
     *  Only active queue processors are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveQueueProcessorView();


    /**
     *  All active and inactive queue processors are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusQueueProcessorView();


    /**
     *  Gets the <code> QueueProcessor </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  QueueProcessor </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> QueueProcessor </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, queue processors are returned that are currently 
     *  active. In any status mode, active and inactive queue processors are 
     *  returned. 
     *
     *  @param  queueProcessorId <code> Id </code> of the <code> 
     *          QueueProcessor </code> 
     *  @return the queue processor 
     *  @throws org.osid.NotFoundException <code> queueProcessorId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> queueProcessorId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessor getQueueProcessor(org.osid.id.Id queueProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QueueProcessorList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  queue processor specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if a <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> QueueProcessors </code> may be omitted from the 
     *  list and may present the elements in any order including returning a 
     *  unique set. 
     *  
     *  In active mode, queue processors are returned that are currently 
     *  active. In any status mode, active and inactive queue processors are 
     *  returned. 
     *
     *  @param  queueProcessorIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> QueueProcessor </code> list 
     *  @throws org.osid.NotFoundException a <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> queueProcessorIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorList getQueueProcessorsByIds(org.osid.id.IdList queueProcessorIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QueueProcessorList </code> corresponding to the given 
     *  queue processor genus <code> Type </code> which does not include queue 
     *  processor of genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  queue processor or an error results. Otherwise, the returned list may 
     *  contain only those queue processor that are accessible through this 
     *  session. 
     *  
     *  In active mode, queue processors are returned that are currently 
     *  active. In any status mode, active and inactive queue processors are 
     *  returned. 
     *
     *  @param  queueProcessorGenusType a queue processor genus type 
     *  @return the returned <code> QueueProcessor </code> list 
     *  @throws org.osid.NullArgumentException <code> queueProcessorGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorList getQueueProcessorsByGenusType(org.osid.type.Type queueProcessorGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QueueProcessorList </code> corresponding to the given 
     *  queue processor genus <code> Type </code> and include any additional 
     *  queue processor with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  queue processor or an error results. Otherwise, the returned list may 
     *  contain only those queue processor that are accessible through this 
     *  session. 
     *  
     *  In active mode, queue processors are returned that are currently 
     *  active. In any status mode, active and inactive queue processors are 
     *  returned. 
     *
     *  @param  queueProcessorGenusType a queue processor genus type 
     *  @return the returned <code> QueueProcessor </code> list 
     *  @throws org.osid.NullArgumentException <code> queueProcessorGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorList getQueueProcessorsByParentGenusType(org.osid.type.Type queueProcessorGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QueueProcessorList </code> containing the given queue 
     *  processor record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  queue processor or an error results. Otherwise, the returned list may 
     *  contain only those queue processor that are accessible through this 
     *  session. 
     *  
     *  In active mode, queue processors are returned that are currently 
     *  active. In any status mode, active and inactive queue processors are 
     *  returned. 
     *
     *  @param  queueProcessorRecordType a queue processor record type 
     *  @return the returned <code> QueueProcessor </code> list 
     *  @throws org.osid.NullArgumentException <code> queueProcessorRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorList getQueueProcessorsByRecordType(org.osid.type.Type queueProcessorRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> QueueProcessors. </code> 
     *  
     *  In plenary mode, the returned list contains all known queue processor 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those queue processor that are accessible through this session. 
     *  
     *  In active mode, queue processors are returned that are currently 
     *  active. In any status mode, active and inactive queue processors are 
     *  returned. 
     *
     *  @return the returned <code> QueueProcessor </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorList getQueueProcessors()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
