//
// org.osid.transaction.TransactionSession
//
//     The OSID Java specification for org.osid.transaction.TransactionSession.
//
// Copyright (C) 2002, 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.transaction;


/**
 *  <p>The transaction session is coordinate transactions. A transaction 
 *  session allows for <code> Transactions </code> to be added to the list of 
 *  transactions it is managing. Upon a <code> commit(), </code> all 
 *  registered transactions receive a <code> prepare() </code> and a <code> 
 *  commit(). </code> Upon an <code> abort() </code> all registered 
 *  transactions receive an <code> abort(). </code> A <code> 
 *  TransactionSession </code> itself may implement transactions (as it is an 
 *  <code> OsidSession </code> ) as a means of enabling a form of federated 
 *  transaction management. </p>
 */

public interface TransactionSession
    extends org.osid.OsidSession {


    /**
     *  Adds a Transaction to be managed by this transaction service. 
     *
     *  @param  transaction the transaction to add 
     *  @throws org.osid.AlreadyExistsException transaction already added 
     *  @throws org.osid.IllegalStateException this transaction has ended 
     *  @throws org.osid.InvalidArgumentException the session doesn't support 
     *          transactions 
     *  @throws org.osid.NullArgumentException a <code> null </code> argument 
     *          provided 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void add(org.osid.transaction.Transaction transaction)
        throws org.osid.AlreadyExistsException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Commits the transaction and makes the state change(s) visible. This 
     *  transaction is effectively closed and the only valid method that may 
     *  be invoked is <code> getState(). </code> 
     *
     *  @throws org.osid.IllegalStateException this transaction has been 
     *          committed or aborted 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  <code> prepare() </code> should be invoked on all regstered 
     *          transactions and iff all are successful should <code> commit() 
     *          </code> be invoked on all registered transactions. In case of 
     *          error on any <code> prepare(), </code> all transactions should 
     *          be aborted. If an error occurs on a <code> commit() </code> 
     *          after a transaction reported success on a <code> prepare() 
     *          </code> after one or more transactions were already committed, 
     *          then it is not ACID compliant and success should be assumed by 
     *          committing the rest of the transactions. If a <code> commit() 
     *          </code> error occurs when no transactions have been committed, 
     *          then this operation should not proceed. 
     */

    public void commit()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Cancels this transaction, rolling back the queue of operations since 
     *  the start of this transaction. This transaction is effectively closed 
     *  and the only valid method that may be invoked is <code> getState(). 
     *  </code> 
     *
     *  @throws org.osid.IllegalStateException this transaction has been 
     *          committed or aborted 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  Invokes <code> abort() </code> on all registered 
     *          transactions(). 
     */

    public void abort();


    /**
     *  Gets the current state of this transaction. 
     *
     *  @return the current state of this transaction 
     *  @throws org.osid.IllegalStateException this transaction has been 
     *          committed or aborted 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.TransactionState getState();
}
