//
// org.osid.type.TypeAdminSession
//
//     The OSID Java specification for org.osid.type.TypeAdminSession.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.type;


/**
 *  <p>This session is used to create, update and delete <code> Types </code> 
 *  in the registry. </p>
 */

public interface TypeAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> Types. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Type </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Type </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateTypes();


    /**
     *  Gets the type form for creating new types. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  type the <code> Type </code> to be created 
     *  @return the type form 
     *  @throws org.osid.NullArgumentException <code> type </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeForm getTypeFormForCreate(org.osid.type.Type type)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Type. </code> 
     *
     *  @param  typeForm the type form 
     *  @return the created <code> Type </code> 
     *  @throws org.osid.IllegalStateException <code> typeForm </code> already 
     *          used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the arguments 
     *          is invalid 
     *  @throws org.osid.NullArgumentException <code> typeForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> typeForm </code> did not 
     *          originate from <code> getTypeFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type createType(org.osid.type.TypeForm typeForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update types. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> Type </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if type modification is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateTypes();


    /**
     *  Gets the type form for creating new types. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  type the <code> Type </code> to be updated 
     *  @return the type form 
     *  @throws org.osid.NotFoundException <code> type </code> not found 
     *  @throws org.osid.NullArgumentException <code> type </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeForm getTypeFormForUpdate(org.osid.type.Type type)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates a type. 
     *
     *  @param  typeForm the type form 
     *  @throws org.osid.IllegalStateException <code> typeForm </code> already 
     *          used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> typeForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> typeForm </code> did not 
     *          originate from <code> getTypeFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateType(org.osid.type.TypeForm typeForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Types </code> from this <code> 
     *  ItemBank. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known deleting a 
     *  <code> Type </code> will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  delete operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Item </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteTypes();


    /**
     *  Tests if this user can delete the specified type. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleteing the <code> Type </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @param  type the <code> Type </code> to be deleted 
     *  @return <code> false </code> if type deletion is not authorized, 
     *          <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> type </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteType(org.osid.type.Type type);


    /**
     *  Removes a <code> Type. </code> 
     *
     *  @param  type the <code> Type </code> to remove 
     *  @throws org.osid.NotFoundException <code> type </code> is not found 
     *  @throws org.osid.NullArgumentException <code> type </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteType(org.osid.type.Type type)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Makes two <code> Types </code> equivalent. Calls to <code> 
     *  TypeLookupSession.getType(equivalentType) </code> return the <code> 
     *  primaryType. </code> 
     *
     *  @param  primaryType the primary <code> Type </code> 
     *  @param  equivalentType a <code> Type </code> to be made equivalent 
     *  @throws org.osid.NotFoundException <code> primaryType </code> or 
     *          <code> equivalentType </code> is not found 
     *  @throws org.osid.NullArgumentException <code> primaryType </code> or 
     *          <code> equivalentType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void makeEquivalent(org.osid.type.Type primaryType, 
                               org.osid.type.Type equivalentType)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds a base type to a type. A base type is a parent of the type where 
     *  the type implies support of the base type. 
     *
     *  @param  type a <code> Type </code> 
     *  @param  baseType a base type 
     *  @throws org.osid.NotFoundException <code> type </code> or <code> 
     *          baseType </code> is not found 
     *  @throws org.osid.NullArgumentException <code> type </code> or <code> 
     *          baseType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addBaseType(org.osid.type.Type type, 
                            org.osid.type.Type baseType)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a base type from a type. 
     *
     *  @param  type a <code> Type </code> 
     *  @param  baseType a base type 
     *  @throws org.osid.NotFoundException <code> type </code> or <code> 
     *          baseType </code> is not found or <code> baseType </code> is 
     *          not a base of <code> type </code> 
     *  @throws org.osid.NullArgumentException <code> type </code> or <code> 
     *          baseType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeBaseType(org.osid.type.Type type, 
                               org.osid.type.Type baseType)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds a relation between two types. The relationship is a <code> Type 
     *  </code> in itself. 
     *
     *  @param  sourceType the source type 
     *  @param  destinationType the destination type 
     *  @param  relationType the relation type 
     *  @throws org.osid.NotFoundException <code> sourceType, destinationType, 
     *          </code> or <code> relationType </code> is not found 
     *  @throws org.osid.NullArgumentException <code> sourceType, 
     *          destinationType, </code> or <code> relationType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addTypeRelation(org.osid.type.Type sourceType, 
                                org.osid.type.Type destinationType, 
                                org.osid.type.Type relationType)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Renoves a relation between two types. 
     *
     *  @param  sourceType the source type 
     *  @param  destinationType the destination type 
     *  @param  relationType the relation type 
     *  @throws org.osid.NotFoundException <code> sourceType, destinationType, 
     *          </code> or <code> relationType </code> is not found, or the 
     *          relationship does not exist 
     *  @throws org.osid.NullArgumentException <code> sourceType, 
     *          destinationType, </code> or <code> relationType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeTypeRelation(org.osid.type.Type sourceType, 
                                   org.osid.type.Type destinationType, 
                                   org.osid.type.Type relationType)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
