//
// org.osid.type.TypeForm
//
//     The OSID Java specification for org.osid.type.TypeForm.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.type;


/**
 *  <p>This form provides a means of updating various fields in the <code> 
 *  Type. </code> Note that the domain, authority and identifier are part of 
 *  the <code> Type </code> identification, and as such not modifiable. </p>
 */

public interface TypeForm
    extends org.osid.OsidForm {


    /**
     *  Gets the metadata for the display name. 
     *
     *  @return metadata for the display name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDisplayNameMetadata();


    /**
     *  Sets a display name. 
     *
     *  @param  displayName the new display name 
     *  @throws org.osid.InvalidArgumentException <code> displayName </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> displayName </code> cannot 
     *          be modified 
     *  @throws org.osid.NullArgumentException <code> displayName </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDisplayName(String displayName);


    /**
     *  Clears the display name. 
     *
     *  @throws org.osid.NoAccessException <code> displayName </code> cannot 
     *          be modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDisplayName();


    /**
     *  Gets the metadata for the display label. 
     *
     *  @return metadata for the display label 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDisplayLabelMetadata();


    /**
     *  Seta a display label. 
     *
     *  @param  displayLabel the new display label 
     *  @throws org.osid.InvalidArgumentException <code> displayLabel </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> displayLabel </code> cannot 
     *          be modified 
     *  @throws org.osid.NullArgumentException <code> displayLabel </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDisplayLabel(String displayLabel);


    /**
     *  Clears the display label. 
     *
     *  @throws org.osid.NoAccessException <code> displayLabel </code> cannot 
     *          be modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDisplayLabel();


    /**
     *  Gets the metadata for the description. 
     *
     *  @return metadata for the description 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDescriptionMetadata();


    /**
     *  Sets a description. 
     *
     *  @param  description the new description 
     *  @throws org.osid.InvalidArgumentException <code> description </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> description </code> cannot 
     *          be modified 
     *  @throws org.osid.NullArgumentException <code> description </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDescription(String description);


    /**
     *  Clears the description. 
     *
     *  @throws org.osid.NoAccessException <code> description </code> cannot 
     *          be modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescription();


    /**
     *  Gets the metadata for the domain. 
     *
     *  @return metadata for the domain 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDomainMetadata();


    /**
     *  Sets a domain. 
     *
     *  @param  domain the new domain 
     *  @throws org.osid.InvalidArgumentException <code> domain </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> domain </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> domain </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDomain(String domain);


    /**
     *  Clears the domain. 
     *
     *  @throws org.osid.NoAccessException <code> domain </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDomain();
}
