//
// org.osid.type.TypeLookupSession
//
//     The OSID Java specification for org.osid.type.TypeLookupSession.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.type;


/**
 *  <p>This session retrieves Types. A single Type can be retrieved using 
 *  <code> getType() </code> and all types known to this service can be 
 *  accessed via <code> getTypes() </code> . </p>
 */

public interface TypeLookupSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform <code> Type </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupTypes();


    /**
     *  Gets a <code> Type </code> by its string representation which is a 
     *  combination of the authority and identifier. This method only returns 
     *  the <code> Type </code> if it is known by the given identification 
     *  components. 
     *
     *  @param  namespace the identifier namespace 
     *  @param  identifier the identifier 
     *  @param  authority the authority 
     *  @return the <code> Type </code> 
     *  @throws org.osid.NotFoundException the type is not found 
     *  @throws org.osid.NullArgumentException <code> null </code> argument 
     *          provided 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getType(String namespace, String identifier, 
                                      String authority)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if the given <code> Type </code> is known. 
     *
     *  @param  type the <code> Type </code> to look for 
     *  @return <code> true </code> if the given <code> Type </code> is known, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> type </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasType(org.osid.type.Type type)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all the known Types by domain. 
     *
     *  @param  domain the domain 
     *  @return the list of <code> Types </code> with the given domain 
     *  @throws org.osid.NullArgumentException <code> domain </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTypesByDomain(String domain)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all the known Types by authority. 
     *
     *  @param  authority the authority 
     *  @return the list of <code> Types </code> with the given authority 
     *  @throws org.osid.NullArgumentException <code> authority </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException respect my authoritay 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTypesByAuthority(String authority)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all the known Types by domain and authority. 
     *
     *  @param  domain the domain 
     *  @param  authority the authority 
     *  @return the list of <code> Types </code> with the given domain and 
     *          authority 
     *  @throws org.osid.NullArgumentException <code> domain </code> or <code> 
     *          authority </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTypesByDomainAndAuthority(String domain, 
                                                               String authority)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all the known Types. 
     *
     *  @return the list of all known <code> Types </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTypes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if the given types are equivalent. 
     *
     *  @param  type a type 
     *  @param  equivalentType another type 
     *  @return <code> true </code> if both types are equivalent, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> type </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isEquivalent(org.osid.type.Type type, 
                                org.osid.type.Type equivalentType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if the given type is implies support of a base type. 
     *
     *  @param  type a type 
     *  @param  baseType another type 
     *  @return <code> true </code> if <code> baseType </code> if supported by 
     *          <code> type, </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> type </code> or <code> 
     *          baseType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean impliesSupport(org.osid.type.Type type, 
                                  org.osid.type.Type baseType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if the given type is derived from a base type. 
     *
     *  @param  type a type 
     *  @return <code> true </code> is the given type is derived from a base 
     *          type, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> type </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasBaseType(org.osid.type.Type type)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the immediate base types of this type. 
     *
     *  @param  type a type 
     *  @return the base types 
     *  @throws org.osid.NullArgumentException <code> type </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBaseTypes(org.osid.type.Type type)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all known relation <code> Types. </code> A relation Types relates 
     *  two <code> Types. </code> 
     *
     *  @return known relation types 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRelationTypes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all source <code> Types </code> related by the given type. 
     *
     *  @param  relationType a relation type 
     *  @return the source types 
     *  @throws org.osid.NullArgumentException <code> relationType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSourceTypesByRelationType(org.osid.type.Type relationType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all destination Types related to the given source <code> Type. 
     *  </code> 
     *
     *  @param  sourceType a source type 
     *  @return the related types 
     *  @throws org.osid.NullArgumentException <code> sourceType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDestinationTypesBySource(org.osid.type.Type sourceType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all destination Types related to the given source <code> Type 
     *  </code> and relation <code> Type. </code> 
     *
     *  @param  sourceType a source type 
     *  @param  relationType a relation type 
     *  @return the related types 
     *  @throws org.osid.NullArgumentException <code> sourceType </code> or 
     *          <code> relationType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDestinationTypesBySourceAndRelationType(org.osid.type.Type sourceType, 
                                                                             org.osid.type.Type relationType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all destination <code> Types </code> related by the given type. 
     *
     *  @param  relationType a relation type 
     *  @return the destination types 
     *  @throws org.osid.NullArgumentException <code> relationType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDestinationTypesByRelationType(org.osid.type.Type relationType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all source Types related to the given destination <code> Type. 
     *  </code> 
     *
     *  @param  destinationType a destination type 
     *  @return the source types 
     *  @throws org.osid.NullArgumentException <code> destinationType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSourceTypesByDestination(org.osid.type.Type destinationType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all source Types related to the given destination <code> Type 
     *  </code> and relation <code> Type. </code> 
     *
     *  @param  destinationType a destination type 
     *  @param  relationType a relation type 
     *  @return the related types 
     *  @throws org.osid.NullArgumentException <code> destinationType </code> 
     *          or <code> relationType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSourceTypesByDestinationAndRelationType(org.osid.type.Type destinationType, 
                                                                             org.osid.type.Type relationType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
