//
// org.osid.voting.CandidateAdminSession
//
//     The OSID Java specification for org.osid.voting.CandidateAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This session creates, updates, and deletes <code> Candidates. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Candidate, </code> a <code> CandidateForm </code> is requested using 
 *  <code> getCandidateFormForCreate() </code> specifying the <code> Race 
 *  </code> and desired record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. The returned <code> CandidateForm </code> 
 *  will indicate that it is to be used with a create operation and can be 
 *  used to examine metdata or validate data prior to creation. Once the 
 *  <code> CandidateForm </code> is submiited to a create operation, it cannot 
 *  be reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> CandidateForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> CandidateForms </code> are requested to the <code> 
 *  Candidate </code> <code> Id </code> that is to be updated using <code> 
 *  getCandidateFormForUpdate(). </code> Similarly, the <code> CandidateForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> CandidateForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Candidates. </code> To unmap a 
 *  <code> Candidate </code> from the current <code> Polls, </code> the <code> 
 *  CandidatePollsAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Candidate </code> itself thus 
 *  removing it from all known <code> Polls </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface CandidateAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the <code> Polls </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Candidates. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Candidate </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Candidate </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCandidates();


    /**
     *  Tests if this user can create a single <code> Candidate </code> using 
     *  the desired record types. While <code> 
     *  VotingManager.getCandidateRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Candidate. </code> Providing 
     *  an empty array tests if a <code> Candidate </code> can be created with 
     *  no records. 
     *
     *  @param  candidateRecordTypes array of candidate record types 
     *  @return <code> true </code> if <code> Candidate </code> creation using 
     *          the specified <code> Types </code> is supported, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> candidateRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCandidateWithRecordTypes(org.osid.type.Type[] candidateRecordTypes);


    /**
     *  Gets the candidate form for creating new candidates. A new form should 
     *  be requested for each create transaction. 
     *
     *  @param  resourceId the resource Id 
     *  @param  raceId the race Id 
     *  @param  candidateRecordTypes array of candidate record types 
     *  @return the candidate form 
     *  @throws org.osid.NotFoundException <code> resourceId </code> or <code> 
     *          raceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> resourceId, raceId 
     *          </code> or <code> candidateRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form with 
     *          requested record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateForm getCandidateFormForCreate(org.osid.id.Id resourceId, 
                                                                   org.osid.id.Id raceId, 
                                                                   org.osid.type.Type[] candidateRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Candidate. </code> 
     *
     *  @param  candidateForm the form for this <code> Candidate </code> 
     *  @return the new <code> Candidate </code> 
     *  @throws org.osid.IllegalStateException <code> candidateForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> candidateForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> candidateForm </code> did 
     *          not originate from <code> getCandidateFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Candidate createCandidate(org.osid.voting.CandidateForm candidateForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Candidates. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Candidate </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Candidate </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateCandidates();


    /**
     *  Gets the candidate form for updating an existing candidate. A new 
     *  candidate form should be requested for each update transaction. 
     *
     *  @param  candidateId the <code> Id </code> of the <code> Candidate 
     *          </code> 
     *  @return the candidate form 
     *  @throws org.osid.NotFoundException <code> candidateId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> candidateId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateForm getCandidateFormForUpdate(org.osid.id.Id candidateId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing candidate. 
     *
     *  @param  candidateForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> candidateForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> candidateForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> candidateForm </code> did 
     *          not originate from <code> getCandidateFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateCandidate(org.osid.voting.CandidateForm candidateForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Candidates. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Candidate </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Candidate </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteCandidates();


    /**
     *  Deletes a <code> Candidate. </code> 
     *
     *  @param  candidateId the <code> Id </code> of the <code> Candidate 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> candidateId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> candidateId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCandidate(org.osid.id.Id candidateId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Candidates. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Candidate </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCandidateAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Candidate </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Candidate </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another candidate it is 
     *  reassigned to the given candidate <code> Id. </code> 
     *
     *  @param  candidateId the <code> Id </code> of a <code> Candidate 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> candidateId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> aliasId </code> or 
     *          <code> candidateId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasCandidate(org.osid.id.Id candidateId, 
                               org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
