//
// org.osid.voting.CandidateLookupSession
//
//     The OSID Java specification for org.osid.voting.CandidateLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This session defines methods for retrieving candidates. A <code> 
 *  Candidate </code> is an arbitrary entity that may represent a person, 
 *  place or thing used to identify an object used in various services. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated polls view: All candidate methods in this session 
 *      operate, retrieve and pertain to candidates defined explicitly in the 
 *      current polls. Using an isolated view is useful for managing <code> 
 *      Candidates </code> with the <code> CandidateAdminSession. </code> 
 *      </li> 
 *      <li> federated polls view: All candidate methods in this session 
 *      operate, retrieve and pertain to all candidates defined in this polls 
 *      and any other candidates implicitly available in this polls through 
 *      polls inheritence. </li> 
 *      <li> effective candidate view: All candidate lookup methods return 
 *      candidates where the current date falls in between the effective dates 
 *      inclusive. </li> 
 *      <li> any effective candidate view: Candidates of any effective date 
 *      are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedPollsView() </code> and <code> 
 *  useIsolatedPollsView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p> 
 *  
 *  <p> Candidates may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> Candidate. </code> </p>
 */

public interface CandidateLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the <code> Polls </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Candidate </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCandidates();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCandidateView();


    /**
     *  A complete view of the <code> Candidate </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCandidateView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include candidates in polls which are children of this polls in the 
     *  polls hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedPollsView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this polls only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedPollsView();


    /**
     *  Only candidates whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveCandidateView();


    /**
     *  All candidates of any effective dates are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveCandidateView();


    /**
     *  Gets the <code> Candidate </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Candidate </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Candidate </code> and retained for compatibility. 
     *  
     *  In effective mode, candidates are returned that are currently 
     *  effective. In any effective mode, effective candidates and those 
     *  currently expired are returned. 
     *
     *  @param  candidateId the <code> Id </code> of the <code> Candidate 
     *          </code> to retrieve 
     *  @return the returned <code> Candidate </code> 
     *  @throws org.osid.NotFoundException no <code> Candidate </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> candidateId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Candidate getCandidate(org.osid.id.Id candidateId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CandidateList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  candidates specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Candidates </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, candidates are returned that are currently 
     *  effective. In any effective mode, effective candidates and those 
     *  currently expired are returned. 
     *
     *  @param  candidateIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Candidate </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> candidateIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateList getCandidatesByIds(org.osid.id.IdList candidateIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CandidateList </code> corresponding to the given 
     *  candidate genus <code> Type </code> which does not include candidates 
     *  of types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  candidates or an error results. Otherwise, the returned list may 
     *  contain only those candidates that are accessible through this 
     *  session. 
     *  
     *  In effective mode, candidates are returned that are currently 
     *  effective. In any effective mode, effective candidates and those 
     *  currently expired are returned. 
     *
     *  @param  candidateGenusType a candidate genus type 
     *  @return the returned <code> Candidate </code> list 
     *  @throws org.osid.NullArgumentException <code> candidateGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateList getCandidatesByGenusType(org.osid.type.Type candidateGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CandidateList </code> corresponding to the given 
     *  candidate genus <code> Type </code> and include any additional 
     *  candidates with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  candidates or an error results. Otherwise, the returned list may 
     *  contain only those candidates that are accessible through this 
     *  session. 
     *  
     *  In effective mode, candidates are returned that are currently 
     *  effective. In any effective mode, effective candidates and those 
     *  currently expired are returned. 
     *
     *  @param  candidateGenusType a candidate genus type 
     *  @return the returned <code> Candidate </code> list 
     *  @throws org.osid.NullArgumentException <code> candidateGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateList getCandidatesByParentGenusType(org.osid.type.Type candidateGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CandidateList </code> containing the given candidate 
     *  record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known candidates or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  candidates that are accessible through this session. 
     *  
     *  In effective mode, candidates are returned that are currently 
     *  effective. In any effective mode, effective candidates and those 
     *  currently expired are returned. 
     *
     *  @param  candidateRecordType a candidate record type 
     *  @return the returned <code> Candidate </code> list 
     *  @throws org.osid.NullArgumentException <code> candidateRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateList getCandidatesByRecordType(org.osid.type.Type candidateRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of candidates effective during the entire given date range 
     *  inclusive but not confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  candidates or an error results. Otherwise, the returned list may 
     *  contain only those availabilities that are accessible through this 
     *  session. 
     *  
     *  In effective mode, candidates are returned that are currently 
     *  effective. In any effective mode, effective candidates and those 
     *  currently expired are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Candidate </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateList getCandidatesOnDate(org.osid.calendaring.DateTime from, 
                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CandidateList </code> in the given race. 
     *  
     *  In plenary mode, the returned list contains all known candidates or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  candidates that are accessible through this session. 
     *  
     *  In effective mode, candidates are returned that are currently 
     *  effective. In any effective mode, effective candidates and those 
     *  currently expired are returned. 
     *
     *  @param  raceId a race <code> Id </code> 
     *  @return the returned <code> Candidate </code> list 
     *  @throws org.osid.NullArgumentException <code> raceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateList getCandidatesForRace(org.osid.id.Id raceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of candidates for the given race effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  candidates or an error results. Otherwise, the returned list may 
     *  contain only those availabilities that are accessible through this 
     *  session. 
     *  
     *  In effective mode, candidates are returned that are currently 
     *  effective. In any effective mode, effective candidates and those 
     *  currently expired are returned. 
     *
     *  @param  raceId a race <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Candidate </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> raceId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateList getCandidatesForRaceOnDate(org.osid.id.Id raceId, 
                                                                    org.osid.calendaring.DateTime from, 
                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CandidateList </code> associated with the given 
     *  resource. 
     *  
     *  In plenary mode, the returned list contains all known candidates or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  candidates that are accessible through this session. 
     *  
     *  In effective mode, candidates are returned that are currently 
     *  effective. In any effective mode, effective candidates and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Candidate </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateList getCandidatesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of candidates for the given resource effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  candidates or an error results. Otherwise, the returned list may 
     *  contain only those availabilities that are accessible through this 
     *  session. 
     *  
     *  In effective mode, candidates are returned that are currently 
     *  effective. In any effective mode, effective candidates and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Candidate </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateList getCandidatesForResourceOnDate(org.osid.id.Id resourceId, 
                                                                        org.osid.calendaring.DateTime from, 
                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CandidateList </code> in the given race and resource. 
     *  
     *  In plenary mode, the returned list contains all known candidates or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  candidates that are accessible through this session. 
     *  
     *  In effective mode, candidates are returned that are currently 
     *  effective. In any effective mode, effective candidates and those 
     *  currently expired are returned. 
     *
     *  @param  raceId a race <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Candidate </code> list 
     *  @throws org.osid.NullArgumentException <code> raceId </code> or <code> 
     *          resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateList getCandidatesForRaceAndResource(org.osid.id.Id raceId, 
                                                                         org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of candidates for the given race and resource effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  candidates or an error results. Otherwise, the returned list may 
     *  contain only those availabilities that are accessible through this 
     *  session. 
     *  
     *  In effective mode, candidates are returned that are currently 
     *  effective. In any effective mode, effective candidates and those 
     *  currently expired are returned. 
     *
     *  @param  raceId a race <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Candidate </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> raceId, resourceId, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateList getCandidatesForRaceAndResourceOnDate(org.osid.id.Id raceId, 
                                                                               org.osid.id.Id resourceId, 
                                                                               org.osid.calendaring.DateTime from, 
                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Candidates. </code> 
     *  
     *  In plenary mode, the returned list contains all known candidates or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  candidates that are accessible through this session. 
     *  
     *  In effective mode, candidates are returned that are currently 
     *  effective. In any effective mode, effective candidates and those 
     *  currently expired are returned. 
     *
     *  @return a list of <code> Candidates </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateList getCandidates()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
