//
// org.osid.voting.CandidateSearchOrder
//
//     The OSID Java specification for org.osid.voting.CandidateSearchOrder.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface CandidateSearchOrder
    extends org.osid.OsidRelationshipSearchOrder {


    /**
     *  Specified a preference for ordering results by the race. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRace(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> RaceSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if a race search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceSearchOrder();


    /**
     *  Gets the search order for a race. 
     *
     *  @return the race search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceSearchOrder() </code> is <code> true. </code> 
     */

    public org.osid.voting.RaceSearchOrder getRaceSearchOrder();


    /**
     *  Specified a preference for ordering results by the assoicated 
     *  resource. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByResource(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> ResourceSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if a resource search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceSearchOrder();


    /**
     *  Gets the search order for the associated resource. 
     *
     *  @return the resource search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceSearchOrder getResourceSearchOrder();


    /**
     *  Gets the candidate search order record corresponding to the given 
     *  candidate record <code> Type. </code> Multiple retrievals return the 
     *  same underlying object. 
     *
     *  @param  candidateRecordType a candidate record type 
     *  @return the candidate search order record 
     *  @throws org.osid.NullArgumentException <code> candidateRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(candidateRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.records.CandidateSearchOrderRecord getCandidateSearchOrderRecord(org.osid.type.Type candidateRecordType)
        throws org.osid.OperationFailedException;
}
