//
// org.osid.voting.CandidateSearchSession
//
//     The OSID Java specification for org.osid.voting.CandidateSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This session provides methods for searching among <code> Candidate 
 *  </code> objects. The search query is constructed using the <code> 
 *  CandidateQuery. </code> </p> 
 *  
 *  <p> <code> getCandidatesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Candidates. </code> A more advanced search may be 
 *  performed with <code> getCandidatesBySearch(). </code> It accepts an 
 *  <code> CandidateSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getCandidatesBySearch() </code> returns an <code> 
 *  CandidateSearchResults </code> that can be used to access the resulting 
 *  <code> CandidateList </code> or be used to perform a search within the 
 *  result set through <code> CandidateList. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated polls view: searches include candidates in polls of 
 *      which this polls is a ancestor in the polls hierarchy </li> 
 *      <li> isolated polls view: searches are restricted to candidates in 
 *      this polls </li> 
 *  </ul>
 *  
 *  
 *  <p> Candidates may have a candidiate query record indicated by their 
 *  respective record types. The candidiate query record is accessed via the 
 *  <code> CandidateQuery. </code> </p>
 */

public interface CandidateSearchSession
    extends org.osid.voting.CandidateQuerySession {


    /**
     *  Gets a candidate search. 
     *
     *  @return the candidate search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateSearch getCandidateSearch();


    /**
     *  Gets a candidate search order. The <code> CandidateSearchOrder </code> 
     *  is supplied to a <code> CandidateSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the candidate search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateSearchOrder getCandidateSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  candidateQuery the candidate query 
     *  @param  candidateSearch the candidate search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> candidateQuery </code> 
     *          or <code> candidateSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> candidateQuery </code> or 
     *          <code> candidateSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateSearchResults getCandidatesBySearch(org.osid.voting.CandidateQuery candidateQuery, 
                                                                        org.osid.voting.CandidateSearch candidateSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a candidate query from an inspector. The inspector is available 
     *  from a <code> CandidateSearchResults. </code> 
     *
     *  @param  candidateQueryInspector a candidate query inspector 
     *  @return the candidate query 
     *  @throws org.osid.NullArgumentException <code> candidateQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> candidateQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateQuery getCandidateQueryFromInspector(org.osid.voting.CandidateQueryInspector candidateQueryInspector);
}
