//
// org.osid.voting.CandidateSmartPollsSession
//
//     The OSID Java specification for org.osid.voting.CandidateSmartPollsSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> CandidateQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Polls </code> to create a virtual 
 *  collection of <code> Candidates. </code> The candidates may be sequenced 
 *  using the <code> CandidateSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Polls </code> has a default query that matches any 
 *  candidate and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> CandidateQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to a <code> 
 *  CandidateQuery. </code> </p>
 */

public interface CandidateSmartPollsSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the <code> Polls </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart polls. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart polls management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartPolls();


    /**
     *  Gets a candidate query. 
     *
     *  @return the candidate query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateQuery getCandidateQuery();


    /**
     *  Gets a candidate search order. 
     *
     *  @return the candidate search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateSearchOrder getCandidateSearchOrder();


    /**
     *  Applies a candidate query to this polls. 
     *
     *  @param  candidateQuery the candidate query 
     *  @throws org.osid.NullArgumentException <code> candidateQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> candidateQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyCandidateQuery(org.osid.voting.CandidateQuery candidateQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a candidate query inspector for this polls. 
     *
     *  @return the candidate query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateQueryInspector inspectCandidateQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a candidate search order to this polls. 
     *
     *  @param  candidateSearchOrder the candidate search order 
     *  @throws org.osid.NullArgumentException <code> candidateSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> candidateSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyCandidateSequencing(org.osid.voting.CandidateSearchOrder candidateSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a candidate query from an inspector. 
     *
     *  @param  candidateQueryInspector a candidate query inspector 
     *  @return the candidate query 
     *  @throws org.osid.NullArgumentException <code> candidateQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> candidateQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.CandidateQuery getCandidateQueryFromInspector(org.osid.voting.CandidateQueryInspector candidateQueryInspector);
}
