//
// org.osid.voting.PollsSearchSession
//
//     The OSID Java specification for org.osid.voting.PollsSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This session provides methods for searching among <code> Polls </code> 
 *  objects. The search query is constructed using the <code> PollsQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getPollsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Polls </code> objects.A more advanced search may 
 *  be performed with <code> getPollsBySearch(). </code> It accepts a <code> 
 *  PollsSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getPollsBySearch() </code> returns a <code> PollsSearchResults </code> 
 *  that can be used to access the resulting <code> PollsList </code> or be 
 *  used to perform a search within the result set through <code> PollsSearch. 
 *  </code> </p> 
 *  
 *  <p> Polls may have a polls query record indicated by their respective 
 *  record types. The polls query record is accessed via the <code> 
 *  PollsQuery. </code> </p>
 */

public interface PollsSearchSession
    extends org.osid.voting.PollsQuerySession {


    /**
     *  Gets a polls search. 
     *
     *  @return the polls search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.PollsSearch getPollsSearch();


    /**
     *  Gets a polls search order. The <code> PollsSearchOrder </code> is 
     *  supplied to a <code> PollsSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the polls search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.PollsSearchOrder getPollsSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  pollsQuery the polls query 
     *  @param  pollsSearch the polls search 
     *  @return the polls search results 
     *  @throws org.osid.NullArgumentException <code> pollsQuery </code> or 
     *          <code> pollsSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> pollsQuery </code> or 
     *          <code> pollsSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.PollsSearchResults getPollssBySearch(org.osid.voting.PollsQuery pollsQuery, 
                                                                org.osid.voting.PollsSearch pollsSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a polls query from an inspector. The inspector is available from 
     *  a <code> PollsSearchResults. </code> 
     *
     *  @param  pollsQueryInspector a polls query inspector 
     *  @return the polls query 
     *  @throws org.osid.NullArgumentException <code> pollsQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> pollsQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.PollsQuery getPollsQueryFromInspector(org.osid.voting.PollsQueryInspector pollsQueryInspector);
}
