//
// org.osid.voting.RaceResult
//
//     The OSID Java specification for org.osid.voting.RaceResult.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>The results for a candidate in a race. </p>
 */

public interface RaceResult
    extends org.osid.OsidCompendium {


    /**
     *  Geta the race <code> Id </code> of the vote. 
     *
     *  @return the ballot <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRaceId();


    /**
     *  Gets the race of the vote. 
     *
     *  @return the race 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Race getRace()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the candidate <code> Id. </code> 
     *
     *  @return a candidate <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCandidateId();


    /**
     *  Gets the <code> Candidate. </code> 
     *
     *  @return the candidate 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Candidate getCandidate()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the resource <code> Id </code> . A resource represents a voter or 
     *  group of voters across a demographic. 
     *
     *  @return a resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getResourceId();


    /**
     *  Gets the <code> Resource. </code> A resource represents a voter or 
     *  group of voters across a demographic. 
     *
     *  @return the resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getResource()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if these results are final. 
     *
     *  @return <code> true </code> if these results are final, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isFinal();


    /**
     *  Gets the total number of votes cast for this candidate. 
     *
     *  @return the total number of votes cast 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getTotalVotes();


    /**
     *  Gets the mean number of votes cast for this candidate. 
     *
     *  @return the mean number of votes cast 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMeanVotes();


    /**
     *  Gets the median number of votes cast for this candidate. 
     *
     *  @return the median number of votes cast 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMedianVotes();


    /**
     *  Gets the standard deviation of the votes. 
     *
     *  @return the standard deviation 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getVoteStandardDeviation();


    /**
     *  Gets the race result record corresponding to the given <code> 
     *  RaceResults </code> record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  raceResultsRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(raceResultsRecordType) </code> is <code> true </code> . 
     *
     *  @param  raceResultsRecordType the type of the record to retrieve 
     *  @return the race results record 
     *  @throws org.osid.NullArgumentException <code> raceResultsRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(raceResultsRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.records.RaceResultRecord getRaceResultRecord(org.osid.type.Type raceResultsRecordType)
        throws org.osid.OperationFailedException;
}
