//
// org.osid.voting.RaceResultsSession
//
//     The OSID Java specification for org.osid.voting.RaceResultsSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This session provides methods for examining voting results. </p>
 */

public interface RaceResultsSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the polls 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this ballot is still open. 
     *
     *  @return <code> true </code> if the ballot is open, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isOpen();


    /**
     *  Tests if this user can examine race results. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer relationship operations. 
     *
     *  @return <code> false </code> if race results methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canExamineRaceResults();


    /**
     *  Gets all race results on a ballot. 
     *
     *  @param  ballotId <code> Id </code> of the <code> Ballot </code> 
     *  @return the race results 
     *  @throws org.osid.NotFoundException <code> ballotId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ballotId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.voting.RaceResultList getRaceResultsForBalot(org.osid.id.Id ballotId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the winning race results for each race on a ballot. 
     *
     *  @param  ballotId <code> Id </code> of the <code> Ballot </code> 
     *  @return the race results 
     *  @throws org.osid.NotFoundException <code> ballotId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ballotId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.voting.RaceResultList getWinningRaceResultsForBallot(org.osid.id.Id ballotId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all race results in a race ordered from the most votes to the 
     *  fewest votes. 
     *
     *  @param  raceId <code> Id </code> of the <code> Race </code> 
     *  @return the race results 
     *  @throws org.osid.NotFoundException <code> raceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> raceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.voting.RaceResultList getRaceResultsForRace(org.osid.id.Id raceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the winning race results in a race. 
     *
     *  @param  raceId <code> Id </code> of the <code> Race </code> 
     *  @return the race results 
     *  @throws org.osid.NotFoundException <code> raceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> raceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.voting.RaceResultList getWinningRaceResultsForRace(org.osid.id.Id raceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the race results for a candidate in a race. 
     *
     *  @param  raceId <code> Id </code> of the <code> Race </code> 
     *  @param  candidateId <code> Id </code> of the <code> Candidate </code> 
     *  @return the race results 
     *  @throws org.osid.NotFoundException <code> candidateId </code> not in 
     *          <code> raceId </code> 
     *  @throws org.osid.NullArgumentException <code> raceId or </code> 
     *          candidateId <code> </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.voting.RaceResultList getRaceResultsForCandidate(org.osid.id.Id raceId, 
                                                                     org.osid.id.Id candidateId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all race results on this ballot by voter. 
     *
     *  @param  resourceId <code> Id </code> of a <code> Resource </code> 
     *  @return the race results 
     *  @throws org.osid.NotFoundException <code> resourceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.voting.RaceResultList getRaceResultsByVoter(org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the top race results for each race by voter, 
     *
     *  @param  resourceId <code> Id </code> of a <code> Resource </code> 
     *  @return the race results 
     *  @throws org.osid.NotFoundException <code> resourceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.voting.RaceResultList getTopRaceResultsByVoter(org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all race results by a resource in a race ordered from the most 
     *  votes to the fewest votes. 
     *
     *  @param  raceId <code> Id </code> of the <code> Race </code> 
     *  @param  resourceId <code> Id </code> of a <code> Resource </code> 
     *  @return the race results 
     *  @throws org.osid.NotFoundException <code> raceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> raceId </code> or <code> 
     *          resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.voting.RaceResultList getRaceResultsByVoterForRace(org.osid.id.Id raceId, 
                                                                       org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the winning race results by a resource in a race ordered from the 
     *  most votes to the fewest votes. 
     *
     *  @param  raceId <code> Id </code> of the <code> Race </code> 
     *  @param  resourceId <code> Id </code> of a <code> Resource </code> 
     *  @return the race results 
     *  @throws org.osid.NotFoundException <code> raceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> raceId </code> or <code> 
     *          resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.voting.RaceResultList getWinningRaceResultsByVoterForRace(org.osid.id.Id raceId, 
                                                                              org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the race results by voter for a candidate in a race. 
     *
     *  @param  raceId <code> Id </code> of the <code> Race </code> 
     *  @param  candidateId <code> Id </code> of the <code> Candidate </code> 
     *  @param  resourceId <code> Id </code> of a <code> Resource </code> 
     *  @return the race results 
     *  @throws org.osid.NotFoundException <code> candidateId </code> not in 
     *          <code> raceId </code> 
     *  @throws org.osid.NullArgumentException <code> raceId, </code> 
     *          candidateId or <code> resourceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.voting.RaceResultList getRaceResultsByVoterForCandidate(org.osid.id.Id raceId, 
                                                                            org.osid.id.Id candidateId, 
                                                                            org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
