//
// org.osid.voting.VoteSearchSession
//
//     The OSID Java specification for org.osid.voting.VoteSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This session provides methods for searching <code> Vote </code> 
 *  objects. The search query is constructed using the <code> VoteQuery. 
 *  </code> The vote record <code> Type </code> also specifies the record for 
 *  the vote query. </p> 
 *  
 *  <p> <code> getVotesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Votes. </code> A more advanced search may be 
 *  performed with <code> getVotesBySearch(). </code> It accepts a <code> 
 *  VoteSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getVotesBySearch() </code> returns an <code> VoteSearchResults </code> 
 *  that can be used to access the resulting <code> VoteList </code> or be 
 *  used to perform a search within the result set through <code> VoteSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated polls view: searches include votes in polls of which 
 *      these polls is a ancestor in the polls hierarchy </li> 
 *      <li> isolated polls view: searches are restricted to votes in these 
 *      polls only </li> 
 *  </ul>
 *  
 *  
 *  <p> Votes may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> VoteQuery. </code> </p>
 */

public interface VoteSearchSession
    extends org.osid.voting.VoteQuerySession {


    /**
     *  Gets a vote search. 
     *
     *  @return the vote search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteSearch getVoteSearch();


    /**
     *  Gets a vote search order. The <code> VoteSearchOrder </code> is 
     *  supplied to a <code> VoteSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the vote search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteSearchOrder getVoteSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  voteQuery the vote search query 
     *  @param  voteSearch the vote search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> voteQuery </code> or 
     *          voteSearch is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> voteSearch </code> or 
     *          voteQuery is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteSearchResults getVotesBySearch(org.osid.voting.VoteQuery voteQuery, 
                                                              org.osid.voting.VoteSearch voteSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a vote query from an inspector. The inspector is available from a 
     *  <code> VoteSearchResults. </code> 
     *
     *  @param  voteQueryInspector a vote query inspector 
     *  @return the vote query 
     *  @throws org.osid.NullArgumentException <code> voteQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> voteQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteQuery getVoteQueryFromInspector(org.osid.voting.VoteQueryInspector voteQueryInspector);
}
