//
// org.osid.voting.VoterAllocation
//
//     The OSID Java specification for org.osid.voting.VoterAllocation.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>An allocation of votes for an individual resource or a resource group. 
 *  </p>
 */

public interface VoterAllocation
    extends org.osid.OsidObject {


    /**
     *  Gets the race <code> Id </code> of the vote. 
     *
     *  @return the ballot <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRaceId();


    /**
     *  Gets the race of the vote. 
     *
     *  @return the race 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Race getRace()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the resource <code> Id. </code> 
     *
     *  @return a resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getVoterId();


    /**
     *  Gets the <code> Resource. </code> 
     *
     *  @return the resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getVoter()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the total number of votes the resource can cast in this race. 
     *
     *  @return the number of votes 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getTotalVotes();


    /**
     *  Gets the maximum votes per candidate the resource can cast in this 
     *  race. 
     *
     *  @return the max votes per candidate 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMaxVotesPerCandidate();


    /**
     *  Tests if this resource can vote for a limited number of candidates. 
     *
     *  @return <code> true </code> if a limit on the number of candidates 
     *          exists, <code> false </code> if no limit exists 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasMaxCandidates();


    /**
     *  Gets the maximum number of candidates for which this resource can 
     *  vote. 
     *
     *  @return the maximum candidates 
     *  @throws org.osid.IllegalStateException <code> hasMaxCandidates() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMaxCandidates();


    /**
     *  Tests if this resource gets the number of votes cast for a candidate 
     *  when the candidate is no longer running in a race. 
     *
     *  @return <code> true </code> if votes are returned to the resource when 
     *          the candidate drops from the race, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean reallocatesVotesWhenCandidateDrops();


    /**
     *  Gets the voter allocation record corresponding to the given <code> 
     *  VoterAllocation </code> record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. The 
     *  <code> voterAllocationRecordType </code> may be the <code> Type 
     *  </code> returned in <code> getRecordTypes() </code> or any of its 
     *  parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(voterAllocationRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  voterAllocationRecordType the type of the record to retrieve 
     *  @return the voter allocation record 
     *  @throws org.osid.NullArgumentException <code> 
     *          voterAllocationRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(voterAllocationRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.records.VoterAllocationRecord getVoterAllocationRecord(org.osid.type.Type voterAllocationRecordType)
        throws org.osid.OperationFailedException;
}
