//
// org.osid.voting.VoterAllocationAdminSession
//
//     The OSID Java specification for org.osid.voting.VoterAllocationAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This session manages voter allocations. All voters are assumed to have 
 *  a default allocation form such that this session only provides an update 
 *  mechanism. The data for update is provided via the <code> 
 *  VoterAllocationForm. </code> </p>
 */

public interface VoterAllocationAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the polls 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage voter allocation. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known allocation methods will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer allocation operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if voter allocation is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageVoterAllocations();


    /**
     *  Gets the voter allocation form. A new form should be requested for 
     *  each update transaction. 
     *
     *  @param  raceId the <code> Id </code> of the <code> Race </code> 
     *  @param  resourceId the <code> Id </code> of the <code> Voter </code> 
     *  @return the voter allocation form 
     *  @throws org.osid.NotFoundException <code> raceId </code> or <code> 
     *          resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> raceId </code> or <code> 
     *          resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoterAllocationForm getVoterAllocationFormForUpdate(org.osid.id.Id raceId, 
                                                                               org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Updates an allocation for a voter. 
     *
     *  @param  voterAllocationForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> voterAllocationForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> voterAllocationForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> voterAllocationForm 
     *          </code> did not originate from <code> 
     *          getVoterAllocationFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateVoterAllocation(org.osid.voting.VoterAllocationForm voterAllocationForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
