//
// org.osid.voting.VoterAllocationForm
//
//     The OSID Java specification for org.osid.voting.VoterAllocationForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This is the form for creating and updating <code> VoterAllocations. 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  VoterAllocationAdminSession. </code> For each data element that may be 
 *  set, metadata may be examined to provide display hints or data 
 *  constraints. </p>
 */

public interface VoterAllocationForm
    extends org.osid.OsidObjectForm {


    /**
     *  Gets the metadata for the total votes. 
     *
     *  @return metadata for the total votes 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTotalVotesMetadata();


    /**
     *  Sets the total votes. 
     *
     *  @param  votes the total votes 
     *  @throws org.osid.InvalidArgumentException <code> votes </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTotalVotes(long votes);


    /**
     *  Clears the total votes. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTotalVotes();


    /**
     *  Gets the metadata for the max votes per candidate. 
     *
     *  @return metadata for the max votes per candidate 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMaxVotesPerCandidateMetadata();


    /**
     *  Sets the max votes per candidate. 
     *
     *  @param  votes the max votes 
     *  @throws org.osid.InvalidArgumentException <code> votes </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMaxVotesPerCandidate(long votes);


    /**
     *  Clears the max votes per candidate. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMaxVotesPerCandidate();


    /**
     *  Gets the metadata for the max candidates. 
     *
     *  @return metadata for the max candidates 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMaxCandidatesMetadata();


    /**
     *  Sets the max candidates. 
     *
     *  @param  candidates the max candidates 
     *  @throws org.osid.InvalidArgumentException <code> candidates </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMaxCandidates(long candidates);


    /**
     *  Clears the max candidates. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMaxCandidates();


    /**
     *  Gets the <code> CandidateFormRecord </code> corresponding to the given 
     *  <code> Candidate </code> record <code> Type. </code> 
     *
     *  @param  candidateRecordType the candidate record type 
     *  @return the candidate form record 
     *  @throws org.osid.NullArgumentException <code> candidateRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(candidateRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.records.CandidateFormRecord getCandidateFormRecord(org.osid.type.Type candidateRecordType)
        throws org.osid.OperationFailedException;
}
