//
// org.osid.voting.VotingProfile
//
//     The OSID Java specification for org.osid.voting.VotingProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>The voting profile describes interoperability among voting services. 
 *  </p>
 */

public interface VotingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if voting is supported. 
     *
     *  @return <code> true </code> if voting is supported <code> , </code> 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVoting();


    /**
     *  Tests if race results is supported. 
     *
     *  @return <code> true </code> if race results is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceResults();


    /**
     *  Tests if voting allocation lookup is supported. 
     *
     *  @return <code> true </code> if voting allocation lookup is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVotingAllocationLookup();


    /**
     *  Tests if voting allocation administration is supported. 
     *
     *  @return <code> true </code> if voting allocation administration is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVotingAllocationAdmin();


    /**
     *  Tests if looking up votes is supported. 
     *
     *  @return <code> true </code> if votes lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVoteLookup();


    /**
     *  Tests if querying votes is supported. 
     *
     *  @return <code> true </code> if votes query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVoteQuery();


    /**
     *  Tests if searching votes is supported. 
     *
     *  @return <code> true </code> if votes search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVoteSearch();


    /**
     *  Tests if a votes <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if votes notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVoteNotification();


    /**
     *  Tests if retrieving mappings of votes and polls is supported. 
     *
     *  @return <code> true </code> if vote polls mapping retrieval is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVotePolls();


    /**
     *  Tests if managing mappings of votes and polls is supported. 
     *
     *  @return <code> true </code> if vote polls assignment is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVotePollsAssignment();


    /**
     *  Tests if vote smart polls are available. 
     *
     *  @return <code> true </code> if vote smart polls are supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVoteSmartPolls();


    /**
     *  Tests if candidate lookup is supported. 
     *
     *  @return <code> true </code> if candidate lookup is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCandidateLookup();


    /**
     *  Tests if candidate query is supported. 
     *
     *  @return <code> true </code> if candidate query is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCandidateQuery();


    /**
     *  Tests if candidate search is supported. 
     *
     *  @return <code> true </code> if candidate search is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCandidateSearch();


    /**
     *  Tests if candidate administration is supported. 
     *
     *  @return <code> true </code> if candidate administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCandidateAdmin();


    /**
     *  Tests if candidate notification is supported. Messages may be sent 
     *  when candidates are created, modified, or deleted. 
     *
     *  @return <code> true </code> if candidate notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCandidateNotification();


    /**
     *  Tests if retrieving mappings of candidate and polls is supported. 
     *
     *  @return <code> true </code> if candidate polls mapping retrieval is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCandidatePolls();


    /**
     *  Tests if managing mappings of candidate and polls is supported. 
     *
     *  @return <code> true </code> if candidate polls assignment is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCandidatePollsAssignment();


    /**
     *  Tests if candidate smart polls are available. 
     *
     *  @return <code> true </code> if candidate smart polls are supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCandidateSmartPolls();


    /**
     *  Tests if looking up races is supported. 
     *
     *  @return <code> true </code> if race lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceLookup();


    /**
     *  Tests if querying races is supported. 
     *
     *  @return <code> true </code> if race query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceQuery();


    /**
     *  Tests if searching races is supported. 
     *
     *  @return <code> true </code> if races search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceSearch();


    /**
     *  Tests if a race <code> a </code> dministrative service is supported. 
     *
     *  @return <code> true </code> if race administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceAdmin();


    /**
     *  Tests if a race <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if race notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceNotification();


    /**
     *  Tests if retrieving mappings of races and polls is supported. 
     *
     *  @return <code> true </code> if race polls mapping retrieval is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRacePolls();


    /**
     *  Tests if managing mappings of races and polls is supported. 
     *
     *  @return <code> true </code> if race polls assignment is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRacePollsAssignment();


    /**
     *  Tests if race smart polls are available. 
     *
     *  @return <code> true </code> if race smart polls are supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceSmartPolls();


    /**
     *  Tests if looking up ballots is supported. 
     *
     *  @return <code> true </code> if ballot lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotLookup();


    /**
     *  Tests if querying ballots is supported. 
     *
     *  @return <code> true </code> if ballot query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotQuery();


    /**
     *  Tests if searching ballots is supported. 
     *
     *  @return <code> true </code> if ballot search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotSearch();


    /**
     *  Tests if a ballot <code> a </code> dministrative service is supported. 
     *
     *  @return <code> true </code> if ballot administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotAdmin();


    /**
     *  Tests if a ballot notification service is supported. 
     *
     *  @return <code> true </code> if ballot notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotNotification();


    /**
     *  Tests if retrieving mappings of ballots and polls is supported. 
     *
     *  @return <code> true </code> if ballot polls mapping retrieval is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotPolls();


    /**
     *  Tests if managing mappings of ballots and polls is supported. 
     *
     *  @return <code> true </code> if ballot polls assignment is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotPollsAssignment();


    /**
     *  Tests if ballot smart polls are available. 
     *
     *  @return <code> true </code> if ballot smart polls are supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotSmartPolls();


    /**
     *  Tests if polls lookup is supported. 
     *
     *  @return <code> true </code> if polls lookup is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPollsLookup();


    /**
     *  Tests if polls query is supported. 
     *
     *  @return <code> true </code> if polls query is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPollsQuery();


    /**
     *  Tests if polls search is supported. 
     *
     *  @return <code> true </code> if polls search is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPollsSearch();


    /**
     *  Tests if polls administration is supported. 
     *
     *  @return <code> true </code> if polls administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPollsAdmin();


    /**
     *  Tests if polls notification is supported. Messages may be sent when 
     *  <code> Polls </code> objects are created, deleted or updated. 
     *  Notifications for candidates within polls are sent via the candidate 
     *  notification session. 
     *
     *  @return <code> true </code> if polls notification is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPollsNotification();


    /**
     *  Tests if a polls hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if a polls hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPollsHierarchy();


    /**
     *  Tests if a polls hierarchy design is supported. 
     *
     *  @return <code> true </code> if a polls hierarchy design is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPollsHierarchyDesign();


    /**
     *  Tests if a voting batch service is supported. 
     *
     *  @return <code> true </code> if a voting batch service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVotingBatch();


    /**
     *  Tests if a voting rules service is supported. 
     *
     *  @return <code> true </code> if a voting rules service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVotingRules();


    /**
     *  Gets the supported <code> Vote </code> record types. 
     *
     *  @return a list containing the supported <code> Vote </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getVoteRecordTypes();


    /**
     *  Tests if the given <code> Vote </code> record type is supported. 
     *
     *  @param  voteRecordType a <code> Type </code> indicating a <code> Vote 
     *          </code> record type 
     *  @return <code> true </code> if the given type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> voteRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVoteRecordType(org.osid.type.Type voteRecordType);


    /**
     *  Gets the supported <code> Vote </code> search record types. 
     *
     *  @return a list containing the supported <code> Vote </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getVoteSearchRecordTypes();


    /**
     *  Tests if the given <code> Vote </code> search record type is 
     *  supported. 
     *
     *  @param  voteSearchRecordType a <code> Type </code> indicating a <code> 
     *          Vote </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> voteSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVoteSearchRecordType(org.osid.type.Type voteSearchRecordType);


    /**
     *  Gets the supported <code> VoterAllocation </code> record types. 
     *
     *  @return a list containing the supported <code> VoterAllocation </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getVoterAllocationRecordTypes();


    /**
     *  Tests if the given <code> VoterAllocation </code> record type is 
     *  supported. 
     *
     *  @param  voterAllocationRecordType a <code> Type </code> indicating a 
     *          <code> VoterAllocation </code> record type 
     *  @return <code> true </code> if the given type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          voterAllocationRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVoterAllocationRecordType(org.osid.type.Type voterAllocationRecordType);


    /**
     *  Gets all the candidate record types supported. 
     *
     *  @return the list of supported candidate record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCandidateRecordTypes();


    /**
     *  Tests if a given candidate record type is supported. 
     *
     *  @param  candidateRecordType the candidate type 
     *  @return <code> true </code> if the candidate record type is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> candidateRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCandidateRecordType(org.osid.type.Type candidateRecordType);


    /**
     *  Gets all the candidate search record types supported. 
     *
     *  @return the list of supported candidate search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCandidateSearchRecordTypes();


    /**
     *  Tests if a given candidate search type is supported. 
     *
     *  @param  candidateSearchRecordType the candidate search type 
     *  @return <code> true </code> if the candidate search record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          candidateSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCandidateSearchRecordType(org.osid.type.Type candidateSearchRecordType);


    /**
     *  Gets the supported <code> Race </code> record types. 
     *
     *  @return a list containing the supported <code> Race </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRaceRecordTypes();


    /**
     *  Tests if the given <code> Race </code> record type is supported. 
     *
     *  @param  raceRecordType a <code> Type </code> indicating a <code> Race 
     *          </code> record type 
     *  @return <code> true </code> if the given type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> raceRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceRecordType(org.osid.type.Type raceRecordType);


    /**
     *  Gets the supported <code> Race </code> search record types. 
     *
     *  @return a list containing the supported <code> Race </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRaceSearchRecordTypes();


    /**
     *  Tests if the given <code> Race </code> search record type is 
     *  supported. 
     *
     *  @param  raceSearchRecordType a <code> Type </code> indicating a <code> 
     *          Race </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> raceSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceSearchRecordType(org.osid.type.Type raceSearchRecordType);


    /**
     *  Gets the supported <code> Ballot </code> record types. 
     *
     *  @return a list containing the supported <code> Ballot </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBallotRecordTypes();


    /**
     *  Tests if the given <code> Ballot </code> record type is supported. 
     *
     *  @param  ballotRecordType a <code> Type </code> indicating a <code> 
     *          Ballot </code> record type 
     *  @return <code> true </code> if the given type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> ballotRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotRecordType(org.osid.type.Type ballotRecordType);


    /**
     *  Gets the supported <code> Ballot </code> search record types. 
     *
     *  @return a list containing the supported <code> Ballot </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBallotSearchRecordTypes();


    /**
     *  Tests if the given <code> Ballot </code> search record type is 
     *  supported. 
     *
     *  @param  ballotSearchRecordType a <code> Type </code> indicating a 
     *          <code> Ballot </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> ballotSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotSearchRecordType(org.osid.type.Type ballotSearchRecordType);


    /**
     *  Gets the supported <code> VotingResults </code> record types. 
     *
     *  @return a list containing the supported <code> VotingResults </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getVotingResultsRecordTypes();


    /**
     *  Tests if the given <code> VotingResults </code> record type is 
     *  supported. 
     *
     *  @param  votingResultsRecordType a <code> Type </code> indicating a 
     *          <code> VotingResults </code> record type 
     *  @return <code> true </code> if the given type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> votingResultsRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVotingResultsRecordType(org.osid.type.Type votingResultsRecordType);


    /**
     *  Gets all the polls record types supported. 
     *
     *  @return the list of supported polls record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPollsRecordTypes();


    /**
     *  Tests if a given polls record type is supported. 
     *
     *  @param  pollsRecordType the polls record type 
     *  @return <code> true </code> if the polls record type is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> pollsRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPollsRecordType(org.osid.type.Type pollsRecordType);


    /**
     *  Gets all the polls search record types supported. 
     *
     *  @return the list of supported polls search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPollsSearchRecordTypes();


    /**
     *  Tests if a given polls search record type is supported. 
     *
     *  @param  pollsSearchRecordType the polls search record type 
     *  @return <code> true </code> if the polls search record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> pollsSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPollsSearchRecordType(org.osid.type.Type pollsSearchRecordType);
}
