//
// org.osid.voting.batch.VotingBatchSession
//
//     The OSID Java specification for org.osid.voting.batch.VotingBatchSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.batch;


/**
 *  <p>This session votes in bulk. The data for create and update is provided 
 *  by the consumer via the form object. <code> OsidForms </code> are 
 *  requested for eachupdate and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Vote, </code> a <code> VoteForm </code> is requested using <code> 
 *  getVoteForms() </code> specifying the desired race, candidate, and record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  Each of the returned <code> VoteForms </code> will indicate that it is to 
 *  be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once a <code> VoteForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  VoteForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> VoteForms </code> returned from <code> getVoteForms() 
 *  </code> may be linked to the originating request through the peer <code> 
 *  Ids </code> of the <code> VoteForm. </code> In the case where there may be 
 *  duplicates, any <code> VoteForm </code> of the same peer <code> Ids 
 *  </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> VoteForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> VoteForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> castVotes() </code> 
 *  errors specific to an individual <code> VoteForm </code> are indicated in 
 *  the corresponding <code> CreateResponse. </code> <code> CreateResponses 
 *  </code> may be linked to the originating <code> VoteForm </code> through 
 *  the <code> VoteForm </code> <code> Id </code> . </p> 
 *  
 *  <p> The delete operations delete <code> Votes </code> in bulk. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface VotingBatchSession
    extends org.osid.voting.VotingSession {


    /**
     *  Gets the vote forms for casting a bunch of new votes. A vote form is 
     *  returned for each supplied race and candidate pair. 
     *
     *  @param  peers the vote peers 
     *  @param  voteRecordTypes array of vote record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the vote forms 
     *  @throws org.osid.NotFoundException a <code> raceId </code> or <code> 
     *          candidateId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          voteRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.batch.VoteBatchFormList getVoteForms(org.osid.voting.batch.VotePeerList peers, 
                                                                org.osid.type.Type[] voteRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Votes. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  voteForms the vote forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> voteForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList castVotes(org.osid.voting.batch.VoteBatchFormList voteForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Votes </code> in this <code> Polls </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllVotes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes votes for the given <code> Ids. </code> 
     *
     *  @param  voteIds the <code> Ids </code> of the votes to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> voteIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteVotes(org.osid.id.IdList voteIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes votes for the given race. 
     *
     *  @param  raceId the <code> Ids </code> of a race 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> raceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteVotesForRace(org.osid.id.Id raceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes votes cast by a voter. 
     *
     *  @param  resourceId the <code> Ids </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteVotesForVoter(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all votes for all races on a ballot. 
     *
     *  @param  ballotId the <code> Ids </code> of a ballot 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> ballotId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteVotesForBallot(org.osid.id.Id ballotId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes votes ineffective before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveVotesByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Vote </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Vote </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another vote, it is reassigned to the given vote <code> Id. 
     *  </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasVotes(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
