//
// org.osid.voting.rules.RaceConstrainerRuleApplicationSession
//
//     The OSID Java specification for org.osid.voting.rules.RaceConstrainerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session provides methods to apply <code> RaceConstrainers </code> 
 *  to <code> Races. </code> A <code> Race </code> with multiple <code> 
 *  RaceConstrainers </code> means any positive rule evaluation across the 
 *  constrainers result in an accessible <code> Race. </code> </p>
 */

public interface RaceConstrainerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the polls 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter race constrainer/race mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRaceConstrainers();


    /**
     *  Adds an existing <code> RaceConstrainer </code> to a <code> Race. 
     *  </code> 
     *
     *  @param  raceConstrainerId the <code> Id </code> of the <code> 
     *          RaceConstrainer </code> 
     *  @param  raceId the <code> Id </code> of the <code> Race </code> 
     *  @throws org.osid.AlreadyExistsException <code> raceConstrainerId 
     *          </code> is already applied to <code> raceId </code> 
     *  @throws org.osid.NotFoundException <code> raceConstrainerId </code> or 
     *          <code> raceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> raceConstrainerId 
     *          </code> or <code> raceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignRaceConstrainerToRace(org.osid.id.Id raceConstrainerId, 
                                            org.osid.id.Id raceId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> RaceConstrainer </code> from a <code> Race. </code> 
     *
     *  @param  raceConstrainerId the <code> Id </code> of the <code> 
     *          RaceConstrainer </code> 
     *  @param  raceId the <code> Id </code> of the <code> Race </code> 
     *  @throws org.osid.NotFoundException <code> raceConstrainerId </code> or 
     *          <code> raceId </code> not found or <code> raceConstrainerId 
     *          </code> not applied to <code> raceId </code> 
     *  @throws org.osid.NullArgumentException <code> raceConstrainerId 
     *          </code> or <code> raceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignRaceConstrainerFromRace(org.osid.id.Id raceConstrainerId, 
                                                org.osid.id.Id raceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> RaceConstrainers. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> RaceConstrainer </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceRaceConstrainers();


    /**
     *  Reorders race constrainers for a race by moving the specified race 
     *  constrainer in front of a reference race constrainer. 
     *
     *  @param  raceConstrainerId the <code> Id </code> of a <code> 
     *          RaceConstrainer </code> 
     *  @param  raceId the <code> Id </code> of a <code> Race </code> 
     *  @param  referenceId the reference race constrainer <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> raceConstrainerId, raceId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          raceConstrainerId </code> or <code> referenceId </code> not 
     *          related to <code> raceId </code> 
     *  @throws org.osid.NullArgumentException <code> raceConstrainerId, 
     *          raceId, </code> or <code> referenceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveRaceConstrainerAhead(org.osid.id.Id raceConstrainerId, 
                                         org.osid.id.Id raceId, 
                                         org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders race constrainers for a race by moving the specified race 
     *  constrainer behind a reference race constrainer. 
     *
     *  @param  raceConstrainerId the <code> Id </code> of a <code> 
     *          RaceConstrainer </code> 
     *  @param  raceId the <code> Id </code> of a <code> Race </code> 
     *  @param  referenceId the reference race constrainer <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> raceConstrainerId, raceId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          raceConstrainerId </code> or <code> referenceId </code> not 
     *          related to <code> raceId </code> 
     *  @throws org.osid.NullArgumentException <code> raceConstrainerId, 
     *          raceId, </code> or <code> referenceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveRaceConstrainerBehind(org.osid.id.Id raceConstrainerId, 
                                          org.osid.id.Id raceId, 
                                          org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of race constrainers for a race. 
     *
     *  @param  raceConstrainerIds the <code> Ids </code> for a set of <code> 
     *          RaceConstrainers </code> 
     *  @param  raceId the <code> Id </code> of a <code> Race </code> 
     *  @throws org.osid.NotFoundException <code> raceId </code> not found or, 
     *          a <code> raceConstrainerId </code> not related to <code> 
     *          raceId </code> 
     *  @throws org.osid.NullArgumentException <code> raceConstrainerIds 
     *          </code> or <code> raceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderRaceConstrainers(org.osid.id.Id[] raceConstrainerIds, 
                                      org.osid.id.Id raceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
