//
// org.osid.voting.rules.RaceProcessor
//
//     The OSID Java specification for org.osid.voting.rules.RaceProcessor.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>A <code> RaceProcessor </code> describes the rules for managing the 
 *  behavior of a race. </p>
 */

public interface RaceProcessor
    extends org.osid.OsidProcessor {


    /**
     *  Tests if there is a limit on the number of winners in a race. 
     *
     *  @return <code> true </code> if a limit on the number of winners, 
     *          <code> false </code> if no limit exists 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasMaximumWinners();


    /**
     *  Gets the number of maximum winners in a race. 
     *
     *  @return the maximum number of winners permitted 
     *  @throws org.osid.IllegalStateException <code> hasMaximumWinners() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMaximumWinners();


    /**
     *  Gets the minimum percentage (0-100) of total votes to be declared a 
     *  winner in a race. 
     *
     *  @return the minimum percentage 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMinimumPercentageToWin();


    /**
     *  Gets the minimum votesl votes to be declared a winner in a race. 
     *
     *  @return the minimum votes 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMinimumVotesToWin();


    /**
     *  Gets the race processor record corresponding to the given <code> 
     *  RaceProcessor </code> record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  raceProcessorRecordType </code> may be the <code> Type </code> 
     *  returned in <code> getRecordTypes() </code> or any of its parents in a 
     *  <code> Type </code> hierarchy where <code> 
     *  hasRecordType(raceProcessorRecordType) </code> is <code> true </code> 
     *  . 
     *
     *  @param  raceProcessorRecordType the type of race processor record to 
     *          retrieve 
     *  @return the race processor record 
     *  @throws org.osid.NullArgumentException <code> raceProcessorRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(raceProcessorRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.records.RaceProcessorRecord getRaceProcessorRecord(org.osid.type.Type raceProcessorRecordType)
        throws org.osid.OperationFailedException;
}
