//
// org.osid.voting.rules.RaceProcessorAdminSession
//
//     The OSID Java specification for org.osid.voting.rules.RaceProcessorAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session creates and removes race processors. The data for create 
 *  and update is provided via the <code> RaceProcessorForm. </code> </p>
 */

public interface RaceProcessorAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the polls 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create race processors. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> RaceProcessor </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> RaceProcessor </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRaceProcessor();


    /**
     *  Tests if this user can create a single <code> RaceProcessor </code> 
     *  using the desired record types. While <code> 
     *  VotingRulesManager.getRaceProcessorRecordTypes() </code> can be used 
     *  to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> RaceProcessor. 
     *  </code> Providing an empty array tests if a <code> RaceProcessor 
     *  </code> can be created with no records. 
     *
     *  @param  raceProcessorRecordTypes array of race processor types 
     *  @return <code> true </code> if <code> RaceProcessor </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> raceProcessorRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRaceProcessorWithRecordTypes(org.osid.type.Type[] raceProcessorRecordTypes);


    /**
     *  Gets the race processor form for creating new race processors. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  raceProcessorRecordTypes array of race processor types 
     *  @return the race processor form 
     *  @throws org.osid.NullArgumentException <code> raceProcessorRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorForm getRaceProcessorFormForCreate(org.osid.type.Type[] raceProcessorRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> RaceProcessor. </code> 
     *
     *  @param  raceProcessorForm the form for this <code> RaceProcessor 
     *          </code> 
     *  @return the new <code> RaceProcessor </code> 
     *  @throws org.osid.IllegalStateException <code> raceProcessorForm 
     *          </code> already used for a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> raceProcessorForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> raceProcessorForm did not 
     *          originate from getRaceProcessorFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessor createRaceProcessor(org.osid.voting.rules.RaceProcessorForm raceProcessorForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update race processors. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known updating a <code> RaceProcessor </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> RaceProcessor </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateRaceProcessors();


    /**
     *  Gets the race processor form for updating an existing race processor. 
     *  A new race processor form should be requested for each update 
     *  transaction. 
     *
     *  @param  raceProcessorId the <code> Id </code> of the <code> 
     *          RaceProcessor </code> 
     *  @return the race processor form 
     *  @throws org.osid.NotFoundException <code> raceProcessorId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> raceProcessorId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorForm getRaceProcessorFormForUpdate(org.osid.id.Id raceProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing race processor. 
     *
     *  @param  raceProcessorForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> raceProcessorForm 
     *          </code> already used for an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> raceProcessorForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> raceProcessorForm did not 
     *          originate from getRaceProcessorFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateRaceProcessor(org.osid.voting.rules.RaceProcessorForm raceProcessorForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete race processors. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known deleting a <code> RaceProcessor </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> RaceProcessor </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteRaceProcessors();


    /**
     *  Deletes a <code> RaceProcessor. </code> 
     *
     *  @param  raceProcessorId the <code> Id </code> of the <code> 
     *          RaceProcessor </code> to remove 
     *  @throws org.osid.NotFoundException <code> raceProcessorId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> raceProcessorId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteRaceProcessor(org.osid.id.Id raceProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for race 
     *  processors. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> RaceProcessor </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageRaceProcessorAliases();


    /**
     *  Adds a <code> Id </code> to a <code> RaceProcessor </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> RaceProcessor </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another race processor. it is 
     *  reassigned to the given race processor <code> Id. </code> 
     *
     *  @param  raceProcessorId the <code> Id </code> of a <code> 
     *          RaceProcessor </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> raceProcessorId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> raceProcessorId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasRaceProcessor(org.osid.id.Id raceProcessorId, 
                                   org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
