//
// org.osid.voting.rules.RaceProcessorEnablerPollsAssignmentSession
//
//     The OSID Java specification for org.osid.voting.rules.RaceProcessorEnablerPollsAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session provides methods to re-assign <code> RaceProcessorEnabler 
 *  </code> to <code> Polls </code> mappings. a <code> RaceProcessorEnabler 
 *  </code> may appear in multiple <code> Polls </code> objects and removing 
 *  the last reference to a <code> RaceProcessorEnabler </code> is the 
 *  equivalent of deleting it. Each <code> Polls </code> may have its own 
 *  authorizations governing who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> RaceProcessorEnabler </code> to another 
 *  <code> Polls </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface RaceProcessorEnablerPollsAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter race processor enabler/polls mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRaceProcessorEnablers();


    /**
     *  Tests if this user can alter race processor enabler/polls mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRaceProcessorEnablersToPolls(org.osid.id.Id pollsId);


    /**
     *  Gets a list of polls including and under the given polls node in which 
     *  any race processor enabler can be assigned. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return list of assignable polls <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignablePollsIds(org.osid.id.Id pollsId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of polls including and under the given polls node in which 
     *  a specific race processor enabler can be assigned. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  raceProcessorEnablerId the <code> Id </code> of the <code> 
     *          RaceProcessorEnabler </code> 
     *  @return list of assignable polls <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> raceProcessorEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignablePollsIdsForRaceProcessorEnabler(org.osid.id.Id pollsId, 
                                                                           org.osid.id.Id raceProcessorEnablerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> RaceProcessorEnabler </code> to a <code> 
     *  Polls. </code> 
     *
     *  @param  raceProcessorEnablerId the <code> Id </code> of the <code> 
     *          RaceProcessorEnabler </code> 
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @throws org.osid.AlreadyExistsException <code> raceProcessorEnablerId 
     *          </code> is already assigned to <code> pollsId </code> 
     *  @throws org.osid.NotFoundException <code> raceProcessorEnablerId 
     *          </code> or <code> pollsId </code> not found 
     *  @throws org.osid.NullArgumentException <code> raceProcessorEnablerId 
     *          </code> or <code> pollsId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignRaceProcessorEnablerToPolls(org.osid.id.Id raceProcessorEnablerId, 
                                                  org.osid.id.Id pollsId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> RaceProcessorEnabler </code> from a <code> Polls. 
     *  </code> 
     *
     *  @param  raceProcessorEnablerId the <code> Id </code> of the <code> 
     *          RaceProcessorEnabler </code> 
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @throws org.osid.NotFoundException <code> raceProcessorEnablerId 
     *          </code> or <code> pollsId </code> not found or <code> 
     *          raceProcessorEnablerId </code> not assigned to <code> pollsId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> raceProcessorEnablerId 
     *          </code> or <code> pollsId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignRaceProcessorEnablerFromPolls(org.osid.id.Id raceProcessorEnablerId, 
                                                      org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> RaceProcessorEnabler </code> from one <code> Polls 
     *  </code> to another. Mappings to other <code> Polls </code> are 
     *  unaffected. 
     *
     *  @param  raceProcessorEnablerId the <code> Id </code> of the <code> 
     *          RaceProcessorEnabler </code> 
     *  @param  fromPollsId the <code> Id </code> of the current <code> Polls 
     *          </code> 
     *  @param  toPollsId the <code> Id </code> of the destination <code> 
     *          Polls </code> 
     *  @throws org.osid.NotFoundException <code> raceProcessorEnablerId, 
     *          fromPollsId, </code> or <code> toPollsId </code> not found or 
     *          <code> raceProcessorEnablerId </code> not mapped to <code> 
     *          fromPollsId </code> 
     *  @throws org.osid.NullArgumentException <code> raceProcessorEnablerId, 
     *          fromPollsId, </code> or <code> toPollsId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignRaceProcessorEnablerToPolls(org.osid.id.Id raceProcessorEnablerId, 
                                                    org.osid.id.Id fromPollsId, 
                                                    org.osid.id.Id toPollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
