//
// org.osid.voting.rules.RaceProcessorEnablerPollsSession
//
//     The OSID Java specification for org.osid.voting.rules.RaceProcessorEnablerPollsSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session provides methods to retrieve <code> RaceProcessorEnabler 
 *  </code> to <code> Polls </code> mappings. a <code> RaceProcessorEnabler 
 *  </code> may appear in multiple <code> Polls </code> objects. Each polls 
 *  may have its own authorizations governing who is allowed to look at it. 
 *  </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface RaceProcessorEnablerPollsSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform lookups of race processor enabler/polls 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupRaceProcessorEnablerPollsMappings();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeRaceProcessorEnablerPollsView();


    /**
     *  A complete view of the <code> RaceProcessorEnabler </code> and <code> 
     *  Polls </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryRaceProcessorEnablerPollsView();


    /**
     *  Gets the list of <code> RaceProcessorEnablerIds </code> associated 
     *  with a <code> Polls. </code> 
     *
     *  @param  pollsId <code> Id </code> of the <code> Polls </code> 
     *  @return list of related race processor enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> pollsId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRaceProcessorEnablerIdsByPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of race processor enablers associated with a <code> 
     *  Polls. </code> 
     *
     *  @param  pollsId <code> Id </code> of the <code> Polls </code> 
     *  @return list of related race processor enablers 
     *  @throws org.osid.NotFoundException <code> pollsId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorEnablerList getRaceProcessorEnablersByPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> RaceProcessorEnabler Ids </code> corresponding 
     *  to a list of <code> Polls. </code> 
     *
     *  @param  pollsIds list of polls <code> Ids </code> 
     *  @return list of race processor enabler <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> pollsIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRaceProcessorEnablerIdsByPolls(org.osid.id.IdList pollsIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of race processor enablers corresponding to a list of 
     *  <code> Polls. </code> 
     *
     *  @param  pollsIds list of polls <code> Ids </code> 
     *  @return list of race processor enablers 
     *  @throws org.osid.NullArgumentException <code> pollsIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorEnablerList getRaceProcessorEnablersByPolls(org.osid.id.IdList pollsIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Polls </code> <code> Ids </code> mapped to a <code> 
     *  RaceProcessorEnabler. </code> 
     *
     *  @param  raceProcessorEnablerId <code> Id </code> of a <code> 
     *          RaceProcessorEnabler </code> 
     *  @return list of polls 
     *  @throws org.osid.NotFoundException <code> raceProcessorEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> raceProcessorEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getPollsIdsByRaceProcessorEnabler(org.osid.id.Id raceProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Polls </code> mapped to a <code> RaceProcessorEnabler. 
     *  </code> 
     *
     *  @param  raceProcessorEnablerId <code> Id </code> of a <code> 
     *          RaceProcessorEnabler </code> 
     *  @return list of polls 
     *  @throws org.osid.NotFoundException <code> raceProcessorEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> raceProcessorEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.PollsList getPollsByRaceProcessorEnabler(org.osid.id.Id raceProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
