//
// org.osid.voting.rules.RaceProcessorEnablerSearchSession
//
//     The OSID Java specification for org.osid.voting.rules.RaceProcessorEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  RaceProcessorEnabler </code> objects. The search query is constructed 
 *  using the <code> RaceProcessorEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getRaceProcessorEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> RaceProcessorEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getRaceProcessorEnablersBySearch(). </code> It accepts a <code> 
 *  RaceProcessorEnablerSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as voting. <code> getRaceProcessorEnablersBySearch() </code> returns a 
 *  <code> RaceProcessorEnablerSearchResults </code> that can be used to 
 *  access the resulting <code> RaceProcessorEnablerList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  RaceProcessorEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated polls view: searches include race processor enablers in 
 *      polls of which this polls is an ancestor in the polls hierarchy </li> 
 *      <li> isolated polls view: searches are restricted to race processor 
 *      enablers in this polls </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> RaceProcessorEnablers </code> may have a query record indicated 
 *  by their respective query record types. The record is accessed via the 
 *  <code> RaceProcessorEnablerQuery. </code> </p>
 */

public interface RaceProcessorEnablerSearchSession
    extends org.osid.voting.rules.RaceProcessorEnablerQuerySession {


    /**
     *  Gets a race processor enabler search. 
     *
     *  @return the race processor enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorEnablerSearch getRaceProcessorEnablerSearch();


    /**
     *  Gets a race processor enabler search order. The <code> 
     *  RaceProcessorEnablerSearchOrder </code> is supplied to a <code> 
     *  RaceProcessorEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the race processor enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorEnablerSearchOrder getRaceProcessorEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  raceProcessorEnablerQuery the race processor enabler query 
     *  @param  raceProcessorEnablerSearch the race processor enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceProcessorEnablerQuery </code> or <code> 
     *          raceProcessorEnablerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> raceProcessorEnablerQuery 
     *          </code> or <code> raceProcessorEnablerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorEnablerSearchResults getRaceProcessorEnablersBySearch(org.osid.voting.rules.RaceProcessorEnablerQuery raceProcessorEnablerQuery, 
                                                                                                    org.osid.voting.rules.RaceProcessorEnablerSearch raceProcessorEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a race processor enabler query from an inspector. The inspector 
     *  is available from a <code> RaceProcessorEnablerSearchResults. </code> 
     *
     *  @param  raceProcessorEnablerQueryInspector a race processor enabler 
     *          query inspector 
     *  @return the race processor enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceProcessorEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          raceProcessorEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorEnablerQuery getRaceProcessorEnablerQueryFromInspector(org.osid.voting.rules.RaceProcessorEnablerQueryInspector raceProcessorEnablerQueryInspector);
}
