//
// org.osid.voting.rules.RaceProcessorEnablerSmartPollsSession
//
//     The OSID Java specification for org.osid.voting.rules.RaceProcessorEnablerSmartPollsSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  polls. a <code> RaceProcessorEnablerQuery </code> can be retrieved from 
 *  this session and mapped to this <code> Polls </code> to create a virtual 
 *  collection of race processor enablers. The race processor enablers may be 
 *  sequenced using the <code> RaceProcessorEnablerSearchOrder </code> from 
 *  this session. </p> 
 *  
 *  <p> This <code> Polls </code> has a default query that matches any race 
 *  processor enabler and a default search order that specifies no sequencing. 
 *  The queries may be examined using a <code> 
 *  RaceProcessorEnablerQueryInspector. </code> The query may be modified by 
 *  converting the inspector back to a <code> RaceProcessorEnablerQuery. 
 *  </code> </p>
 */

public interface RaceProcessorEnablerSmartPollsSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the polls 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart polls. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart polls management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartPolls();


    /**
     *  Gets a race processor enabler query. 
     *
     *  @return the race processor enabler query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorEnablerQuery getRaceProcessorEnablerQuery();


    /**
     *  Gets a race processor enabler search order. 
     *
     *  @return the race processor enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorEnablerSearchOrder getRaceProcessorEnablerSearchOrder();


    /**
     *  Applies a race processor enabler query to this polls. 
     *
     *  @param  raceProcessorEnablerQuery the race processor enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceProcessorEnablerQuery </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> raceProcessorEnablerQuery 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyRaceProcessorEnablerQuery(org.osid.voting.rules.RaceProcessorEnablerQuery raceProcessorEnablerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a race processor enabler query inspector for this polls. 
     *
     *  @return the race processor enabler query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorEnablerQueryInspector inspectRaceProcessorEnablerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a race processor enabler search order to this polls. 
     *
     *  @param  raceProcessorEnablerSearchOrder the race processor enabler 
     *          search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceProcessorEnablerSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          raceProcessorEnablerSearchOrder </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyRaceProcessorEnablerSequencing(org.osid.voting.rules.RaceProcessorEnablerSearchOrder raceProcessorEnablerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a race processor enabler query from an inspector. 
     *
     *  @param  raceProcessorEnablerQueryInspector a race processor enabler 
     *          query inspector 
     *  @return the race processor enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceProcessorEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          raceProcessorEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorEnablerQuery getRaceProcessorEnablerQueryFromInspector(org.osid.voting.rules.RaceProcessorEnablerQueryInspector raceProcessorEnablerQueryInspector);
}
