//
// org.osid.voting.rules.RaceProcessorPollsAssignmentSession
//
//     The OSID Java specification for org.osid.voting.rules.RaceProcessorPollsAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session provides methods to re-assign <code> RaceProcessor </code> 
 *  to <code> Polls </code> mappings. a <code> RaceProcessor </code> may 
 *  appear in multiple <code> Polls </code> objects and removing the last 
 *  reference to a <code> RaceProcessor </code> is the equivalent of deleting 
 *  it. Each <code> Polls </code> may have its own authorizations governing 
 *  who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> RaceProcessor </code> to another <code> 
 *  Polls </code> is not a copy operation (eg: does not change its <code> Id 
 *  </code> ). </p>
 */

public interface RaceProcessorPollsAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter race processor/polls mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRaceProcessors();


    /**
     *  Tests if this user can alter race processor/polls mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRaceProcessorsToPolls(org.osid.id.Id pollsId);


    /**
     *  Gets a list of polls including and under the given polls node in which 
     *  any race processor can be assigned. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return list of assignable polls <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignablePollsIds(org.osid.id.Id pollsId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of polls including and under the given polls node in which 
     *  a specific race processor can be assigned. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  raceProcessorId the <code> Id </code> of the <code> 
     *          RaceProcessor </code> 
     *  @return list of assignable polls <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> raceProcessorId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignablePollsIdsForRaceProcessor(org.osid.id.Id pollsId, 
                                                                    org.osid.id.Id raceProcessorId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> RaceProcessor </code> to a <code> Polls. 
     *  </code> 
     *
     *  @param  raceProcessorId the <code> Id </code> of the <code> 
     *          RaceProcessor </code> 
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @throws org.osid.AlreadyExistsException <code> raceProcessorId </code> 
     *          is already assigned to <code> pollsId </code> 
     *  @throws org.osid.NotFoundException <code> raceProcessorId </code> or 
     *          <code> pollsId </code> not found 
     *  @throws org.osid.NullArgumentException <code> raceProcessorId </code> 
     *          or <code> pollsId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignRaceProcessorToPolls(org.osid.id.Id raceProcessorId, 
                                           org.osid.id.Id pollsId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> RaceProcessor </code> from a <code> Polls. </code> 
     *
     *  @param  raceProcessorId the <code> Id </code> of the <code> 
     *          RaceProcessor </code> 
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @throws org.osid.NotFoundException <code> raceProcessorId </code> or 
     *          <code> pollsId </code> not found or <code> raceProcessorId 
     *          </code> not assigned to <code> pollsId </code> 
     *  @throws org.osid.NullArgumentException <code> raceProcessorId </code> 
     *          or <code> pollsId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignRaceProcessorFromPolls(org.osid.id.Id raceProcessorId, 
                                               org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> RaceProcessor </code> from one <code> Polls </code> to 
     *  another. Mappings to other <code> Polls </code> are unaffected. 
     *
     *  @param  raceProcessorId the <code> Id </code> of the <code> 
     *          RaceProcessor </code> 
     *  @param  fromPollsId the <code> Id </code> of the current <code> Polls 
     *          </code> 
     *  @param  toPollsId the <code> Id </code> of the destination <code> 
     *          Polls </code> 
     *  @throws org.osid.NotFoundException <code> raceProcessorId, 
     *          fromPollsId, </code> or <code> toPollsId </code> not found or 
     *          <code> raceProcessorId </code> not mapped to <code> 
     *          fromPollsId </code> 
     *  @throws org.osid.NullArgumentException <code> raceProcessorId, 
     *          fromPollsId, </code> or <code> toPollsId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignRaceProcessorToPolls(org.osid.id.Id raceProcessorId, 
                                             org.osid.id.Id fromPollsId, 
                                             org.osid.id.Id toPollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
