//
// org.osid.workflow.OfficeQuery
//
//     The OSID Java specification for org.osid.workflow.OfficeQuery.
//
// Copyright (C) 2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow;


/**
 *  <p>This is the query for searching offices. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface OfficeQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the step <code> Id </code> for this query to match offices 
     *  containing process. 
     *
     *  @param  processId the process <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> processId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProcessId(org.osid.id.Id processId, boolean match);


    /**
     *  Clears the process query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProcessIdTerms();


    /**
     *  Tests if a <code> ProcessQuery </code> is available. 
     *
     *  @return <code> true </code> if a process query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessQuery();


    /**
     *  Gets the query for a process. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the process query 
     *  @throws org.osid.UnimplementedException <code> supportsProcessQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessQuery() </code> is <code> true. </code> 
     */

    public org.osid.workflow.ProcessQuery getProcessQuery();


    /**
     *  Matches offices that have any process. 
     *
     *  @param  match <code> true </code> to match offices with any process, 
     *          <code> false </code> to match offices with no process 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyProcess(boolean match);


    /**
     *  Clears the process query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProcessTerms();


    /**
     *  Sets the step <code> Id </code> for this query. 
     *
     *  @param  stepId the step <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> stepId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStepId(org.osid.id.Id stepId, boolean match);


    /**
     *  Clears the step <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStepIdTerms();


    /**
     *  Tests if an <code> StepQuery </code> is available. 
     *
     *  @return <code> true </code> if an step query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepQuery();


    /**
     *  Gets the query for an step. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the step query 
     *  @throws org.osid.UnimplementedException <code> supportsStepQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepQuery() </code> is <code> true. </code> 
     */

    public org.osid.workflow.StepQuery getStepQuery();


    /**
     *  Matches offices with any step. 
     *
     *  @param  match <code> true </code> to match offices with any step, 
     *          <code> false </code> to match offices with no step 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyStep(boolean match);


    /**
     *  Clears the step query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStepTerms();


    /**
     *  Sets the work <code> Id </code> for this query. 
     *
     *  @param  workId the work <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> workId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWorkId(org.osid.id.Id workId, boolean match);


    /**
     *  Clears the work <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWorkIdTerms();


    /**
     *  Tests if a <code> WorkQuery </code> is available. 
     *
     *  @return <code> true </code> if a work query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkQuery();


    /**
     *  Gets the query for a work. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the work query 
     *  @throws org.osid.UnimplementedException <code> supportsWorkQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkQuery() </code> is <code> true. </code> 
     */

    public org.osid.workflow.WorkQuery getWorkQuery();


    /**
     *  Matches offices that have any work. 
     *
     *  @param  match <code> true </code> to match offices with any work, 
     *          <code> false </code> to match offices with no process 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyWork(boolean match);


    /**
     *  Clears the work query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWorkTerms();


    /**
     *  Sets the office <code> Id </code> for this query to match offices that 
     *  have the specified office as an ancestor. 
     *
     *  @param  officeId a office <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorOfficeId(org.osid.id.Id officeId, boolean match);


    /**
     *  Clears the ancestor office <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorOfficeIdTerms();


    /**
     *  Tests if a <code> OfficeQuery </code> is available. 
     *
     *  @return <code> true </code> if a office query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorOfficeQuery();


    /**
     *  Gets the query for a office/ Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the office query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorOfficeQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorOfficeQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.OfficeQuery getAncestorOfficeQuery();


    /**
     *  Matches offices with any ancestor. 
     *
     *  @param  match <code> true </code> to match offices with any ancestor, 
     *          <code> false </code> to match root offices 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorOffice(boolean match);


    /**
     *  Clears the ancestor office query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorOfficeTerms();


    /**
     *  Sets the office <code> Id </code> for this query to match offices that 
     *  have the specified office as a descendant. 
     *
     *  @param  officeId a office <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantOfficeId(org.osid.id.Id officeId, boolean match);


    /**
     *  Clears the descendant office <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantOfficeIdTerms();


    /**
     *  Tests if a <code> OfficeQuery </code> is available. 
     *
     *  @return <code> true </code> if a office query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantOfficeQuery();


    /**
     *  Gets the query for a office/ Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the office query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantOfficeQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantOfficeQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.OfficeQuery getDescendantOfficeQuery();


    /**
     *  Matches offices with any descendant. 
     *
     *  @param  match <code> true </code> to match offices with any 
     *          descendant, <code> false </code> to match leaf offices 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantOffice(boolean match);


    /**
     *  Clears the descendant office query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantOfficeTerms();


    /**
     *  Gets the office query corresponding to the given <code> Office </code> 
     *  record <code> Type. </code> Multiple record retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @param  officeRecordType a office record type 
     *  @return the office query record 
     *  @throws org.osid.NullArgumentException <code> officeRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(officeRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.records.OfficeQueryRecord getOfficeQueryRecord(org.osid.type.Type officeRecordType)
        throws org.osid.OperationFailedException;
}
