//
// org.osid.workflow.ProcessForm
//
//     The OSID Java specification for org.osid.workflow.ProcessForm.
//
// Copyright (C) 2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow;


/**
 *  <p>This is the form for creating and updating <code> Processes. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  ProcessAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface ProcessForm
    extends org.osid.OsidGovernatorForm {


    /**
     *  Gets the metadata for the enabled flag. 
     *
     *  @return metadata for the enabled flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getEnabledMetadata();


    /**
     *  Sets the enabled flag. 
     *
     *  @param  enabled the new enabled flag 
     *  @throws org.osid.InvalidArgumentException <code> enabled </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setEnabled(boolean enabled);


    /**
     *  Removes the enabled flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEnabled();


    /**
     *  Gets the metadata for the initial step. 
     *
     *  @return metadata for the initial step 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getInitialStepMetadata();


    /**
     *  Sets the initial step. 
     *
     *  @param  stepId the new initial step 
     *  @throws org.osid.InvalidArgumentException <code> stepId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> stepId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setInitialStep(org.osid.id.Id stepId);


    /**
     *  Removes the initial step. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInitialStep();


    /**
     *  Gets the metadata for the initial state. 
     *
     *  @return metadata for the initial state 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getInitialStateMetadata();


    /**
     *  Sets the initial state. 
     *
     *  @param  stateId the new initial state 
     *  @throws org.osid.InvalidArgumentException <code> stateId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> stateId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setInitialState(org.osid.id.Id stateId);


    /**
     *  Removes the initial state. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInitialState();


    /**
     *  Gets the <code> ProcessFormRecord </code> corresponding to the given 
     *  process record <code> Type. </code> 
     *
     *  @param  processRecordType a process record type 
     *  @return the process form record 
     *  @throws org.osid.NullArgumentException <code> processRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(processRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.records.ProcessFormRecord getProcessFormRecord(org.osid.type.Type processRecordType)
        throws org.osid.OperationFailedException;
}
