//
// org.osid.workflow.ProcessSearchSession
//
//     The OSID Java specification for org.osid.workflow.ProcessSearchSession.
//
// Copyright (C) 2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow;


/**
 *  <p>This session provides methods for searching among <code> Process 
 *  </code> objects. The search query is constructed using the <code> 
 *  ProcessQuery. </code> </p> 
 *  
 *  <p> <code> getProcesssByQuery() </code> is the basic search method and 
 *  returns a list of <code> Processes. </code> A more advanced search may be 
 *  performed with <code> getProcessesBySearch(). </code> It accepts a <code> 
 *  ProcessSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getProcessesBySearch() </code> returns a <code> 
 *  ProcessSearchResults </code> that can be used to access the resulting 
 *  <code> ProcessList </code> or be used to perform a search within the 
 *  result set through <code> ProcessSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated office view: searches include processes in offices of 
 *      which this office is an ancestor in the office hierarchy </li> 
 *      <li> isolated office view: searches are restricted to processes in 
 *      this office </li> 
 *  </ul>
 *  
 *  
 *  <p> Processes may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> ProcessQuery. </code> 
 *  </p>
 */

public interface ProcessSearchSession
    extends org.osid.workflow.ProcessQuerySession {


    /**
     *  Gets a process search. 
     *
     *  @return the process search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.ProcessSearch getProcessSearch();


    /**
     *  Gets a process search order. The <code> ProcessSearchOrder </code> is 
     *  supplied to a <code> ProcessSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the process search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.ProcessSearchOrder getProcessSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  processQuery the process query 
     *  @param  processSearch the process search 
     *  @return the process search results 
     *  @throws org.osid.NullArgumentException <code> processQuery </code> or 
     *          <code> processSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> processQuery </code> or 
     *          <code> processSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.ProcessSearchResults getProcessesBySearch(org.osid.workflow.ProcessQuery processQuery, 
                                                                       org.osid.workflow.ProcessSearch processSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a process query from an inspector. The inspector is available 
     *  from a <code> ProcessSearchResults. </code> 
     *
     *  @param  processQueryInspector a process query inspector 
     *  @return the process query 
     *  @throws org.osid.NullArgumentException <code> processQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> processQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.ProcessQuery getProcessQueryFromInspector(org.osid.workflow.ProcessQueryInspector processQueryInspector);
}
