//
// org.osid.workflow.Step
//
//     The OSID Java specification for org.osid.workflow.Step.
//
// Copyright (C) 2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow;


/**
 *  <p>A <code> Step </code> is an element in a Process in which Work is 
 *  processed. The workers in this <code> Step </code> are represented by 
 *  <code> Resources </code> or <code> Resource </code> groups. The input 
 *  <code> States </code> list the states of <code> Work </code> that are 
 *  valid to be accepted into this <code> Step. </code> Successful processing 
 *  of the <code> Work </code> result in a single next <code> State </code> 
 *  that determines the valid next <code> Steps </code> in the <code> Process. 
 *  </code> </p>
 */

public interface Step
    extends org.osid.OsidGovernator,
            org.osid.Subjugateable {


    /**
     *  Gets the <code> Id </code> of the process. 
     *
     *  @return the process <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProcessId();


    /**
     *  Gets the process. 
     *
     *  @return the process 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Process getProcess()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Ids </code> of the resources working in this step. 
     *
     *  @return the resource <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getResourceIds();


    /**
     *  Gets the resources working in this step. 
     *
     *  @return the resources 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getResources()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Ids </code> of the valid states entering this step. 
     *
     *  @return the state <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getInputStateIds();


    /**
     *  Gets the valid states to enter this step. 
     *
     *  @return the states 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.StateList getInputStates()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the state of the work upon completing 
     *  this step. 
     *
     *  @return the state <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getNextStateId();


    /**
     *  Gets the state of the work upon completing this step. 
     *
     *  @return the state 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.State getNextState()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the step record corresponding to the given <code> Step </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> stepRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(stepRecordType) </code> is <code> true </code> . 
     *
     *  @param  stepRecordType the type of step record to retrieve 
     *  @return the step record 
     *  @throws org.osid.NullArgumentException <code> stepRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(stepRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.records.StepRecord getStepRecord(org.osid.type.Type stepRecordType)
        throws org.osid.OperationFailedException;
}
