//
// org.osid.workflow.StepLookupSession
//
//     The OSID Java specification for org.osid.workflow.StepLookupSession.
//
// Copyright (C) 2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow;


/**
 *  <p>This session provides methods for retrieving <code> Step </code> 
 *  objects. The <code> Step </code> represents a fixed connection between two 
 *  <code> Availabilities. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated office view: All step methods in this session operate, 
 *      retrieve and pertain to steps defined explicitly in the current 
 *      office. Using an isolated view is useful for managing <code> Steps 
 *      </code> with the <code> StepAdminSession. </code> </li> 
 *      <li> federated office view: All step methods in this session operate, 
 *      retrieve and pertain to all steps defined in this office and any other 
 *      steps implicitly available in this office through office inheritence. 
 *      </li> 
 *      <li> active step view: active steps are returned from methods in this 
 *      session </li> 
 *      <li> any status step view: active and inactive steps are returned from 
 *      methods in this session </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedOfficeView() </code> and <code> 
 *  useIsolatedOfficeView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface StepLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Office </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Office Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOfficeId();


    /**
     *  Gets the <code> Office </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Office getOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Step </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupSteps();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeStepView();


    /**
     *  A complete view of the <code> Step </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryStepView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include steps in offices which are children of this office in the 
     *  office hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedOfficeView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this office only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedOfficeView();


    /**
     *  Only active steps are returned from methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveStepView();


    /**
     *  Borth active and inactive steps are returned from methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusStepView();


    /**
     *  Gets the <code> Step </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Step </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Step </code> and retained for compatibility. 
     *  
     *  In active mode, steps are returned that are currently active. In any 
     *  status mode, active and inactive steps are returned. 
     *
     *  @param  stepId <code> Id </code> of the <code> Step </code> 
     *  @return the step 
     *  @throws org.osid.NotFoundException <code> stepId </code> not found 
     *  @throws org.osid.NullArgumentException <code> stepId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.workflow.Step getStep(org.osid.id.Id stepId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> StepList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  steps specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Steps </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *  
     *  In active mode, steps are returned that are currently active. In any 
     *  status mode, active and inactive steps are returned. 
     *
     *  @param  stepIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Step </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> stepIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.StepList getStepsByIds(org.osid.id.IdList stepIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> StepList </code> corresponding to the given step genus 
     *  <code> Type </code> which does not include steps of genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  steps or an error results. Otherwise, the returned list may contain 
     *  only those steps that are accessible through this session. 
     *  
     *  In active mode, steps are returned that are currently active. In any 
     *  status mode, active and inactive steps are returned. 
     *
     *  @param  stepGenusType a step genus type 
     *  @return the returned <code> Step </code> list 
     *  @throws org.osid.NullArgumentException <code> stepGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.StepList getStepsByGenusType(org.osid.type.Type stepGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> StepList </code> corresponding to the given step genus 
     *  <code> Type </code> and include any additional steps with genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  steps or an error results. Otherwise, the returned list may contain 
     *  only those steps that are accessible through this session. 
     *  
     *  In active mode, steps are returned that are currently active. In any 
     *  status mode, active and inactive steps are returned. 
     *
     *  @param  stepGenusType a step genus type 
     *  @return the returned <code> Step </code> list 
     *  @throws org.osid.NullArgumentException <code> stepGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.StepList getStepsByParentGenusType(org.osid.type.Type stepGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> StepList </code> containing the given step record <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  steps or an error results. Otherwise, the returned list may contain 
     *  only those steps that are accessible through this session. 
     *  
     *  In active mode, steps are returned that are currently active. In any 
     *  status mode, active and inactive steps are returned. 
     *
     *  @param  stepRecordType a step record type 
     *  @return the returned <code> Step </code> list 
     *  @throws org.osid.NullArgumentException <code> stepRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.StepList getStepsByRecordType(org.osid.type.Type stepRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> StepList </code> from the given provider. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  steps or an error results. Otherwise, the returned list may contain 
     *  only those steps that are accessible through this session. 
     *  
     *  In active mode, steps are returned that are currently active. In any 
     *  status mode, active and inactive steps are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Step </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.StepList getStepsByProvider(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of steps by process. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  steps or an error results. Otherwise, the returned list may contain 
     *  only those steps that are accessible through this session. 
     *  
     *  In active mode, steps are returned that are currently active. In any 
     *  status mode, active and inactive steps are returned. 
     *
     *  @param  processId a process <code> Id </code> 
     *  @return the returned <code> Step </code> list 
     *  @throws org.osid.NullArgumentException <code> processId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.StepList getStepsForProcess(org.osid.id.Id processId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of steps for which the given state is valid. The steps 
     *  returned are the states specified in the previous step or the process. 
     *  <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  steps or an error results. Otherwise, the returned list may contain 
     *  only those steps that are accessible through this session. 
     *  
     *  In active mode, steps are returned that are currently active. In any 
     *  status mode, active and inactive steps are returned. 
     *
     *  @param  stateId a stateId <code> Id </code> 
     *  @return the returned <code> Step </code> list 
     *  @throws org.osid.NullArgumentException <code> stateId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.StepList getStepsByState(org.osid.id.Id stateId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Steps. </code> 
     *  
     *  In plenary mode, the returned list contains all known steps or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  steps that are accessible through this session. 
     *  
     *  In active mode, steps are returned that are currently active. In any 
     *  status mode, active and inactive steps are returned. 
     *
     *  @return a list of <code> Steps </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.StepList getSteps()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
