//
// org.osid.workflow.WorkAdminSession
//
//     The OSID Java specification for org.osid.workflow.WorkAdminSession.
//
// Copyright (C) 2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow;


/**
 *  <p>This session creates, updates, and deletes <code> Works. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Work, </code> a <code> WorkForm </code> is requested using <code> 
 *  getWorkFormForCreate() </code> specifying the desired record <code> Types 
 *  </code> or none if no record <code> Types </code> are needed. The returned 
 *  <code> WorkForm </code> will indicate that it is to be used with a create 
 *  operation and can be used to examine metdata or validate data prior to 
 *  creation. Once the <code> WorkForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> WorkForm </code> corresponds 
 *  to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> WorkForms </code> are requested to the <code> Work 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getWorkFormForUpdate(). </code> Similarly, the <code> WorkForm </code> has 
 *  metadata about the data that can be updated and it can perform validation 
 *  before submitting the update. The <code> WorkForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Works. </code> To unmap a <code> 
 *  Work </code> from the current <code> Office, </code> the <code> 
 *  WorkOfficeAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Work </code> itself thus removing 
 *  it from all known <code> Office </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface WorkAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Office </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Office Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOfficeId();


    /**
     *  Gets the <code> Office </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Office getOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Works. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Work </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Work </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateWorks();


    /**
     *  Tests if this user can create a single <code> Work </code> using the 
     *  desired record types. While <code> 
     *  WorkflowManager.getWorkRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Work. </code> Providing an 
     *  empty array tests if a <code> Work </code> can be created with no 
     *  records. 
     *
     *  @param  workRecordTypes array of work record types 
     *  @return <code> true </code> if <code> Work </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> workRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateWorkWithRecordTypes(org.osid.type.Type[] workRecordTypes);


    /**
     *  Gets the work form for creating new works. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  workRecordTypes array of work record types 
     *  @return the work form 
     *  @throws org.osid.NullArgumentException <code> workRecordTypes </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkForm getWorkFormForCreate(org.osid.type.Type[] workRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Work. </code> 
     *
     *  @param  workForm the form for this <code> Work </code> 
     *  @return the new <code> Work </code> 
     *  @throws org.osid.IllegalStateException <code> workForm </code> already 
     *          used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> workForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> workForm </code> did not 
     *          originate from <code> getWorkFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Work createWork(org.osid.workflow.WorkForm workForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Works. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Work </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Work </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateWorks();


    /**
     *  Gets the work form for updating an existing work. A new work form 
     *  should be requested for each update transaction. 
     *
     *  @param  workId the <code> Id </code> of the <code> Work </code> 
     *  @return the work form 
     *  @throws org.osid.NotFoundException <code> workId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> workId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkForm getWorkFormForUpdate(org.osid.id.Id workId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing work. 
     *
     *  @param  workForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> workForm </code> already 
     *          used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> workForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> workForm </code> did not 
     *          originate from <code> getWorkFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateWork(org.osid.workflow.WorkForm workForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Works. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Work </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Work </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteWorks();


    /**
     *  Deletes a <code> Work. </code> 
     *
     *  @param  workId the <code> Id </code> of the <code> Work </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> workId </code> not found 
     *  @throws org.osid.NullArgumentException <code> workId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteWork(org.osid.id.Id workId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Works. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Work </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageWorkAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Work </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Work </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another work, it is reassigned to the given work <code> 
     *  Id. </code> 
     *
     *  @param  workId the <code> Id </code> of a <code> Work </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> workId </code> not found 
     *  @throws org.osid.NullArgumentException <code> workId </code> or <code> 
     *          aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasWork(org.osid.id.Id workId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can move <code> Work </code> among process. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting a <code> Work </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer move operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Work </code> moving is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canMoveWork();


    /**
     *  Moves work to another process. 
     *
     *  @param  workId the work <code> Id </code> 
     *  @param  processId the new process <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException work already part of process 
     *  @throws org.osid.NotFoundException <code> processId </code> or <code> 
     *          workId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> processId </code> or 
     *          <code> workId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveWork(org.osid.id.Id workId, org.osid.id.Id processId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can change <code> Work </code> status. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Work </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer status operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Work </code> status is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageWorkStatus();


    /**
     *  Marks work as complete. 
     *
     *  @param  workId the work <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> workId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> workId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void completeWork(org.osid.id.Id workId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Marks work as incomplete. 
     *
     *  @param  workId the work <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> workId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> workId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reopenWork(org.osid.id.Id workId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
