//
// org.osid.workflow.rules.ProcessEnablerSmartOfficeSession
//
//     The OSID Java specification for org.osid.workflow.rules.ProcessEnablerSmartOfficeSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  offices. A <code> ProcessEnablerQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Office </code> to create a virtual 
 *  collection of process enablers. The process enabler may be sequenced using 
 *  the <code> ProcessEnablerSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Office </code> has a default query that matches any 
 *  process enabler and a default search order that specifies no sequencing. 
 *  The queries may be examined using a <code> ProcessEnablerQueryInspector. 
 *  </code> The query may be modified by converting the inspector back to a 
 *  <code> ProcessEnablerQuery. </code> </p>
 */

public interface ProcessEnablerSmartOfficeSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Office </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Office Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOfficeId();


    /**
     *  Gets the <code> Office </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Office getOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart offices. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart office management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartOffices();


    /**
     *  Gets a process enabler query. 
     *
     *  @return the process enabler query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.ProcessEnablerQuery getProcessEnablerQuery();


    /**
     *  Gets a process enabler search order. 
     *
     *  @return the process enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.ProcessEnablerSearchOrder getProcessEnablerSearchOrder();


    /**
     *  Applies a process enabler query to this office. 
     *
     *  @param  processEnablerQuery the process enabler query 
     *  @throws org.osid.NullArgumentException <code> processEnablerQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> processEnablerQuery 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyProcessEnablerQuery(org.osid.workflow.rules.ProcessEnablerQuery processEnablerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a process enabler query inspector for this office. 
     *
     *  @return the process enabler query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.ProcessEnablerQueryInspector inspectProcessEnablerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a process enabler search order to this office. 
     *
     *  @param  processEnablerSearchOrder the process enabler search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          processEnablerSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> processEnablerSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyProcessEnablerSequencing(org.osid.workflow.rules.ProcessEnablerSearchOrder processEnablerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a process enabler query from an inspector. 
     *
     *  @param  processEnablerQueryInspector a process enabler query inspector 
     *  @return the process enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          processEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          processEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.ProcessEnablerQuery getProcessEnablerQueryFromInspector(org.osid.workflow.rules.ProcessEnablerQueryInspector processEnablerQueryInspector);
}
