//
// org.osid.workflow.rules.StepConstrainerEnablerAdminSession
//
//     The OSID Java specification for org.osid.workflow.rules.StepConstrainerEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This session creates and removes step constrainer enablers. The data 
 *  for create and update is provided via the <code> 
 *  StepConstrainerEnablerForm. </code> </p>
 */

public interface StepConstrainerEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Office </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Office Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOfficeId();


    /**
     *  Gets the <code> Office </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Office getOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create step constrainer enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> StepConstrainerEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> StepConstrainerEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateStepConstrainerEnabler();


    /**
     *  Tests if this user can create a single <code> StepConstrainerEnabler 
     *  </code> using the desired record types. While <code> 
     *  WorkflowRulesManager.getStepConstrainerEnablerRecordTypes() </code> 
     *  can be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  StepConstrainerEnabler. </code> Providing an empty array tests if a 
     *  <code> StepConstrainerEnabler </code> can be created with no records. 
     *
     *  @param  stepConstrainerEnablerRecordTypes array of step constrainer 
     *          enabler record types 
     *  @return <code> true </code> if <code> StepConstrainerEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepConstrainerEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateStepConstrainerEnablerWithRecordTypes(org.osid.type.Type[] stepConstrainerEnablerRecordTypes);


    /**
     *  Gets the step constrainer enabler form for creating new step 
     *  constrainer enablers. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  stepConstrainerEnablerRecordTypes array of step constrainer 
     *          enabler record types 
     *  @return the step constrainer enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepConstrainerEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerForm getStepConstrainerEnablerFormForCreate(org.osid.type.Type[] stepConstrainerEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> StepConstrainerEnabler. </code> 
     *
     *  @param  stepConstrainerEnablerForm the form for this <code> 
     *          StepConstrainerEnabler </code> 
     *  @return the new <code> StepConstrainerEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          stepConstrainerEnablerForm </code> already used in a create 
     *          transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepConstrainerEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          stepConstrainerEnablerForm </code> did not originate from 
     *          <code> getStepConstrainerEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerEnabler createStepConstrainerEnabler(org.osid.workflow.rules.StepConstrainerEnablerForm stepConstrainerEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update step constrainer enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> StepConstrainerEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> StepConstrainerEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateStepConstrainerEnablers();


    /**
     *  Gets the step constrainer enabler form for updating an existing step 
     *  constrainer enabler. A new step constrainer enabler form should be 
     *  requested for each update transaction. 
     *
     *  @param  stepConstrainerEnablerId the <code> Id </code> of the <code> 
     *          StepConstrainerEnabler </code> 
     *  @return the step constrainer enabler form 
     *  @throws org.osid.NotFoundException <code> stepConstrainerEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerForm getStepConstrainerEnablerFormForUpdate(org.osid.id.Id stepConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing step constrainer enabler. 
     *
     *  @param  stepConstrainerEnablerForm the form containing the elements to 
     *          be updated 
     *  @throws org.osid.IllegalStateException <code> 
     *          stepConstrainerEnablerForm </code> already used in an update 
     *          transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepConstrainerEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          stepConstrainerEnablerForm </code> did not originate from 
     *          <code> getStepConstrainerEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateStepConstrainerEnabler(org.osid.workflow.rules.StepConstrainerEnablerForm stepConstrainerEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete step constrainer enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> StepConstrainerEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> StepConstrainerEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteStepConstrainerEnablers();


    /**
     *  Deletes a <code> StepConstrainerEnabler. </code> 
     *
     *  @param  stepConstrainerEnablerId the <code> Id </code> of the <code> 
     *          StepConstrainerEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> stepConstrainerEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteStepConstrainerEnabler(org.osid.id.Id stepConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for step 
     *  constrainer enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> StepConstrainerEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageStepConstrainerEnablerAliases();


    /**
     *  Adds a <code> Id </code> to a <code> StepConstrainerEnabler </code> 
     *  for the purpose of creating compatibility. The primary <code> Id 
     *  </code> of the <code> StepConstrainerEnabler </code> is determined by 
     *  the provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another step 
     *  constrainer enabler. it is reassigned to the given step constrainer 
     *  enabler <code> Id. </code> 
     *
     *  @param  stepConstrainerEnablerId the <code> Id </code> of a <code> 
     *          StepConstrainerEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> stepConstrainerEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerEnablerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasStepConstrainerEnabler(org.osid.id.Id stepConstrainerEnablerId, 
                                            org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
