//
// org.osid.workflow.rules.StepConstrainerRuleApplicationSession
//
//     The OSID Java specification for org.osid.workflow.rules.StepConstrainerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This session provides methods to apply <code> StepConstrainers </code> 
 *  to <code> Steps. </code> A <code> Step </code> with multiple <code> 
 *  StepConstrainers </code> means any positive rule evaluation across the 
 *  constrainers result in an accessible <code> Step. </code> </p>
 */

public interface StepConstrainerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Office </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Office Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOfficeId();


    /**
     *  Gets the <code> Office </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Office getOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter step constrainer/step mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignStepConstrainers();


    /**
     *  Adds an existing <code> StepConstrainer </code> to a <code> Step. 
     *  </code> 
     *
     *  @param  stepConstrainerId the <code> Id </code> of the <code> 
     *          StepConstrainer </code> 
     *  @param  stepId the <code> Id </code> of the <code> Step </code> 
     *  @throws org.osid.AlreadyExistsException <code> stepConstrainerId 
     *          </code> is already applied to <code> stepId </code> 
     *  @throws org.osid.NotFoundException <code> stepConstrainerId </code> or 
     *          <code> stepId </code> not found 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerId 
     *          </code> or <code> stepId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignStepConstrainerToStep(org.osid.id.Id stepConstrainerId, 
                                            org.osid.id.Id stepId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> StepConstrainer </code> from a <code> Step. </code> 
     *
     *  @param  stepConstrainerId the <code> Id </code> of the <code> 
     *          StepConstrainer </code> 
     *  @param  stepId the <code> Id </code> of the <code> Step </code> 
     *  @throws org.osid.NotFoundException <code> stepConstrainerId </code> or 
     *          <code> stepId </code> not found or <code> stepConstrainerId 
     *          </code> not applied to <code> stepId </code> 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerId 
     *          </code> or <code> stepId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignStepConstrainerFromStep(org.osid.id.Id stepConstrainerId, 
                                                org.osid.id.Id stepId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> StepConstrainers. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> StepConstrainer </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceStepConstrainers();


    /**
     *  Reorders step constrainer for a step by moving the specified step 
     *  constrainer in front of a reference step constrainer. 
     *
     *  @param  stepConstrainerId the <code> Id </code> of a <code> 
     *          StepConstrainer </code> 
     *  @param  stepId the <code> Id </code> of a <code> Step </code> 
     *  @param  referenceId the reference step constrainer <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> stepConstrainerId, stepId 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          stepConstrainerId </code> or <code> referenceId </code> not 
     *          related to <code> stepId </code> 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerId, 
     *          stepId </code> or <code> referenceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveStepConstrainerAhead(org.osid.id.Id stepConstrainerId, 
                                         org.osid.id.Id stepId, 
                                         org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders step constrainer for a step by moving the specified step 
     *  constrainer behind a reference step constrainer. 
     *
     *  @param  stepConstrainerId the <code> Id </code> of a <code> 
     *          StepConstrainer </code> 
     *  @param  stepId the <code> Id </code> of a <code> Step </code> 
     *  @param  referenceId the reference step constrainer <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> stepConstrainerId, stepId 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          stepConstrainerId </code> or <code> referenceId </code> not 
     *          related to <code> stepId </code> 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerId, 
     *          stepId </code> or <code> referenceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveStepConstrainerBehind(org.osid.id.Id stepConstrainerId, 
                                          org.osid.id.Id stepId, 
                                          org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of step constrainers for a step. 
     *
     *  @param  stepConstrainerIds the <code> Ids </code> for a set of <code> 
     *          StepConstrainers </code> 
     *  @param  stepId the <code> Id </code> of a <code> StepConstrainer 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> stepId </code> not found or, 
     *          a <code> stepConstrainerId </code> not related to <code> 
     *          stepId </code> 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerIds 
     *          </code> or <code> stepId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderStepConstrainers(org.osid.id.Id[] stepConstrainerIds, 
                                      org.osid.id.Id stepId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
