//
// org.osid.workflow.rules.StepProcessorEnablerAdminSession
//
//     The OSID Java specification for org.osid.workflow.rules.StepProcessorEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This session creates and removes step processor enablers. The data for 
 *  create and update is provided via the <code> StepProcessorEnablerForm. 
 *  </code> </p>
 */

public interface StepProcessorEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Office </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Office Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOfficeId();


    /**
     *  Gets the <code> Office </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Office getOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create step processor enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> StepProcessorEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> StepProcessorEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateStepProcessorEnabler();


    /**
     *  Tests if this user can create a single <code> StepProcessorEnabler 
     *  </code> using the desired record types. While <code> 
     *  WorkflowRulesManager.getStepProcessorEnablerRecordTypes() </code> can 
     *  be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  StepProcessorEnabler. </code> Providing an empty array tests if a 
     *  <code> StepProcessorEnabler </code> can be created with no records. 
     *
     *  @param  stepProcessorEnablerRecordTypes array of step processor 
     *          enabler types 
     *  @return <code> true </code> if <code> StepProcessorEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepProcessorEnablerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateStepProcessorEnablerWithRecordTypes(org.osid.type.Type[] stepProcessorEnablerRecordTypes);


    /**
     *  Gets the step processor enabler form for creating new step processor 
     *  enablers. A new form should be requested for each create transaction. 
     *
     *  @param  stepProcessorEnablerRecordTypes array of step processor 
     *          enabler types 
     *  @return the step processor enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepProcessorEnablerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepProcessorEnablerForm getStepProcessorEnablerFormForCreate(org.osid.type.Type[] stepProcessorEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> StepProcessorEnabler. </code> 
     *
     *  @param  stepProcessorEnablerForm the form for this <code> 
     *          StepProcessorEnabler </code> 
     *  @return the new <code> StepProcessorEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> stepProcessorEnablerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> stepProcessorEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> stepProcessorEnablerForm 
     *          </code> did not originate from <code> 
     *          getStepProcessorEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepProcessorEnabler createStepProcessorEnabler(org.osid.workflow.rules.StepProcessorEnablerForm stepProcessorEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update step processor enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> StepProcessorEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> StepProcessorEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateStepProcessorEnablers();


    /**
     *  Gets the step processor enabler form for updating an existing step 
     *  processor enabler. A new step processor enabler form should be 
     *  requested for each update transaction. 
     *
     *  @param  stepProcessorEnablerId the <code> Id </code> of the <code> 
     *          StepProcessorEnabler </code> 
     *  @return the step processor enabler form 
     *  @throws org.osid.NotFoundException <code> stepProcessorEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> stepProcessorEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepProcessorEnablerForm getStepProcessorEnablerFormForUpdate(org.osid.id.Id stepProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing step processor enabler. 
     *
     *  @param  stepProcessorEnablerForm the form containing the elements to 
     *          be updated 
     *  @throws org.osid.IllegalStateException <code> stepProcessorEnablerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> stepProcessorEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> stepProcessorEnablerForm 
     *          </code> did not originate from <code> 
     *          getStepProcessorEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateStepProcessorEnabler(org.osid.workflow.rules.StepProcessorEnablerForm stepProcessorEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete step processor enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> StepProcessorEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> StepProcessorEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteStepProcessorEnablers();


    /**
     *  Deletes a <code> StepProcessorEnabler. </code> 
     *
     *  @param  stepProcessorEnablerId the <code> Id </code> of the <code> 
     *          StepProcessorEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> stepProcessorEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> stepProcessorEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteStepProcessorEnabler(org.osid.id.Id stepProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for step 
     *  processor enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> StepProcessorEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageStepProcessorEnablerAliases();


    /**
     *  Adds a <code> Id </code> to a <code> StepProcessorEnabler </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> StepProcessorEnabler </code> is determined by the 
     *  provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another step 
     *  processor enabler. it is reassigned to the given step processor 
     *  enabler <code> Id. </code> 
     *
     *  @param  stepProcessorEnablerId the <code> Id </code> of a <code> 
     *          StepProcessorEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> stepProcessorEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> stepProcessorEnablerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasStepProcessorEnabler(org.osid.id.Id stepProcessorEnablerId, 
                                          org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
