//
// org.osid.workflow.rules.StepProcessorEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.workflow.rules.StepProcessorEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This session provides methods to apply <code> StepProcessorEnablers 
 *  </code> to <code> StepProcessors. </code> a <code> StepProcessor </code> 
 *  with multiple <code> StepProcessorEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an effective <code> 
 *  StepProcessor. </code> </p>
 */

public interface StepProcessorEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Office </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Office Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOfficeId();


    /**
     *  Gets the <code> Office </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Office getOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter step processor enabler/step processor 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignStepProcessorEnablers();


    /**
     *  Adds an existing <code> StepProcessorEnabler </code> to a <code> 
     *  StepProcessor. </code> 
     *
     *  @param  stepProcessorEnablerId the <code> Id </code> of the <code> 
     *          StepProcessorEnabler </code> 
     *  @param  stepProcessorId the <code> Id </code> of the <code> 
     *          StepProcessor </code> 
     *  @throws org.osid.AlreadyExistsException <code> stepProcessorEnablerId 
     *          </code> is already applied to <code> stepProcessorId </code> 
     *  @throws org.osid.NotFoundException <code> stepProcessorEnablerId 
     *          </code> or <code> stepProcessorId </code> not found 
     *  @throws org.osid.NullArgumentException <code> stepProcessorEnablerId 
     *          </code> or <code> stepProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignStepProcessorEnablerToStepProcessor(org.osid.id.Id stepProcessorEnablerId, 
                                                          org.osid.id.Id stepProcessorId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> StepProcessorEnabler </code> from a <code> 
     *  StepProcessor. </code> 
     *
     *  @param  stepProcessorEnablerId the <code> Id </code> of the <code> 
     *          StepProcessorEnabler </code> 
     *  @param  stepProcessorId the <code> Id </code> of the <code> 
     *          StepProcessor </code> 
     *  @throws org.osid.NotFoundException <code> stepProcessorEnablerId 
     *          </code> or <code> stepProcessorId </code> not found or <code> 
     *          stepProcessorEnablerId </code> not applied to <code> 
     *          stepProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> stepProcessorEnablerId 
     *          </code> or <code> stepProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignStepProcessorEnablerFromStepProcessor(org.osid.id.Id stepProcessorEnablerId, 
                                                              org.osid.id.Id stepProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> StepProcessorEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> StepProcessorEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceStepProcessorEnablers();


    /**
     *  Reorders step processor enablers for a step processor by moving the 
     *  specified step processor enabler in front of a reference step 
     *  processor enabler. 
     *
     *  @param  stepProcessorEnablerId the <code> Id </code> of a <code> 
     *          StepProcessorEnabler </code> 
     *  @param  stepProcessorId the <code> Id </code> of a <code> 
     *          StepProcessor </code> 
     *  @param  referenceId the reference step processor enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> stepProcessorEnablerId, 
     *          stepProcessorId, </code> or <code> referenceId </code> not 
     *          found or, <code> stepProcessorEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> stepProcessorId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> stepProcessorEnablerId, 
     *          stepProcessorId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveStepProcessorEnablerAhead(org.osid.id.Id stepProcessorEnablerId, 
                                              org.osid.id.Id stepProcessorId, 
                                              org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders step processor enablers for a step processor by moving the 
     *  specified step processor enabler behind a reference step processor 
     *  enabler. 
     *
     *  @param  stepProcessorEnablerId the <code> Id </code> of a <code> 
     *          StepProcessorEnabler </code> 
     *  @param  stepProcessorId the <code> Id </code> of a <code> 
     *          StepProcessor </code> 
     *  @param  referenceId the reference step processor enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> stepProcessorEnablerId, 
     *          stepProcessorId, </code> or <code> referenceId </code> not 
     *          found or, <code> stepProcessorEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> stepProcessorId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> stepProcessorEnablerId, 
     *          stepProcessorId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveStepProcessorEnablerBehind(org.osid.id.Id stepProcessorEnablerId, 
                                               org.osid.id.Id stepProcessorId, 
                                               org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of step processor enablers for a step processor. 
     *
     *  @param  stepProcessorEnablerIds the <code> Ids </code> for a set of 
     *          <code> StepProcessorEnablers </code> 
     *  @param  stepProcessorId the <code> Id </code> of a <code> 
     *          StepProcessor </code> 
     *  @throws org.osid.NotFoundException <code> stepProcessorId </code> not 
     *          found or, an <code> stepProcessorEnablerId </code> not related 
     *          to <code> stepProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> stepProcessorEnablerIds 
     *          </code> or <code> stepProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderStepProcessorEnablers(org.osid.id.Id[] stepProcessorEnablerIds, 
                                           org.osid.id.Id stepProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
