//
// org.osid.provisioning.rules.ProvisioningRulesProxyManager
//
//     The OSID Java specification for org.osid.provisioning.rules.ProvisioningRulesProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>The provisioning rules proxy manager provides access to provisioning 
 *  rules sessions and provides interoperability tests for various aspects of 
 *  this service. Methods in this manager pass a <code> Proxy </code> 
 *  interface for passing information from server environments. The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> QueueConstrainerLookupSession: </code> a session to 
 *      retrieve queue constrainer </li> 
 *      <li> <code> QueueConstrainerQuerySession: </code> a session to query 
 *      for queue constrainer </li> 
 *      <li> <code> QueueConstrainerSearchSession: </code> a session to search 
 *      for queue constrainer </li> 
 *      <li> <code> QueueConstrainerAdminSession: </code> a session to create 
 *      and delete queue constrainer </li> 
 *      <li> <code> QueueConstrainerNotificationSession: </code> a session to 
 *      receive notifications pertaining to queue constrainer changes </li> 
 *      <li> <code> QueueConstrainerDistributorSession: </code> a session to 
 *      look up queue constrainer distributor mappings </li> 
 *      <li> <code> QueueConstrainerDistributorAssignmentSession: </code> a 
 *      session to manage queue constrainer to distributor mappings </li> 
 *      <li> <code> QueueConstrainerSmartDistributorSession: </code> a session 
 *      to manage dynamic distributors of queue constrainer </li> 
 *      <li> <code> QueueConstrainerRuleLookupSession: </code> a session to 
 *      look up queue constrainer to queue mappings </li> 
 *      <li> <code> QueueConstrainerRuleApplicationSession: </code> a session 
 *      to apply queue constrainer to queuess </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> QueueConstrainerEnablerLookupSession: </code> a session to 
 *      retrieve queue constrainer enablers </li> 
 *      <li> <code> QueueConstrainerEnablerQuerySession: </code> a session to 
 *      query for queue constrainer enablers </li> 
 *      <li> <code> QueueConstrainerEnablerSearchSession: </code> a session to 
 *      search for queue constrainer enablers </li> 
 *      <li> <code> QueueConstrainerEnablerAdminSession: </code> a session to 
 *      create and delete queue constrainer enablers </li> 
 *      <li> <code> QueueConstrainerEnablerNotificationSession: </code> a 
 *      session to receive notifications pertaining to queue constrainer 
 *      enabler changes </li> 
 *      <li> <code> QueueConstrainerEnablerDistributorSession: </code> a 
 *      session to look up queue constrainer enabler distributor mappings 
 *      </li> 
 *      <li> <code> QueueConstrainerEnablerDistributorAssignmentSession: 
 *      </code> a session to manage queue constrainer enabler to distributor 
 *      mappings </li> 
 *      <li> <code> QueueConstrainerEnablerSmartDistributorSession: </code> a 
 *      session to manage dynamic distributors of queue constrainer enablers 
 *      </li> 
 *      <li> <code> QueueConstrainerEnableRuleLookupSession: </code> a session 
 *      to look up queue constrainer enabler mappings </li> 
 *      <li> <code> QueueConstrainerEnablerRuleApplicationSession: </code> a 
 *      session to apply queue constrainer enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> QueueProcessorLookupSession: </code> a session to retrieve 
 *      queue processor </li> 
 *      <li> <code> QueueProcessorQuerySession: </code> a session to query for 
 *      queue processor </li> 
 *      <li> <code> QueueProcessorSearchSession: </code> a session to search 
 *      for queue processor </li> 
 *      <li> <code> QueueProcessorAdminSession: </code> a session to create 
 *      and delete queue processor </li> 
 *      <li> <code> QueueProcessorNotificationSession: </code> a session to 
 *      receive notifications pertaining to queue processor changes </li> 
 *      <li> <code> QueueProcessorDistributorSession: </code> a session to 
 *      look up queue processor distributor mappings </li> 
 *      <li> <code> QueueProcessorDistributorAssignmentSession: </code> a 
 *      session to manage queue processor to distributor mappings </li> 
 *      <li> <code> QueueProcessorSmartDistributorSession: </code> a session 
 *      to manage dynamic distributors of queue processor </li> 
 *      <li> <code> QueueProcessorRuleLookupSession: </code> a session to look 
 *      up queue processor to queue mappings </li> 
 *      <li> <code> QueueProcessorRuleApplicationSession: </code> a session to 
 *      apply queue processor to queuess </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> QueueProcessorEnablerLookupSession: </code> a session to 
 *      retrieve queue processor enablers </li> 
 *      <li> <code> QueueProcessorEnablerQuerySession: </code> a session to 
 *      query for queue processor enablers </li> 
 *      <li> <code> QueueProcessorEnablerSearchSession: </code> a session to 
 *      search for queue processor enablers </li> 
 *      <li> <code> QueueProcessorEnablerAdminSession: </code> a session to 
 *      create and delete queue processor enablers </li> 
 *      <li> <code> QueueProcessorEnablerNotificationSession: </code> a 
 *      session to receive notifications pertaining to queue processor enabler 
 *      changes </li> 
 *      <li> <code> QueueProcessorEnablerDistributorSession: </code> a session 
 *      to look up queue processor enabler distributor mappings </li> 
 *      <li> <code> QueueProcessorEnablerDistributorAssignmentSession: </code> 
 *      a session to manage queue processor enabler to distributor mappings 
 *      </li> 
 *      <li> <code> QueueProcessorEnablerSmartDistributorSession: </code> a 
 *      session to manage dynamic distributors of queue processor enablers 
 *      </li> 
 *      <li> <code> QueueProcessorEnablerRuleLookupSession: </code> a session 
 *      to look up queue processor enabler mappings </li> 
 *      <li> <code> QueueProcessorEnablerRuleApplicationSession: </code> a 
 *      session to apply queue processor enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> PoolConstrainerLookupSession: </code> a session to 
 *      retrieve pool constrainer </li> 
 *      <li> <code> PoolConstrainerQuerySession: </code> a session to query 
 *      for pool constrainer </li> 
 *      <li> <code> PoolConstrainerSearchSession: </code> a session to search 
 *      for pool constrainer </li> 
 *      <li> <code> PoolConstrainerAdminSession: </code> a session to create 
 *      and delete pool constrainer </li> 
 *      <li> <code> PoolConstrainerNotificationSession: </code> a session to 
 *      receive notifications pertaining to pool constrainer changes </li> 
 *      <li> <code> PoolConstrainerDistributorSession: </code> a session to 
 *      look up pool constrainer distributor mappings </li> 
 *      <li> <code> PoolConstrainerDistributorAssignmentSession: </code> a 
 *      session to manage pool constrainer to distributor mappings </li> 
 *      <li> <code> PoolConstrainerSmartDistributorSession: </code> a session 
 *      to manage dynamic distributors of pool constrainer </li> 
 *      <li> <code> PoolConstrainerRuleLookupSession: </code> a session to 
 *      look up pool constrainer to pool mappings </li> 
 *      <li> <code> PoolConstrainerRuleApplicationSession: </code> a session 
 *      to apply pool constrainer to poolss </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> PoolConstrainerEnablerLookupSession: </code> a session to 
 *      retrieve pool constrainer enablers </li> 
 *      <li> <code> PoolConstrainerEnablerQuerySession: </code> a session to 
 *      query for pool constrainer enablers </li> 
 *      <li> <code> PoolConstrainerEnablerSearchSession: </code> a session to 
 *      search for pool constrainer enablers </li> 
 *      <li> <code> PoolConstrainerEnablerAdminSession: </code> a session to 
 *      create and delete pool constrainer enablers </li> 
 *      <li> <code> PoolConstrainerEnablerNotificationSession: </code> a 
 *      session to receive notifications pertaining to pool constrainer 
 *      enabler changes </li> 
 *      <li> <code> PoolConstrainerEnablerDistributorSession: </code> a 
 *      session to look up pool constrainer enabler distributor mappings </li> 
 *      <li> <code> PoolConstrainerEnablerDistributorAssignmentSession: 
 *      </code> a session to manage pool constrainer enabler to distributor 
 *      mappings </li> 
 *      <li> <code> PoolConstrainerEnablerSmartDistributorSession: </code> a 
 *      session to manage dynamic distributors of pool constrainer enablers 
 *      </li> 
 *      <li> <code> PoolConstrainerEnableRuleLookupSession: </code> a session 
 *      to look up pool constrainer enabler mappings </li> 
 *      <li> <code> PoolConstrainerEnablerRuleApplicationSession: </code> a 
 *      session to apply pool constrainer enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> PoolProcessorLookupSession: </code> a session to retrieve 
 *      pool processor </li> 
 *      <li> <code> PoolProcessorQuerySession: </code> a session to query for 
 *      pool processor </li> 
 *      <li> <code> PoolProcessorSearchSession: </code> a session to search 
 *      for pool processor </li> 
 *      <li> <code> PoolProcessorAdminSession: </code> a session to create and 
 *      delete pool processor </li> 
 *      <li> <code> PoolProcessorNotificationSession: </code> a session to 
 *      receive notifications pertaining to pool processor changes </li> 
 *      <li> <code> PoolProcessorDistributorSession: </code> a session to look 
 *      up pool processor distributor mappings </li> 
 *      <li> <code> PoolProcessorDistributorAssignmentSession: </code> a 
 *      session to manage pool processor to distributor mappings </li> 
 *      <li> <code> PoolProcessorSmartDistributorSession: </code> a session to 
 *      manage dynamic distributors of pool processor </li> 
 *      <li> <code> PoolProcessorRuleLookupSession: </code> a session to look 
 *      up pool processor to pool mappings </li> 
 *      <li> <code> PoolProcessorRuleApplicationSession: </code> a session to 
 *      apply pool processor to poolss </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> PoolProcessorEnablerLookupSession: </code> a session to 
 *      retrieve pool processor enablers </li> 
 *      <li> <code> PoolProcessorEnablerQuerySession: </code> a session to 
 *      query for pool processor enablers </li> 
 *      <li> <code> PoolProcessorEnablerSearchSession: </code> a session to 
 *      search for pool processor enablers </li> 
 *      <li> <code> PoolProcessorEnablerAdminSession: </code> a session to 
 *      create and delete pool processor enablers </li> 
 *      <li> <code> PoolProcessorEnablerNotificationSession: </code> a session 
 *      to receive notifications pertaining to pool processor enabler changes 
 *      </li> 
 *      <li> <code> PoolProcessorEnablerDistributorSession: </code> a session 
 *      to look up pool processor enabler distributor mappings </li> 
 *      <li> <code> PoolProcessorEnablerDistributorAssignmentSession: </code> 
 *      a session to manage pool processor enabler to distributor mappings 
 *      </li> 
 *      <li> <code> PoolProcessorEnablerSmartDistributorSession: </code> a 
 *      session to manage dynamic distributors of pool processor enablers 
 *      </li> 
 *      <li> <code> PoolProcessorEnablerRuleLookupSession: </code> a session 
 *      to look up pool processor enabler mappings </li> 
 *      <li> <code> PoolProcessorEnablerRuleApplicationSession: </code> a 
 *      session to apply pool processor enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> BrokerConstrainerLookupSession: </code> a session to 
 *      retrieve broker constrainer </li> 
 *      <li> <code> BrokerConstrainerQuerySession: </code> a session to query 
 *      for broker constrainer </li> 
 *      <li> <code> BrokerConstrainerSearchSession: </code> a session to 
 *      search for broker constrainer </li> 
 *      <li> <code> BrokerConstrainerAdminSession: </code> a session to create 
 *      and delete broker constrainer </li> 
 *      <li> <code> BrokerConstrainerNotificationSession: </code> a session to 
 *      receive notifications pertaining to broker constrainer changes </li> 
 *      <li> <code> BrokerConstrainerDistributorSession: </code> a session to 
 *      look up broker constrainer distributor mappings </li> 
 *      <li> <code> BrokerConstrainerDistributorAssignmentSession: </code> a 
 *      session to manage broker constrainer to distributor mappings </li> 
 *      <li> <code> BrokerConstrainerSmartDistributorSession: </code> a 
 *      session to manage dynamic distributors of broker constrainer </li> 
 *      <li> <code> BrokerConstrainerRuleLookupSession: </code> a session to 
 *      look up broker constrainer to broker mappings </li> 
 *      <li> <code> BrokerConstrainerRuleApplicationSession: </code> a session 
 *      to apply broker constrainer to brokerss </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> BrokerConstrainerEnablerLookupSession: </code> a session 
 *      to retrieve broker constrainer enablers </li> 
 *      <li> <code> BrokerConstrainerEnablerQuerySession: </code> a session to 
 *      query for broker constrainer enablers </li> 
 *      <li> <code> BrokerConstrainerEnablerSearchSession: </code> a session 
 *      to search for broker constrainer enablers </li> 
 *      <li> <code> BrokerConstrainerEnablerAdminSession: </code> a session to 
 *      create and delete broker constrainer enablers </li> 
 *      <li> <code> BrokerConstrainerEnablerNotificationSession: </code> a 
 *      session to receive notifications pertaining to broker constrainer 
 *      enabler changes </li> 
 *      <li> <code> BrokerConstrainerEnablerDistributorSession: </code> a 
 *      session to look up broker constrainer enabler distributor mappings 
 *      </li> 
 *      <li> <code> BrokerConstrainerEnablerDistributorAssignmentSession: 
 *      </code> a session to manage broker constrainer enabler to distributor 
 *      mappings </li> 
 *      <li> <code> BrokerConstrainerEnablerSmartDistributorSession: </code> a 
 *      session to manage dynamic distributors of broker constrainer enablers 
 *      </li> 
 *      <li> <code> BrokerConstrainerEnableRuleLookupSession: </code> a 
 *      session to look up broker constrainer enabler mappings </li> 
 *      <li> <code> BrokerConstrainerEnablerRuleApplicationSession: </code> a 
 *      session to apply broker constrainer enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> BrokerProcessorLookupSession: </code> a session to 
 *      retrieve broker processor </li> 
 *      <li> <code> BrokerProcessorQuerySession: </code> a session to query 
 *      for broker processor </li> 
 *      <li> <code> BrokerProcessorSearchSession: </code> a session to search 
 *      for broker processor </li> 
 *      <li> <code> BrokerProcessorAdminSession: </code> a session to create 
 *      and delete broker processor </li> 
 *      <li> <code> BrokerProcessorNotificationSession: </code> a session to 
 *      receive notifications pertaining to broker processor changes </li> 
 *      <li> <code> BrokerProcessorDistributorSession: </code> a session to 
 *      look up broker processor distributor mappings </li> 
 *      <li> <code> BrokerProcessorDistributorAssignmentSession: </code> a 
 *      session to manage broker processor to distributor mappings </li> 
 *      <li> <code> BrokerProcessorSmartDistributorSession: </code> a session 
 *      to manage dynamic distributors of broker processor </li> 
 *      <li> <code> BrokerProcessorRuleLookupSession: </code> a session to 
 *      look up broker processor to broker mappings </li> 
 *      <li> <code> BrokerProcessorRuleApplicationSession: </code> a session 
 *      to apply broker processor to brokerss </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> BrokerProcessorEnablerLookupSession: </code> a session to 
 *      retrieve broker processor enablers </li> 
 *      <li> <code> BrokerProcessorEnablerQuerySession: </code> a session to 
 *      query for broker processor enablers </li> 
 *      <li> <code> BrokerProcessorEnablerSearchSession: </code> a session to 
 *      search for broker processor enablers </li> 
 *      <li> <code> BrokerProcessorEnablerAdminSession: </code> a session to 
 *      create and delete broker processor enablers </li> 
 *      <li> <code> BrokerProcessorEnablerNotificationSession: </code> a 
 *      session to receive notifications pertaining to broker processor 
 *      enabler changes </li> 
 *      <li> <code> BrokerProcessorEnablerDistributorSession: </code> a 
 *      session to look up broker processor enabler distributor mappings </li> 
 *      <li> <code> BrokerProcessorEnablerDistributorAssignmentSession: 
 *      </code> a session to manage broker processor enabler to distributor 
 *      mappings </li> 
 *      <li> <code> BrokerProcessorEnablerSmartDistributorSession: </code> a 
 *      session to manage dynamic distributors of broker processor enablers 
 *      </li> 
 *      <li> <code> BrokerProcessorEnablerRuleLookupSession: </code> a session 
 *      to look up broker processor enabler mappings </li> 
 *      <li> <code> BrokerProcessorEnablerRuleApplicationSession: </code> a 
 *      session to apply broker processor enablers </li> 
 *  </ul>
 *  
 */

public interface ProvisioningRulesProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.provisioning.rules.ProvisioningRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerLookupSession getQueueConstrainerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerLookupSession getQueueConstrainerLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerQuerySession getQueueConstrainerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer query service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerQuerySession getQueueConstrainerQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerSearchSession getQueueConstrainerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer earch service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerSearchSession getQueueConstrainerSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerAdminSession getQueueConstrainerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer administration service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerAdminSession getQueueConstrainerAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer notification service. 
     *
     *  @param  queueConstrainerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> queueConstrainerReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerNotificationSession getQueueConstrainerNotificationSession(org.osid.provisioning.rules.QueueConstrainerReceiver queueConstrainerReceiver, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer notification service for the given distributor. 
     *
     *  @param  queueConstrainerReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerReceiver, distributorId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerNotificationSession getQueueConstrainerNotificationSessionForDistributor(org.osid.provisioning.rules.QueueConstrainerReceiver queueConstrainerReceiver, 
                                                                                                                                org.osid.id.Id distributorId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup queue 
     *  constrainer/distributor mappings for queue constrainers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerDistributor() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerDistributor() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerDistributorSession getQueueConstrainerDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning queue 
     *  constrainer to distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerDistributorAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerDistributorAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerDistributorAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerDistributorAssignmentSession getQueueConstrainerDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage queue constrainer smart 
     *  distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerSmartDistributorSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerSmartDistributor() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerSmartDistributor() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerSmartDistributorSession getQueueConstrainerSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer mapping lookup service for looking up the rules applied to 
     *  ta queue. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerRuleLookupSession getQueueConstrainerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer mapping lookup service for the given distributor for 
     *  looking up rules applied to a qeue. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerRuleLookupSession getQueueConstrainerRuleLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer assignment service to apply to queues. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerRuleApplicationSession getQueueConstrainerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer assignment service for the given distributor to apply to 
     *  queues. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerRuleApplicationSession getQueueConstrainerRuleApplicationSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerLookupSession getQueueConstrainerEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer enabler lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerLookupSession getQueueConstrainerEnablerLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerQuerySession getQueueConstrainerEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer enabler query service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerQuerySession getQueueConstrainerEnablerQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerSearch() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerSearchSession getQueueConstrainerEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer enablers earch service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerSearchSession getQueueConstrainerEnablerSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerAdminSession getQueueConstrainerEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer enabler administration service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerAdminSession getQueueConstrainerEnablerAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer enabler notification service. 
     *
     *  @param  queueConstrainerEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerEnablerReceiver </code> or <code> proxy 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerNotification() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerNotificationSession getQueueConstrainerEnablerNotificationSession(org.osid.provisioning.rules.QueueConstrainerEnablerReceiver queueConstrainerEnablerReceiver, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer enabler notification service for the given distributor. 
     *
     *  @param  queueConstrainerEnablerReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerEnablerReceiver, distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerNotification() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerNotificationSession getQueueConstrainerEnablerNotificationSessionForDistributor(org.osid.provisioning.rules.QueueConstrainerEnablerReceiver queueConstrainerEnablerReceiver, 
                                                                                                                                              org.osid.id.Id distributorId, 
                                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup queue constrainer 
     *  enabler/distributor mappings for queue constrainer enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerDistributor() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerDistributor() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerDistributorSession getQueueConstrainerEnablerDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning queue 
     *  constrainer enablers to distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerDistributorAssignmentSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerDistributorAssignment() </code> 
     *          is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerDistributorAssignment() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerDistributorAssignmentSession getQueueConstrainerEnablerDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage queue constrainer 
     *  enabler smart distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerSmartDistributorSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerSmartDistributor() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerSmartDistributor() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerSmartDistributorSession getQueueConstrainerEnablerSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer enabler mapping lookup service . 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerRuleLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerRuleLookupSession getQueueConstrainerEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer enabler mapping lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerRuleLookupSession getQueueConstrainerEnablerRuleLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerRuleApplication() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerRuleApplicationSession getQueueConstrainerEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  constrainer enabler assignment service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueConstrainerEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueConstrainerEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueConstrainerEnablerRuleApplication() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerRuleApplicationSession getQueueConstrainerEnablerRuleApplicationSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorLookupSession getQueueProcessorLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorLookupSession getQueueProcessorLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorQuerySession getQueueProcessorQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor query service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorQuerySession getQueueProcessorQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorSearchSession getQueueProcessorSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor earch service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorSearchSession getQueueProcessorSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorAdminSession getQueueProcessorAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor administration service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorAdminSession getQueueProcessorAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor notification service. 
     *
     *  @param  queueProcessorReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> queueProcessorReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorNotificationSession getQueueProcessorNotificationSession(org.osid.provisioning.rules.QueueProcessorReceiver queueProcessorReceiver, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor notification service for the given distributor. 
     *
     *  @param  queueProcessorReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> queueProcessorReceiver, 
     *          distributorId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorNotificationSession getQueueProcessorNotificationSessionForDistributor(org.osid.provisioning.rules.QueueProcessorReceiver queueProcessorReceiver, 
                                                                                                                            org.osid.id.Id distributorId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup queue 
     *  processor/distributor mappings for queue processors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorDistributor() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorDistributor() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorDistributorSession getQueueProcessorDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning queue 
     *  processor to distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorDistributorAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorDistributorAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorDistributorAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorDistributorAssignmentSession getQueueProcessorDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage queue processor smart 
     *  distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorSmartDistributorSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorSmartDistributor() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorSmartDistributor() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorSmartDistributorSession getQueueProcessorSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor mapping lookup service for looking up the rules applied to a 
     *  queue processor. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorRuleLookupSession getQueueProcessorRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor mapping lookup service for the given distributor for looking 
     *  up rules applied to a queue. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorRuleLookupSession getQueueProcessorRuleLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor assignment service to apply to queues. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorRuleApplicationSession getQueueProcessorRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor assignment service for the given distributor to apply to 
     *  queues. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorRuleApplicationSession getQueueProcessorRuleApplicationSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerLookupSession getQueueProcessorEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor enabler lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerLookupSession getQueueProcessorEnablerLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerQuerySession getQueueProcessorEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor enabler query service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerQuerySession getQueueProcessorEnablerQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerSearchSession getQueueProcessorEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor enablers earch service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerSearchSession getQueueProcessorEnablerSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerAdminSession getQueueProcessorEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor enabler administration service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerAdminSession getQueueProcessorEnablerAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor enabler notification service. 
     *
     *  @param  queueProcessorEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerReceiver </code> or <code> proxy </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerNotificationSession getQueueProcessorEnablerNotificationSession(org.osid.provisioning.rules.QueueProcessorEnablerReceiver queueProcessorEnablerReceiver, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor enabler notification service for the given distributor. 
     *
     *  @param  queueProcessorEnablerReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerReceiver, distributorId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerNotificationSession getQueueProcessorEnablerNotificationSessionForDistributor(org.osid.provisioning.rules.QueueProcessorEnablerReceiver queueProcessorEnablerReceiver, 
                                                                                                                                          org.osid.id.Id distributorId, 
                                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup queue processor 
     *  enabler/distributor mappings for queue processor enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerDistributor() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerDistributor() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerDistributorSession getQueueProcessorEnablerDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning queue 
     *  processor enablers to queue processors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerDistributorAssignmentSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerDistributorAssignment() </code> 
     *          is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerDistributorAssignment() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerDistributorAssignmentSession getQueueProcessorEnablerDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage queue processor enabler 
     *  smart distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerSmartDistributorSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerSmartDistributor() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerSmartDistributor() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerSmartDistributorSession getQueueProcessorEnablerSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor enabler mapping lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerRuleLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerRuleLookupSession getQueueProcessorEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor enabler mapping lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerRuleLookupSession getQueueProcessorEnablerRuleLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerRuleApplicationSession getQueueProcessorEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  processor enabler assignment service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueProcessorEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueProcessorEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueProcessorEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerRuleApplicationSession getQueueProcessorEnablerRuleApplicationSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerLookupSession getPoolConstrainerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerLookupSession getPoolConstrainerLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerQuerySession getPoolConstrainerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer query service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerQuerySession getPoolConstrainerQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerSearchSession </code> 
     *  @throws org.osid.NullArgumentException a <code> 
     *          PoolConstrainerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerSearchSession getPoolConstrainerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer earch service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerSearchSession getPoolConstrainerSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerAdminSession getPoolConstrainerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer administration service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerAdminSession getPoolConstrainerAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer notification service. 
     *
     *  @param  poolConstrainerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> poolConstrainerReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerNotificationSession getPoolConstrainerNotificationSession(org.osid.provisioning.rules.PoolConstrainerReceiver poolConstrainerReceiver, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer notification service for the given distributor. 
     *
     *  @param  poolConstrainerReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> poolConstrainerReceiver, 
     *          distributorId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerNotificationSession getPoolConstrainerNotificationSessionForDistributor(org.osid.provisioning.rules.PoolConstrainerReceiver poolConstrainerReceiver, 
                                                                                                                              org.osid.id.Id distributorId, 
                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup pool 
     *  constrainer/distributor mappings for pool constrainers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerDistributor() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerDistributor() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerDistributorSession getPoolConstrainerDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning pool 
     *  constrainer to distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerDistributorAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerDistributorAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerDistributorAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerDistributorAssignmentSession getPoolConstrainerDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage pool constrainer smart 
     *  distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerSmartDistributorSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerSmartDistributor() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerSmartDistributor() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerSmartDistributorSession getPoolConstrainerSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer mapping lookup service for looking up the rules applied to 
     *  a pool. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerRuleLookupSession getPoolConstrainerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer mapping lookup service for the given distributor for 
     *  looking up rules applied to a pool. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerRuleLookupSession getPoolConstrainerRuleLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer assignment service to apply to pools. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerRuleApplicationSession getPoolConstrainerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer assignment service for the given distributor to apply to 
     *  pools. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerRuleApplicationSession getPoolConstrainerRuleApplicationSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerLookupSession getPoolConstrainerEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer enabler lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerLookupSession getPoolConstrainerEnablerLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerQuerySession getPoolConstrainerEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer enabler query service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerQuerySession getPoolConstrainerEnablerQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerSearchSession getPoolConstrainerEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer enablers earch service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerSearchSession getPoolConstrainerEnablerSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerAdminSession getPoolConstrainerEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer enabler administration service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerAdminSession getPoolConstrainerEnablerAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer enabler notification service. 
     *
     *  @param  poolConstrainerEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerEnablerReceiver </code> or <code> proxy </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerNotificationSession getPoolConstrainerEnablerNotificationSession(org.osid.provisioning.rules.PoolConstrainerEnablerReceiver poolConstrainerEnablerReceiver, 
                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer enabler notification service for the given distributor. 
     *
     *  @param  poolConstrainerEnablerReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerEnablerReceiver, distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerNotificationSession getPoolConstrainerEnablerNotificationSessionForDistributor(org.osid.provisioning.rules.PoolConstrainerEnablerReceiver poolConstrainerEnablerReceiver, 
                                                                                                                                            org.osid.id.Id distributorId, 
                                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup pool constrainer 
     *  enabler/distributor mappings for pool constrainer enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerDistributor() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerDistributor() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerDistributorSession getPoolConstrainerEnablerDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning pool 
     *  constrainer enablers to distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerDistributorAssignmentSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerDistributorAssignment() </code> 
     *          is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerDistributorAssignment() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerDistributorAssignmentSession getPoolConstrainerEnablerDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage pool constrainer enabler 
     *  smart distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerSmartDistributorSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerSmartDistributor() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerSmartDistributor() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerSmartDistributorSession getPoolConstrainerEnablerSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer enabler mapping lookup service . 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerRuleLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerRuleLookupSession getPoolConstrainerEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer enabler mapping lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerRuleLookupSession getPoolConstrainerEnablerRuleLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerRuleApplicationSession getPoolConstrainerEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  constrainer enabler assignment service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolConstrainerEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolConstrainerEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolConstrainerEnablerRuleApplication() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerRuleApplicationSession getPoolConstrainerEnablerRuleApplicationSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorLookupSession getPoolProcessorLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorLookupSession getPoolProcessorLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorQuerySession getPoolProcessorQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  query service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorQuerySession getPoolProcessorQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorSearchSession getPoolProcessorSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  earch service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorSearchSession getPoolProcessorSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorAdminSession getPoolProcessorAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  administration service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorAdminSession getPoolProcessorAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  notification service. 
     *
     *  @param  poolProcessorReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> poolProcessorReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorNotificationSession getPoolProcessorNotificationSession(org.osid.provisioning.rules.PoolProcessorReceiver poolProcessorReceiver, 
                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  notification service for the given distributor. 
     *
     *  @param  poolProcessorReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> poolProcessorReceiver, 
     *          distributorId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorNotificationSession getPoolProcessorNotificationSessionForDistributor(org.osid.provisioning.rules.PoolProcessorReceiver poolProcessorReceiver, 
                                                                                                                          org.osid.id.Id distributorId, 
                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup pool 
     *  processor/distributor mappings for pool processors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorDistributor() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorDistributor() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorDistributorSession getPoolProcessorDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning pool 
     *  processor to distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorDistributorAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorDistributorAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorDistributorAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorDistributorAssignmentSession getPoolProcessorDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage pool processor smart 
     *  distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorSmartDistributorSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorSmartDistributor() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorSmartDistributor() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorSmartDistributorSession getPoolProcessorSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  mapping lookup service for looking up the rules applied to a pool. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorRuleLookupSession getPoolProcessorRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  mapping lookup service for the given distributor for looking up rules 
     *  applied to a pool. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorRuleLookupSession getPoolProcessorRuleLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  assignment service to apply to pool processors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorRuleApplication() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorRuleApplicationSession getPoolProcessorRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  assignment service for the given distributor to apply to pool 
     *  processors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorRuleApplicationSession getPoolProcessorRuleApplicationSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerLookupSession getPoolProcessorEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  enabler lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerLookupSession getPoolProcessorEnablerLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerQuerySession getPoolProcessorEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  enabler query service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerQuerySession getPoolProcessorEnablerQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerSearchSession getPoolProcessorEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  enablers earch service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerSearchSession getPoolProcessorEnablerSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerAdminSession getPoolProcessorEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  enabler administration service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerAdminSession getPoolProcessorEnablerAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  enabler notification service. 
     *
     *  @param  poolProcessorEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolProcessorEnablerReceiver </code> or <code> proxy </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerNotificationSession getPoolProcessorEnablerNotificationSession(org.osid.provisioning.rules.PoolProcessorEnablerReceiver poolProcessorEnablerReceiver, 
                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  enabler notification service for the given distributor. 
     *
     *  @param  poolProcessorEnablerReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolProcessorEnablerReceiver, distributorId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerNotificationSession getPoolProcessorEnablerNotificationSessionForDistributor(org.osid.provisioning.rules.PoolProcessorEnablerReceiver poolProcessorEnablerReceiver, 
                                                                                                                                        org.osid.id.Id distributorId, 
                                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup pool processor 
     *  enabler/distributor mappings for pool processor enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerDistributor() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerDistributor() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerDistributorSession getPoolProcessorEnablerDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning pool 
     *  processor enablers to distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerDistributorAssignmentSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerDistributorAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerDistributorAssignment() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerDistributorAssignmentSession getPoolProcessorEnablerDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage pool processor enabler 
     *  smart distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerSmartDistributorSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerSmartDistributor() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerSmartDistributor() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerSmartDistributorSession getPoolProcessorEnablerSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  enabler mapping lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerRuleLookupSession getPoolProcessorEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  enabler mapping lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerRuleLookupSession getPoolProcessorEnablerRuleLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerRuleApplicationSession getPoolProcessorEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool processor 
     *  enabler assignment service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolProcessorEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolProcessorEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolProcessorEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.PoolProcessorEnablerRuleApplicationSession getPoolProcessorEnablerRuleApplicationSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerLookupSession getBrokerConstrainerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerLookupSession getBrokerConstrainerLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerQuerySession getBrokerConstrainerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer query service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerQuerySession getBrokerConstrainerQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerSearchSession getBrokerConstrainerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer earch service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerSearchSession getBrokerConstrainerSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerAdminSession getBrokerConstrainerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer administration service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerAdminSession getBrokerConstrainerAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer notification service. 
     *
     *  @param  brokerConstrainerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerReceiver </code> or <code> proxy </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerNotificationSession getBrokerConstrainerNotificationSession(org.osid.provisioning.rules.BrokerConstrainerReceiver brokerConstrainerReceiver, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer notification service for the given distributor. 
     *
     *  @param  brokerConstrainerReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerReceiver, distributorId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerNotificationSession getBrokerConstrainerNotificationSessionForDistributor(org.osid.provisioning.rules.BrokerConstrainerReceiver brokerConstrainerReceiver, 
                                                                                                                                  org.osid.id.Id distributorId, 
                                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup broker 
     *  constrainer/distributor mappings for broker constrainers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerDistributor() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerDistributor() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerDistributorSession getBrokerConstrainerDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning broker 
     *  constrainer to distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerDistributorAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerDistributorAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerDistributorAssignment() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerDistributorAssignmentSession getBrokerConstrainerDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage broker constrainer smart 
     *  distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerSmartDistributorSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerSmartDistributor() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerSmartDistributor() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerSmartDistributorSession getBrokerConstrainerSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer mapping lookup service for looking up the rules applied to 
     *  a broker. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerRuleLookupSession getBrokerConstrainerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer mapping lookup service for the given distributor for 
     *  looking up rules applied to a broker. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerRuleLookupSession getBrokerConstrainerRuleLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer assignment service to apply to brokers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerRuleApplicationSession getBrokerConstrainerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer assignment service for the given distributor to apply to 
     *  brokers. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerRuleApplicationSession getBrokerConstrainerRuleApplicationSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerLookupSession getBrokerConstrainerEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer enabler lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerLookupSession getBrokerConstrainerEnablerLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerQuery() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerQuerySession getBrokerConstrainerEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer enabler query service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerQuerySession getBrokerConstrainerEnablerQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerSearch() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerSearchSession getBrokerConstrainerEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer enablers earch service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerSearch() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerSearchSession getBrokerConstrainerEnablerSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerAdmin() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerAdminSession getBrokerConstrainerEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer enabler administration service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerAdminSession getBrokerConstrainerEnablerAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer enabler notification service. 
     *
     *  @param  brokerConstrainerEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerEnablerReceiver </code> or <code> proxy 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerNotification() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerNotificationSession getBrokerConstrainerEnablerNotificationSession(org.osid.provisioning.rules.BrokerConstrainerEnablerReceiver brokerConstrainerEnablerReceiver, 
                                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer enabler notification service for the given distributor. 
     *
     *  @param  brokerConstrainerEnablerReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerEnablerReceiver, distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerNotification() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerNotificationSession getBrokerConstrainerEnablerNotificationSessionForDistributor(org.osid.provisioning.rules.BrokerConstrainerEnablerReceiver brokerConstrainerEnablerReceiver, 
                                                                                                                                                org.osid.id.Id distributorId, 
                                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup broker constrainer 
     *  enabler/distributor mappings for broker constrainer enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerDistributor() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerDistributor() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerDistributorSession getBrokerConstrainerEnablerDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning broker 
     *  constrainer enablers to distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerDistributorAssignmentSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerDistributorAssignment() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerDistributorAssignment() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerDistributorAssignmentSession getBrokerConstrainerEnablerDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage broker constrainer 
     *  enabler smart distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerSmartDistributorSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerSmartDistributor() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerSmartDistributor() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerSmartDistributorSession getBrokerConstrainerEnablerSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer enabler mapping lookup service . 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerRuleLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerRuleLookupSession getBrokerConstrainerEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer enabler mapping lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerRuleLookupSession getBrokerConstrainerEnablerRuleLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerRuleApplicationSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerRuleApplication() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerRuleApplicationSession getBrokerConstrainerEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  constrainer enabler assignment service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerConstrainerEnablerRuleApplicationSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerConstrainerEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerConstrainerEnablerRuleApplication() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerRuleApplicationSession getBrokerConstrainerEnablerRuleApplicationSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorLookupSession getBrokerProcessorLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorLookupSession getBrokerProcessorLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorQuerySession getBrokerProcessorQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor query service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorQuerySession getBrokerProcessorQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorSearchSession getBrokerProcessorSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor earch service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorSearchSession getBrokerProcessorSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorAdminSession getBrokerProcessorAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor administration service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorAdminSession getBrokerProcessorAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor notification service. 
     *
     *  @param  brokerProcessorReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorNotificationSession getBrokerProcessorNotificationSession(org.osid.provisioning.rules.BrokerProcessorReceiver brokerProcessorReceiver, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor notification service for the given distributor. 
     *
     *  @param  brokerProcessorReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorReceiver, 
     *          distributorId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorNotificationSession getBrokerProcessorNotificationSessionForDistributor(org.osid.provisioning.rules.BrokerProcessorReceiver brokerProcessorReceiver, 
                                                                                                                              org.osid.id.Id distributorId, 
                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup broker 
     *  processor/distributor mappings for broker processors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorDistributor() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorDistributor() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorDistributorSession getBrokerProcessorDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning broker 
     *  processor to distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorDistributorAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorDistributorAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorDistributorAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorDistributorAssignmentSession getBrokerProcessorDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage broker processor smart 
     *  distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorSmartDistributorSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorSmartDistributor() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorSmartDistributor() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorSmartDistributorSession getBrokerProcessorSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor mapping lookup service for looking up the rules applied to a 
     *  broker. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorRuleLookupSession getBrokerProcessorRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor mapping lookup service for the given distributor for looking 
     *  up rules applied to a broker. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorRuleLookupSession getBrokerProcessorRuleLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor assignment service to apply to brokers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorRuleApplicationSession getBrokerProcessorRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor assignment service for the given distributor to apply to 
     *  brokers. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorRuleApplicationSession getBrokerProcessorRuleApplicationSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerLookupSession getBrokerProcessorEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor enabler lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerLookupSession getBrokerProcessorEnablerLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerQuerySession getBrokerProcessorEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor enabler query service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerQuerySession getBrokerProcessorEnablerQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerSearchSession getBrokerProcessorEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor enablers earch service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerSearchSession getBrokerProcessorEnablerSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerAdminSession getBrokerProcessorEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor enabler administration service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerAdminSession getBrokerProcessorEnablerAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor enabler notification service. 
     *
     *  @param  brokerProcessorEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerProcessorEnablerReceiver </code> or <code> proxy </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerNotificationSession getBrokerProcessorEnablerNotificationSession(org.osid.provisioning.rules.BrokerProcessorEnablerReceiver brokerProcessorEnablerReceiver, 
                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor enabler notification service for the given distributor. 
     *
     *  @param  brokerProcessorEnablerReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerProcessorEnablerReceiver, distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerNotificationSession getBrokerProcessorEnablerNotificationSessionForDistributor(org.osid.provisioning.rules.BrokerProcessorEnablerReceiver brokerProcessorEnablerReceiver, 
                                                                                                                                            org.osid.id.Id distributorId, 
                                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup broker processor 
     *  enabler/distributor mappings for broker processor enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerDistributor() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerDistributor() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerDistributorSession getBrokerProcessorEnablerDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning broker 
     *  processor enablers to distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerDistributorAssignmentSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerDistributorAssignment() </code> 
     *          is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerDistributorAssignment() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerDistributorAssignmentSession getBrokerProcessorEnablerDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage broker processor enabler 
     *  smart distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerSmartDistributorSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerSmartDistributor() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerSmartDistributor() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerSmartDistributorSession getBrokerProcessorEnablerSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor enabler mapping lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerRuleLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerRuleLookupSession getBrokerProcessorEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor enabler mapping lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerRuleLookupSession getBrokerProcessorEnablerRuleLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerRuleApplicationSession getBrokerProcessorEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  processor enabler assignment service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerProcessorEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerProcessorEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerProcessorEnablerRuleApplication() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerRuleApplicationSession getBrokerProcessorEnablerRuleApplicationSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
